/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_sej1KvDv);
  numBytes += sLine_init(&sLine_dZ7n3rfQ);
  numBytes += sLine_init(&sLine_gl52Z6OQ);
  numBytes += sLine_init(&sLine_53bw1hnb);
  numBytes += sLine_init(&sLine_lpjwtbeN);
  numBytes += sBiquad_init(&sBiquad_s_ikrhn9Ym);
  numBytes += sLine_init(&sLine_4r4wX7nS);
  numBytes += sLine_init(&sLine_3LTEDo4O);
  numBytes += sLine_init(&sLine_lfN5ZIzu);
  numBytes += sLine_init(&sLine_ZZqkUpdO);
  numBytes += sLine_init(&sLine_sGntX5nh);
  numBytes += sBiquad_init(&sBiquad_s_qoYTJRhm);
  numBytes += sLine_init(&sLine_Lntt1gKQ);
  numBytes += sLine_init(&sLine_3QAlvVxT);
  numBytes += sLine_init(&sLine_RtHfbkXF);
  numBytes += sLine_init(&sLine_Pr9RHTzh);
  numBytes += sLine_init(&sLine_npUChMq9);
  numBytes += sLine_init(&sLine_2vnoandb);
  numBytes += sBiquad_init(&sBiquad_s_ngWZE9jG);
  numBytes += sLine_init(&sLine_afMLwezW);
  numBytes += sLine_init(&sLine_9FRuhRsR);
  numBytes += sLine_init(&sLine_raqXavFV);
  numBytes += sLine_init(&sLine_7quaHcdV);
  numBytes += sLine_init(&sLine_M4rcebnw);
  numBytes += sLine_init(&sLine_zkgrVsG6);
  numBytes += sBiquad_init(&sBiquad_s_2s4LClbv);
  numBytes += sLine_init(&sLine_6vVca9Cr);
  numBytes += sLine_init(&sLine_dRwmqQef);
  numBytes += sLine_init(&sLine_26wwKcyL);
  numBytes += sLine_init(&sLine_qaz4s4xL);
  numBytes += sLine_init(&sLine_TjraN0UB);
  numBytes += sBiquad_init(&sBiquad_s_HwIjPgBM);
  numBytes += sLine_init(&sLine_REElEn5X);
  numBytes += sLine_init(&sLine_eUesPIQn);
  numBytes += sLine_init(&sLine_CqyyEhpi);
  numBytes += sLine_init(&sLine_O0zgOsnr);
  numBytes += sLine_init(&sLine_X0cqLvoj);
  numBytes += sLine_init(&sLine_qNVqZ0xs);
  numBytes += sBiquad_init(&sBiquad_s_b5bzU8L6);
  numBytes += sLine_init(&sLine_uQ15MQKN);
  numBytes += sLine_init(&sLine_mz8VXjYh);
  numBytes += sLine_init(&sLine_nNObmQnJ);
  numBytes += sLine_init(&sLine_WoERXYiG);
  numBytes += sLine_init(&sLine_V8kzE1T5);
  numBytes += sLine_init(&sLine_2HZSDI7Z);
  numBytes += sLine_init(&sLine_EatOt60Z);
  numBytes += sLine_init(&sLine_ya7UUR3T);
  numBytes += sLine_init(&sLine_QMwfSRga);
  numBytes += sLine_init(&sLine_QWeQvLzO);
  numBytes += sLine_init(&sLine_dPcUEwbX);
  numBytes += sLine_init(&sLine_j9UaZDEl);
  numBytes += sLine_init(&sLine_4r1gdoJt);
  numBytes += sLine_init(&sLine_DCvegYgG);
  numBytes += sLine_init(&sLine_8EvkVbqL);
  numBytes += sEnv_init(&sEnv_8OdsCRrA, 512, 256);
  numBytes += sEnv_init(&sEnv_oxk4RKer, 512, 256);
  numBytes += sLine_init(&sLine_pJQ56YO0);
  numBytes += sLine_init(&sLine_HK2gFNh1);
  numBytes += sLine_init(&sLine_m8B9emDa);
  numBytes += sLine_init(&sLine_XyeDdSp8);
  numBytes += sLine_init(&sLine_JRzax4vN);
  numBytes += sLine_init(&sLine_SA2ckAkw);
  numBytes += sLine_init(&sLine_WWnlyZY9);
  numBytes += sLine_init(&sLine_tiaIaBPv);
  numBytes += sLine_init(&sLine_WT3npUqH);
  numBytes += sLine_init(&sLine_VVYOa60h);
  numBytes += sLine_init(&sLine_hmkvz4a8);
  numBytes += sLine_init(&sLine_seo1zEtK);
  numBytes += sLine_init(&sLine_jPPBcdLx);
  numBytes += sLine_init(&sLine_f9mjabuR);
  numBytes += sLine_init(&sLine_qmwD0tTA);
  numBytes += sLine_init(&sLine_J2LrEdIu);
  numBytes += sLine_init(&sLine_moI6oDZz);
  numBytes += sLine_init(&sLine_BpyP2r8M);
  numBytes += sEnv_init(&sEnv_TgHdAcS9, 512, 256);
  numBytes += sEnv_init(&sEnv_xECpFu9h, 512, 256);
  numBytes += sLine_init(&sLine_sUnt3fmJ);
  numBytes += sLine_init(&sLine_fqOE2GNO);
  numBytes += sLine_init(&sLine_EvvUng9M);
  numBytes += sLine_init(&sLine_EXuIzKoZ);
  numBytes += sLine_init(&sLine_eIRCpUjN);
  numBytes += sLine_init(&sLine_bCVl9EtW);
  numBytes += sLine_init(&sLine_rMz6RJNI);
  numBytes += sLine_init(&sLine_aC7DT6sk);
  numBytes += sLine_init(&sLine_HjEufcug);
  numBytes += sLine_init(&sLine_0Wi290KZ);
  numBytes += sLine_init(&sLine_L5mr6iNo);
  numBytes += sLine_init(&sLine_e7Spewh2);
  numBytes += sLine_init(&sLine_wOSRRnGQ);
  numBytes += sLine_init(&sLine_QgOHtB8W);
  numBytes += sLine_init(&sLine_7sguzfOG);
  numBytes += sLine_init(&sLine_kbKfvAp6);
  numBytes += sLine_init(&sLine_Lub09x2W);
  numBytes += sLine_init(&sLine_ZdQX6UkK);
  numBytes += sLine_init(&sLine_KScbNcDK);
  numBytes += sLine_init(&sLine_M4qLKRWz);
  numBytes += sEnv_init(&sEnv_TH3MPeU9, 512, 256);
  numBytes += sEnv_init(&sEnv_gRDr9mRZ, 512, 256);
  numBytes += sLine_init(&sLine_Gx8dbkoU);
  numBytes += sLine_init(&sLine_Fw9cbCSV);
  numBytes += sLine_init(&sLine_t8jeFpDX);
  numBytes += sLine_init(&sLine_iMgO4h1Q);
  numBytes += sLine_init(&sLine_79LUztVd);
  numBytes += sLine_init(&sLine_r2YfIevf);
  numBytes += sLine_init(&sLine_nTvlXFPr);
  numBytes += sLine_init(&sLine_GQ2RnPk3);
  numBytes += sLine_init(&sLine_DrL1fQT8);
  numBytes += sLine_init(&sLine_06v0ov2y);
  numBytes += sLine_init(&sLine_TNe89WGO);
  numBytes += sLine_init(&sLine_OfC7p1tY);
  numBytes += sLine_init(&sLine_aTIrxYQX);
  numBytes += sLine_init(&sLine_YO57sY5g);
  numBytes += sLine_init(&sLine_KEzHY0W9);
  numBytes += sLine_init(&sLine_lpzUfHtL);
  numBytes += sLine_init(&sLine_KZRLzRkT);
  numBytes += sLine_init(&sLine_3yCyl5fj);
  numBytes += sEnv_init(&sEnv_6hbp07Ll, 512, 256);
  numBytes += sEnv_init(&sEnv_s06cSl1I, 512, 256);
  numBytes += sLine_init(&sLine_Ia7I8vH7);
  numBytes += sLine_init(&sLine_PUNHRokT);
  numBytes += sLine_init(&sLine_PPHNkKqa);
  numBytes += sLine_init(&sLine_qmGYOjlu);
  numBytes += sLine_init(&sLine_Sjifc3bi);
  numBytes += sLine_init(&sLine_Xxu8Vd2c);
  numBytes += sLine_init(&sLine_wnyHJOKW);
  numBytes += sLine_init(&sLine_hdxUK3Bt);
  numBytes += sLine_init(&sLine_eIOJyGLt);
  numBytes += sLine_init(&sLine_Mja35mP2);
  numBytes += sLine_init(&sLine_tg35ulWt);
  numBytes += sLine_init(&sLine_vIW2eJ5Y);
  numBytes += sLine_init(&sLine_ZwmsUNff);
  numBytes += sLine_init(&sLine_ckwoFKe3);
  numBytes += sLine_init(&sLine_eigIZEcC);
  numBytes += sLine_init(&sLine_PFoCM56L);
  numBytes += sLine_init(&sLine_F075KHvp);
  numBytes += sLine_init(&sLine_ne6aPGeq);
  numBytes += sLine_init(&sLine_YUh0TIV9);
  numBytes += sLine_init(&sLine_whaKzzsP);
  numBytes += sEnv_init(&sEnv_9A6aXtWA, 512, 256);
  numBytes += sEnv_init(&sEnv_Gi9Jylt3, 512, 256);
  numBytes += sLine_init(&sLine_IyJGTvYs);
  numBytes += sLine_init(&sLine_XQ7uR8i7);
  numBytes += sLine_init(&sLine_DZriARlK);
  numBytes += sLine_init(&sLine_LC5DhuoK);
  numBytes += sLine_init(&sLine_7Rxsi0U6);
  numBytes += sLine_init(&sLine_5TUnRzVB);
  numBytes += sLine_init(&sLine_EFU1BRDz);
  numBytes += sLine_init(&sLine_iZheSgqy);
  numBytes += sLine_init(&sLine_WiClOoou);
  numBytes += sLine_init(&sLine_3hLgWrox);
  numBytes += sLine_init(&sLine_WVfGqVX0);
  numBytes += sLine_init(&sLine_epeDfFTl);
  numBytes += sLine_init(&sLine_pAzKTcwn);
  numBytes += sLine_init(&sLine_qi29mgPh);
  numBytes += sLine_init(&sLine_oK3ouDb7);
  numBytes += sLine_init(&sLine_dJlozWy7);
  numBytes += sLine_init(&sLine_ngbSHQhy);
  numBytes += sLine_init(&sLine_RpULlIeq);
  numBytes += sEnv_init(&sEnv_sPKu9mgO, 512, 256);
  numBytes += sEnv_init(&sEnv_ubATTlpE, 512, 256);
  numBytes += sLine_init(&sLine_ooHmc5n6);
  numBytes += sLine_init(&sLine_fYxkiR48);
  numBytes += sLine_init(&sLine_9I1zi2Zk);
  numBytes += sLine_init(&sLine_95mY20Hw);
  numBytes += sLine_init(&sLine_TJ9q0kzw);
  numBytes += sLine_init(&sLine_JCRjLcqj);
  numBytes += cVar_init_f(&cVar_SkuXN42G, 0.0f);
  numBytes += cVar_init_f(&cVar_uJsLa4rX, 0.0f);
  numBytes += cVar_init_f(&cVar_2gcvKABU, 0.0f);
  numBytes += cVar_init_f(&cVar_zpOI3hT6, 0.0f);
  numBytes += cVar_init_f(&cVar_Xyw8bzAI, 0.0f);
  numBytes += cVar_init_f(&cVar_4GSgR6Hj, 1.0f);
  numBytes += cVar_init_f(&cVar_Hjjj7Gkl, 0.0f);
  numBytes += cVar_init_f(&cVar_dOisNT3F, 0.0f);
  numBytes += cVar_init_f(&cVar_cSv0eSaA, 0.0f);
  numBytes += cVar_init_f(&cVar_41T1P0MT, 0.0f);
  numBytes += cSlice_init(&cSlice_xATTgOGW, 1, -1);
  numBytes += cVar_init_f(&cVar_vXswbp7G, 1337.0f);
  numBytes += cVar_init_f(&cVar_s0DtSXmq, 0.0f);
  numBytes += cIf_init(&cIf_pnZuN4Pz, false);
  numBytes += cIf_init(&cIf_BavTpePu, false);
  numBytes += cBinop_init(&cBinop_pg8HLkb5, 0.0f); // __pow
  numBytes += cIf_init(&cIf_bk7ESpmF, false);
  numBytes += cBinop_init(&cBinop_LJkyeNIQ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_fRplhASY, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_6BbbTg2Q, 0.0f);
  numBytes += cIf_init(&cIf_YF7fZQPI, false);
  numBytes += cIf_init(&cIf_6YSa8fqh, false);
  numBytes += cBinop_init(&cBinop_uPfjIP7x, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Hb0CtREM, false);
  numBytes += cBinop_init(&cBinop_PI602Cv7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8ydYRDGa, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_S4P4lcf7, 0.0f);
  numBytes += cIf_init(&cIf_U3zFWP0W, false);
  numBytes += cIf_init(&cIf_HvWY9sJW, false);
  numBytes += cBinop_init(&cBinop_c7P9gKZH, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ss5kAQ6S, false);
  numBytes += cBinop_init(&cBinop_bOlgInDB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_EcwF3NQe, -15.0f); // __eq
  numBytes += cIf_init(&cIf_XFAG4AY6, false);
  numBytes += cSlice_init(&cSlice_ijFyqL49, 1, -1);
  numBytes += cVar_init_f(&cVar_MjOS9zGe, 0.0f);
  numBytes += cSlice_init(&cSlice_rU5MIj7O, 1, -1);
  numBytes += cVar_init_f(&cVar_7PJXTgPc, 0.0f);
  numBytes += cSlice_init(&cSlice_e98Y68Ke, 1, -1);
  numBytes += cVar_init_f(&cVar_jX0ERHxB, 0.0f);
  numBytes += cSlice_init(&cSlice_kWPQyVZ1, 1, -1);
  numBytes += cVar_init_f(&cVar_yOAtbf1e, 0.313f);
  numBytes += cBinop_init(&cBinop_55GRQzGz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_P6UI7xpS, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_domoguBz, 0.0f);
  numBytes += cVar_init_f(&cVar_rSaP5Oj9, 1337.0f);
  numBytes += cVar_init_f(&cVar_OvyC4f6y, 0.3f);
  numBytes += cBinop_init(&cBinop_5m5Wgqrz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yGrp55kt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4sE1sQfJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TG8SqWe9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gad6ySIp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L9tJn8k1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DNw8EPtK, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_RmaKdLeh, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aOAuIYeV, 0.0f);
  numBytes += cVar_init_f(&cVar_afI0yXk5, 1337.0f);
  numBytes += cVar_init_f(&cVar_RHC5YGr0, 0.313f);
  numBytes += cBinop_init(&cBinop_VmQgOBYF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HC1SlKxu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rDBmuGrJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kCA3Z3VI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MwnZVMy9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LSEjh1uE, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_OLEo28i3, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_spyRH8pQ, 0.0f);
  numBytes += cVar_init_f(&cVar_JC1bABvF, 1037.0f);
  numBytes += cVar_init_f(&cVar_19rYGSbo, 0.4f);
  numBytes += cBinop_init(&cBinop_uUKtEod4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_j3i6VK5x, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iQMR7jim, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_G18zNitn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_raDD9ZQe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wcfkEwvo, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_2VJHCtpi, 1, -1);
  numBytes += cVar_init_f(&cVar_FvyrLmTE, 1337.0f);
  numBytes += cVar_init_f(&cVar_gzQ2LRNY, 0.0f);
  numBytes += cIf_init(&cIf_dm1Bwonh, false);
  numBytes += cIf_init(&cIf_HiGqmY2R, false);
  numBytes += cBinop_init(&cBinop_UwraAuBL, 0.0f); // __pow
  numBytes += cIf_init(&cIf_93trXGI8, false);
  numBytes += cBinop_init(&cBinop_IVItAYld, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_foYYzKNw, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_flLMe8XE, 0.0f);
  numBytes += cIf_init(&cIf_VabdDMfz, false);
  numBytes += cIf_init(&cIf_BcShZzz7, false);
  numBytes += cBinop_init(&cBinop_mYGwEWl8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_wPa2Ee9Y, false);
  numBytes += cBinop_init(&cBinop_DNXim1NI, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_QoazAXRM, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Wjupj4pL, 0.0f);
  numBytes += cIf_init(&cIf_kiA35Ncm, false);
  numBytes += cIf_init(&cIf_DlJck292, false);
  numBytes += cBinop_init(&cBinop_OHq7w2lP, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Wkdfg6cc, false);
  numBytes += cBinop_init(&cBinop_6Y03BWZ5, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_tA9xpZYS, -15.0f); // __eq
  numBytes += cIf_init(&cIf_deDUVDjr, false);
  numBytes += cSlice_init(&cSlice_COf6yhOy, 1, -1);
  numBytes += cVar_init_f(&cVar_YDP0k7AN, 0.0f);
  numBytes += cSlice_init(&cSlice_NtESeyTN, 1, -1);
  numBytes += cVar_init_f(&cVar_4CeHcXc0, 0.0f);
  numBytes += cSlice_init(&cSlice_kjyVkAVM, 1, -1);
  numBytes += cVar_init_f(&cVar_6b0EHiqE, 0.0f);
  numBytes += cSlice_init(&cSlice_td2PB9xi, 1, -1);
  numBytes += cVar_init_f(&cVar_t1AnaW3Q, 0.313f);
  numBytes += cBinop_init(&cBinop_KhJLSn8U, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sH7skcpm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZbOSXhdm, 0.0f);
  numBytes += cVar_init_f(&cVar_nXuPzEvr, 1337.0f);
  numBytes += cVar_init_f(&cVar_VHOIqA7Y, 0.3f);
  numBytes += cBinop_init(&cBinop_msvO6W7U, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PfCV1v0S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nVcGJ0ZH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iob2gDIv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6SEDxjYm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_o31MkgMQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_j6Q3R9ia, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_LcoRoVR2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_a3XsnOjg, 0.0f);
  numBytes += cVar_init_f(&cVar_kUZAMChw, 1337.0f);
  numBytes += cVar_init_f(&cVar_E0YFy6UL, 0.313f);
  numBytes += cBinop_init(&cBinop_qXgioyOo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3LEAu5Bb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_79B47L3B, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vQKBZMCN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oc6R38tc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EpS4SjhC, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_770zwUGE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bR93fS8q, 0.0f);
  numBytes += cVar_init_f(&cVar_uC3qg3Ta, 1037.0f);
  numBytes += cVar_init_f(&cVar_sm0mZmc5, 0.4f);
  numBytes += cBinop_init(&cBinop_ljHLgF4F, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L2KYDFHA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BwEPke3z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_v0KlHAKP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bS41TH9K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_z5ZWCgzs, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_om0lpqK3, 5705.6f);
  numBytes += cVar_init_f(&cVar_AQVkZflm, 313.3f);
  numBytes += cBinop_init(&cBinop_T1pfZXq3, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_P8LxCXas, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_FH6wKarX, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_3eND2rf4, 1, -1);
  numBytes += cVar_init_f(&cVar_W8z6vecT, 0.5f);
  numBytes += cVar_init_f(&cVar_faZ6EUdk, 0.0f);
  numBytes += cVar_init_f(&cVar_3ZUY5rtM, 0.0f);
  numBytes += cIf_init(&cIf_rZPZkBYe, false);
  numBytes += cIf_init(&cIf_nrXq1pId, false);
  numBytes += cDelay_init(this, &cDelay_xL1cimJa, 10.0f);
  numBytes += cIf_init(&cIf_qBqUbyvf, false);
  numBytes += cIf_init(&cIf_joUq5Dg8, false);
  numBytes += cDelay_init(this, &cDelay_uiVZVRSd, 10.0f);
  numBytes += cIf_init(&cIf_aCQNy187, false);
  numBytes += cIf_init(&cIf_IiP5H2MN, false);
  numBytes += cDelay_init(this, &cDelay_IUJu461L, 10.0f);
  numBytes += cIf_init(&cIf_w4upmWr1, false);
  numBytes += cIf_init(&cIf_VMBLhdTF, false);
  numBytes += cDelay_init(this, &cDelay_5d88VEFO, 10.0f);
  numBytes += cIf_init(&cIf_RXPVmfrS, false);
  numBytes += cIf_init(&cIf_BjWkBQKp, false);
  numBytes += cDelay_init(this, &cDelay_ghD3M5nq, 10.0f);
  numBytes += cIf_init(&cIf_gH8xkWa4, false);
  numBytes += cIf_init(&cIf_xBd9cXju, false);
  numBytes += cDelay_init(this, &cDelay_GJ0hf4gK, 10.0f);
  numBytes += cIf_init(&cIf_urSupkEr, false);
  numBytes += cIf_init(&cIf_d4MZwD38, false);
  numBytes += cDelay_init(this, &cDelay_f6CvEkvi, 10.0f);
  numBytes += cIf_init(&cIf_m2kQ7kDd, false);
  numBytes += cIf_init(&cIf_llQsnpYS, false);
  numBytes += cDelay_init(this, &cDelay_sNEuETOi, 10.0f);
  numBytes += cIf_init(&cIf_zTkDCWhg, false);
  numBytes += cIf_init(&cIf_n0joCUc6, false);
  numBytes += cDelay_init(this, &cDelay_tMfXYhXj, 10.0f);
  numBytes += cIf_init(&cIf_RjQVFPMQ, false);
  numBytes += cIf_init(&cIf_1JPhumj8, false);
  numBytes += cDelay_init(this, &cDelay_NAEiPiYB, 10.0f);
  numBytes += cIf_init(&cIf_zkFuNTwG, false);
  numBytes += cIf_init(&cIf_yw4unP2m, false);
  numBytes += cDelay_init(this, &cDelay_kPFs8OsT, 10.0f);
  numBytes += cIf_init(&cIf_4qRB0p9V, false);
  numBytes += cIf_init(&cIf_lu7S16iF, false);
  numBytes += cDelay_init(this, &cDelay_Ma4Mo2fd, 10.0f);
  numBytes += sVarf_init(&sVarf_OeThDu7x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XvX0DP4T, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XknWIf2A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y57SgT2f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8JCjcEg0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LOndclkB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_95TtqOFu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IMBMYOIg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6ARbiM1H, 0.0f);
  numBytes += cSlice_init(&cSlice_szjMbTXU, 1, -1);
  numBytes += cVar_init_f(&cVar_s1PGAgDC, 1.0f);
  numBytes += cSlice_init(&cSlice_yt1KEm5e, 1, -1);
  numBytes += cVar_init_f(&cVar_F4e1gTeM, 0.0f);
  numBytes += cSlice_init(&cSlice_2T4Uzhhe, 1, -1);
  numBytes += cVar_init_f(&cVar_oPv3OGDS, 512.0f);
  numBytes += cSlice_init(&cSlice_GFPEUSRv, 1, -1);
  numBytes += cVar_init_f(&cVar_Lor68x1Q, 1.0f);
  numBytes += cSlice_init(&cSlice_46NNMAJQ, 1, -1);
  numBytes += cVar_init_f(&cVar_fjwMo5Md, 1.0f);
  numBytes += cDelay_init(this, &cDelay_7QEbly5M, 20.0f);
  numBytes += cVar_init_f(&cVar_9oNyGt2L, 0.0f);
  numBytes += cIf_init(&cIf_od9GEpez, false);
  numBytes += cIf_init(&cIf_UcZ1ughr, false);
  numBytes += cBinop_init(&cBinop_HvB7Squ3, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_5EJnJL20, 1, -1);
  numBytes += cVar_init_f(&cVar_Jw7t1KrR, 0.0f);
  numBytes += sVarf_init(&sVarf_ExdiaC29, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OZM9WAwd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hVBRXm4G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0kIcHBaa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2CkmCKc6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dx4aErxA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_UO5nSCrF, 0.0f);
  numBytes += cVar_init_f(&cVar_0EbCbiso, 0.0f);
  numBytes += cIf_init(&cIf_zCnltwqn, false);
  numBytes += cIf_init(&cIf_7qGGY6pB, false);
  numBytes += cDelay_init(this, &cDelay_TtE5ooxF, 10.0f);
  numBytes += cIf_init(&cIf_Sqdoqvmf, false);
  numBytes += cIf_init(&cIf_zXymloa8, false);
  numBytes += cDelay_init(this, &cDelay_5TyKpITm, 10.0f);
  numBytes += cIf_init(&cIf_gtCX2lBF, false);
  numBytes += cIf_init(&cIf_GlLtXK4z, false);
  numBytes += cDelay_init(this, &cDelay_pOVJOXCs, 10.0f);
  numBytes += cIf_init(&cIf_zp0fCLDd, false);
  numBytes += cIf_init(&cIf_YMWJSu4A, false);
  numBytes += cDelay_init(this, &cDelay_J473aMcz, 10.0f);
  numBytes += cIf_init(&cIf_U1CGVWlp, false);
  numBytes += cIf_init(&cIf_SUNsmsdJ, false);
  numBytes += cDelay_init(this, &cDelay_woTVaoDn, 10.0f);
  numBytes += cIf_init(&cIf_jZAhw5AC, false);
  numBytes += cIf_init(&cIf_EeReahtF, false);
  numBytes += cDelay_init(this, &cDelay_oP6ZzBJ2, 10.0f);
  numBytes += cIf_init(&cIf_nboBnz8K, false);
  numBytes += cIf_init(&cIf_nhgpSxVq, false);
  numBytes += cDelay_init(this, &cDelay_RH6gkcFj, 10.0f);
  numBytes += cIf_init(&cIf_i7kJz4MF, false);
  numBytes += cIf_init(&cIf_rr453G9Y, false);
  numBytes += cDelay_init(this, &cDelay_IZQevzEx, 10.0f);
  numBytes += cIf_init(&cIf_OlbVMSsI, false);
  numBytes += cIf_init(&cIf_2gSALixr, false);
  numBytes += cDelay_init(this, &cDelay_MqqZ9zNi, 10.0f);
  numBytes += cIf_init(&cIf_WjQWQyAa, false);
  numBytes += cIf_init(&cIf_KwfzzepX, false);
  numBytes += cDelay_init(this, &cDelay_BmbMqJrL, 10.0f);
  numBytes += cIf_init(&cIf_69B7bNBq, false);
  numBytes += cIf_init(&cIf_TMoUevPH, false);
  numBytes += cDelay_init(this, &cDelay_MTUnsGSE, 10.0f);
  numBytes += cIf_init(&cIf_OdySkh0w, false);
  numBytes += cIf_init(&cIf_kyJelErj, false);
  numBytes += cDelay_init(this, &cDelay_P7lGCPUB, 10.0f);
  numBytes += sVarf_init(&sVarf_ShpDAYKz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qzxQEqsb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yBlBBiOQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B5XRbvMj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pA0lRah3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_u14jmybK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_88CCVbw4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S0lqDWzV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_O1R7IVBh, 0.0f);
  numBytes += cSlice_init(&cSlice_Pb7bexez, 1, -1);
  numBytes += cVar_init_f(&cVar_iBNn5ckW, 1.0f);
  numBytes += cSlice_init(&cSlice_mFvMQJ40, 1, -1);
  numBytes += cVar_init_f(&cVar_NwxnDSmH, 0.0f);
  numBytes += cSlice_init(&cSlice_faT7fuze, 1, -1);
  numBytes += cVar_init_f(&cVar_g8tNmKsh, 512.0f);
  numBytes += cSlice_init(&cSlice_6UYS1LrN, 1, -1);
  numBytes += cVar_init_f(&cVar_9UOxWWwP, 1.0f);
  numBytes += cSlice_init(&cSlice_gfoaeLXd, 1, -1);
  numBytes += cVar_init_f(&cVar_yaeEgAZP, 1.0f);
  numBytes += cDelay_init(this, &cDelay_rfOgalhJ, 20.0f);
  numBytes += cVar_init_f(&cVar_HE6nO6UW, 0.0f);
  numBytes += cIf_init(&cIf_VEvNRyfy, false);
  numBytes += cIf_init(&cIf_KJBlkulu, false);
  numBytes += cBinop_init(&cBinop_UujdfMmp, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_BD2EByby, 1, -1);
  numBytes += cVar_init_f(&cVar_A2sS1xOo, 0.0f);
  numBytes += sVarf_init(&sVarf_lqdcecXa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qCoLmusq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bR6c2Di2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TqvJawLR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9di6zYGx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aBJrg6Oc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZZl5dmbC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X844x2ZN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WSjIvhTN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DG1clAzq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_umAP1ILs, 0.0f);
  numBytes += cVar_init_f(&cVar_Zuv3wBvS, 0.0f);
  numBytes += cVar_init_f(&cVar_An4hjZTa, 0.0f);
  numBytes += cVar_init_f(&cVar_5k49lYlX, 0.0f);
  numBytes += cVar_init_f(&cVar_cvRZM7dw, 0.0f);
  numBytes += cVar_init_f(&cVar_Iiby1YWS, 1.0f);
  numBytes += cSlice_init(&cSlice_xsjDchXw, 1, -1);
  numBytes += cVar_init_f(&cVar_lPSpx9PB, 0.5f);
  numBytes += cVar_init_f(&cVar_rOfM6v9x, 0.0f);
  numBytes += cVar_init_f(&cVar_N2s2pr8f, 0.0f);
  numBytes += cIf_init(&cIf_AEQ82mGn, false);
  numBytes += cIf_init(&cIf_Q5uq7DpR, false);
  numBytes += cDelay_init(this, &cDelay_9082iQtt, 10.0f);
  numBytes += cIf_init(&cIf_XY9h36C0, false);
  numBytes += cIf_init(&cIf_hxWQB3ZC, false);
  numBytes += cDelay_init(this, &cDelay_0MgV46Z2, 10.0f);
  numBytes += cIf_init(&cIf_g9Dedvue, false);
  numBytes += cIf_init(&cIf_qjAzY1FE, false);
  numBytes += cDelay_init(this, &cDelay_wRADg0UY, 10.0f);
  numBytes += cIf_init(&cIf_3dgfP4Qq, false);
  numBytes += cIf_init(&cIf_sTXeoL8B, false);
  numBytes += cDelay_init(this, &cDelay_Cqffm0lb, 10.0f);
  numBytes += cIf_init(&cIf_oH1U9KOz, false);
  numBytes += cIf_init(&cIf_t3EP04e8, false);
  numBytes += cDelay_init(this, &cDelay_O8bupDjz, 10.0f);
  numBytes += cIf_init(&cIf_sKbU2Ao0, false);
  numBytes += cIf_init(&cIf_6xwx0NYw, false);
  numBytes += cDelay_init(this, &cDelay_wdkRrTBM, 10.0f);
  numBytes += cIf_init(&cIf_YrPAfTKc, false);
  numBytes += cIf_init(&cIf_3Y66JFZ3, false);
  numBytes += cDelay_init(this, &cDelay_wzPEvjgL, 10.0f);
  numBytes += cIf_init(&cIf_LDZzyc3W, false);
  numBytes += cIf_init(&cIf_4FKuDM62, false);
  numBytes += cDelay_init(this, &cDelay_l3idUGzO, 10.0f);
  numBytes += cIf_init(&cIf_bmbxXUsw, false);
  numBytes += cIf_init(&cIf_LAtwhTOW, false);
  numBytes += cDelay_init(this, &cDelay_ErhMvv75, 10.0f);
  numBytes += cIf_init(&cIf_YLppH3aL, false);
  numBytes += cIf_init(&cIf_e1wIRMuy, false);
  numBytes += cDelay_init(this, &cDelay_fI5Q4QN5, 10.0f);
  numBytes += cIf_init(&cIf_nlvq0xow, false);
  numBytes += cIf_init(&cIf_OrISnqUR, false);
  numBytes += cDelay_init(this, &cDelay_BAYm9xn7, 10.0f);
  numBytes += cIf_init(&cIf_k3gqYIte, false);
  numBytes += cIf_init(&cIf_4G5Nt3iy, false);
  numBytes += cDelay_init(this, &cDelay_4dn0YQeG, 10.0f);
  numBytes += sVarf_init(&sVarf_4SG93k7D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dGVOgJc7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZosQzkjf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6WDpbRwq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fGNPXAgy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3wCQGagt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8mUt6gky, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_prcUgFkP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_R4aWj4R5, 0.0f);
  numBytes += cSlice_init(&cSlice_5KVMVSmf, 1, -1);
  numBytes += cVar_init_f(&cVar_o3BxUaNk, 1.0f);
  numBytes += cSlice_init(&cSlice_SnpfxD2M, 1, -1);
  numBytes += cVar_init_f(&cVar_sUtl7CNh, 0.0f);
  numBytes += cSlice_init(&cSlice_ADOb9MKK, 1, -1);
  numBytes += cVar_init_f(&cVar_Dh8Guek0, 512.0f);
  numBytes += cSlice_init(&cSlice_R8F0Po3E, 1, -1);
  numBytes += cVar_init_f(&cVar_LoqW4EPY, 1.0f);
  numBytes += cSlice_init(&cSlice_sE6N7cJ5, 1, -1);
  numBytes += cVar_init_f(&cVar_i9hEyMSL, 1.0f);
  numBytes += cDelay_init(this, &cDelay_q9dON1FH, 20.0f);
  numBytes += cVar_init_f(&cVar_CVVD1gDo, 0.0f);
  numBytes += cIf_init(&cIf_0W3TtCXC, false);
  numBytes += cIf_init(&cIf_i3vzggbM, false);
  numBytes += cBinop_init(&cBinop_0DooFNDo, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_1PkPXkMA, 1, -1);
  numBytes += cVar_init_f(&cVar_PetLlyWF, 0.0f);
  numBytes += sVarf_init(&sVarf_wiclSSgC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jXRomTnn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sxRrVfkm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F0bs1PCs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MRlNTXxU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IdaBpeE6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DcVn2d5N, 0.0f);
  numBytes += cVar_init_f(&cVar_8hkMbGJs, 0.0f);
  numBytes += cIf_init(&cIf_Gs03ZVh6, false);
  numBytes += cIf_init(&cIf_LeDjlmJx, false);
  numBytes += cDelay_init(this, &cDelay_AYUibBt5, 10.0f);
  numBytes += cIf_init(&cIf_q8TihbSV, false);
  numBytes += cIf_init(&cIf_goDZZJKi, false);
  numBytes += cDelay_init(this, &cDelay_GZf33aDM, 10.0f);
  numBytes += cIf_init(&cIf_QV7MQsJq, false);
  numBytes += cIf_init(&cIf_hRLlkKwJ, false);
  numBytes += cDelay_init(this, &cDelay_gYfhUSM8, 10.0f);
  numBytes += cIf_init(&cIf_b2rKToXh, false);
  numBytes += cIf_init(&cIf_JFyNgjIf, false);
  numBytes += cDelay_init(this, &cDelay_Fh2HaYbK, 10.0f);
  numBytes += cIf_init(&cIf_PsbIYKWb, false);
  numBytes += cIf_init(&cIf_SfRiob92, false);
  numBytes += cDelay_init(this, &cDelay_wZFSc2ia, 10.0f);
  numBytes += cIf_init(&cIf_Fz9iZt2E, false);
  numBytes += cIf_init(&cIf_3gNr59uG, false);
  numBytes += cDelay_init(this, &cDelay_0haWYZ33, 10.0f);
  numBytes += cIf_init(&cIf_cnrbjvXM, false);
  numBytes += cIf_init(&cIf_1BH4Ezgi, false);
  numBytes += cDelay_init(this, &cDelay_0qvUFvq7, 10.0f);
  numBytes += cIf_init(&cIf_emumqg22, false);
  numBytes += cIf_init(&cIf_Bq7u471k, false);
  numBytes += cDelay_init(this, &cDelay_sYLn6XTl, 10.0f);
  numBytes += cIf_init(&cIf_9P4oGQza, false);
  numBytes += cIf_init(&cIf_1SiX9hjg, false);
  numBytes += cDelay_init(this, &cDelay_4rYPuzP7, 10.0f);
  numBytes += cIf_init(&cIf_yntZjqAa, false);
  numBytes += cIf_init(&cIf_Zz7b1Yrc, false);
  numBytes += cDelay_init(this, &cDelay_2sYriDIu, 10.0f);
  numBytes += cIf_init(&cIf_dN4Od6dW, false);
  numBytes += cIf_init(&cIf_FZE15HHC, false);
  numBytes += cDelay_init(this, &cDelay_IxjM1C0E, 10.0f);
  numBytes += cIf_init(&cIf_CG42HSUW, false);
  numBytes += cIf_init(&cIf_8umYTvb3, false);
  numBytes += cDelay_init(this, &cDelay_4BaKOyFS, 10.0f);
  numBytes += sVarf_init(&sVarf_BetPxAwB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_n5tyFLhA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V3aHakud, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J2vTYnF3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JAPXPLVV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7hjksRKV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RKwgPg38, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sLctzEdm, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bLkseGDH, 0.0f);
  numBytes += cSlice_init(&cSlice_hXTz1ABP, 1, -1);
  numBytes += cVar_init_f(&cVar_PDdGidzx, 1.0f);
  numBytes += cSlice_init(&cSlice_5LV7DwKu, 1, -1);
  numBytes += cVar_init_f(&cVar_MZZHCzlw, 0.0f);
  numBytes += cSlice_init(&cSlice_stTI8Zk3, 1, -1);
  numBytes += cVar_init_f(&cVar_cS3lFCWw, 512.0f);
  numBytes += cSlice_init(&cSlice_DZcQTnxI, 1, -1);
  numBytes += cVar_init_f(&cVar_X11oOzSZ, 1.0f);
  numBytes += cSlice_init(&cSlice_3JmQvSjg, 1, -1);
  numBytes += cVar_init_f(&cVar_GM85VBZq, 1.0f);
  numBytes += cDelay_init(this, &cDelay_JagwMNw9, 20.0f);
  numBytes += cVar_init_f(&cVar_RjQsoxzy, 0.0f);
  numBytes += cIf_init(&cIf_ocPoBjns, false);
  numBytes += cIf_init(&cIf_eG0ON97L, false);
  numBytes += cBinop_init(&cBinop_KBSiokfF, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_FSFOJBxZ, 1, -1);
  numBytes += cVar_init_f(&cVar_Qt2vkRgU, 0.0f);
  numBytes += sVarf_init(&sVarf_zZjXv2uG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_z5GeY2SP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h8iJTmdX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LbIhn1e2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_25zR7owl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_37WMNZrg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gWkqP9St, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jeeuclHE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_i9sM1SQc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_derGQKYi, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_EGC51EDO, 0.0f);
  numBytes += cVar_init_f(&cVar_Z5WewmxS, 0.0f);
  numBytes += cVar_init_f(&cVar_znjcRjVy, 0.0f);
  numBytes += cVar_init_f(&cVar_ELsEM9M6, 0.0f);
  numBytes += cVar_init_f(&cVar_smfHHkgW, 0.0f);
  numBytes += cVar_init_f(&cVar_JLdQCMJJ, 1.0f);
  numBytes += cSlice_init(&cSlice_OCx7nA4n, 1, -1);
  numBytes += cVar_init_f(&cVar_1B2dBury, 0.5f);
  numBytes += cVar_init_f(&cVar_w8gIL8FX, 0.0f);
  numBytes += cVar_init_f(&cVar_sut06sUw, 0.0f);
  numBytes += cIf_init(&cIf_9tKQd3KG, false);
  numBytes += cIf_init(&cIf_xuQbgsSr, false);
  numBytes += cDelay_init(this, &cDelay_V8AVhcz0, 10.0f);
  numBytes += cIf_init(&cIf_HQniJE11, false);
  numBytes += cIf_init(&cIf_JT5YK775, false);
  numBytes += cDelay_init(this, &cDelay_XfNgmPtj, 10.0f);
  numBytes += cIf_init(&cIf_pfHtmWxd, false);
  numBytes += cIf_init(&cIf_oUjnr0of, false);
  numBytes += cDelay_init(this, &cDelay_RyssiktB, 10.0f);
  numBytes += cIf_init(&cIf_hnyfnwaI, false);
  numBytes += cIf_init(&cIf_2XC6qhC8, false);
  numBytes += cDelay_init(this, &cDelay_oZASpEX9, 10.0f);
  numBytes += cIf_init(&cIf_oqjNYPB5, false);
  numBytes += cIf_init(&cIf_8SCpKquy, false);
  numBytes += cDelay_init(this, &cDelay_IVikXT7N, 10.0f);
  numBytes += cIf_init(&cIf_ScXTvSbz, false);
  numBytes += cIf_init(&cIf_BYmAcvvb, false);
  numBytes += cDelay_init(this, &cDelay_mCqZ7Px6, 10.0f);
  numBytes += cIf_init(&cIf_rRbskevg, false);
  numBytes += cIf_init(&cIf_qHJOiPwR, false);
  numBytes += cDelay_init(this, &cDelay_g8GFWPaO, 10.0f);
  numBytes += cIf_init(&cIf_SjtMX6ie, false);
  numBytes += cIf_init(&cIf_oClkpwD9, false);
  numBytes += cDelay_init(this, &cDelay_00oanLG3, 10.0f);
  numBytes += cIf_init(&cIf_IHWxZJby, false);
  numBytes += cIf_init(&cIf_HAclVkRL, false);
  numBytes += cDelay_init(this, &cDelay_MtOpQlNO, 10.0f);
  numBytes += cIf_init(&cIf_QIbFhJIL, false);
  numBytes += cIf_init(&cIf_zOsJyx2w, false);
  numBytes += cDelay_init(this, &cDelay_EVaU9APB, 10.0f);
  numBytes += cIf_init(&cIf_bKhpf6Jx, false);
  numBytes += cIf_init(&cIf_SLszZyGS, false);
  numBytes += cDelay_init(this, &cDelay_vJmYmDye, 10.0f);
  numBytes += cIf_init(&cIf_5mX2ArI5, false);
  numBytes += cIf_init(&cIf_CNyPVCiw, false);
  numBytes += cDelay_init(this, &cDelay_ULo6QypW, 10.0f);
  numBytes += sVarf_init(&sVarf_4IoYfFzJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FS7z3Svg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EI5p9koQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hVkn6xBE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jxDhnbSF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NDbIMnZ0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1FUPBahw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rq5NfA5X, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_4QNhStaO, 0.0f);
  numBytes += cSlice_init(&cSlice_k6UZEAXK, 1, -1);
  numBytes += cVar_init_f(&cVar_qzP4bGat, 1.0f);
  numBytes += cSlice_init(&cSlice_W3a4LvNm, 1, -1);
  numBytes += cVar_init_f(&cVar_SmbGZjaf, 0.0f);
  numBytes += cSlice_init(&cSlice_y60BcfGn, 1, -1);
  numBytes += cVar_init_f(&cVar_rGavTHPC, 512.0f);
  numBytes += cSlice_init(&cSlice_Q1iICSch, 1, -1);
  numBytes += cVar_init_f(&cVar_QbWn36HT, 1.0f);
  numBytes += cSlice_init(&cSlice_3zICmhCh, 1, -1);
  numBytes += cVar_init_f(&cVar_cZYTJsya, 1.0f);
  numBytes += cDelay_init(this, &cDelay_M54dt0d9, 20.0f);
  numBytes += cVar_init_f(&cVar_ItYIhR0T, 0.0f);
  numBytes += cIf_init(&cIf_hSNk0LfA, false);
  numBytes += cIf_init(&cIf_pxDcAnNn, false);
  numBytes += cBinop_init(&cBinop_buAeymWO, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_UWhvCNY3, 1, -1);
  numBytes += cVar_init_f(&cVar_y9Ic8F9C, 0.0f);
  numBytes += sVarf_init(&sVarf_0xi5CqHY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5BYYlVNZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2WNNUoVQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m06ewGta, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ATTUWutT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lu1Mfbj6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lLDvfCuW, 0.0f);
  numBytes += cVar_init_f(&cVar_xIVEoOiY, 0.0f);
  numBytes += cIf_init(&cIf_EGs2MKJq, false);
  numBytes += cIf_init(&cIf_meuowHOx, false);
  numBytes += cDelay_init(this, &cDelay_Vl5Ozy5a, 10.0f);
  numBytes += cIf_init(&cIf_qHaMXADt, false);
  numBytes += cIf_init(&cIf_9Lva9RF7, false);
  numBytes += cDelay_init(this, &cDelay_axqqacJr, 10.0f);
  numBytes += cIf_init(&cIf_avY7XTwE, false);
  numBytes += cIf_init(&cIf_YTGazUGY, false);
  numBytes += cDelay_init(this, &cDelay_tXCFi4wl, 10.0f);
  numBytes += cIf_init(&cIf_8WpWV7sO, false);
  numBytes += cIf_init(&cIf_zxOBxmfh, false);
  numBytes += cDelay_init(this, &cDelay_y7la9T5L, 10.0f);
  numBytes += cIf_init(&cIf_fK9mnZWb, false);
  numBytes += cIf_init(&cIf_hRfI5Qzs, false);
  numBytes += cDelay_init(this, &cDelay_eFv70F2N, 10.0f);
  numBytes += cIf_init(&cIf_lG0MlHE3, false);
  numBytes += cIf_init(&cIf_peUIsEBB, false);
  numBytes += cDelay_init(this, &cDelay_EEx3mr23, 10.0f);
  numBytes += cIf_init(&cIf_4ejsRWQT, false);
  numBytes += cIf_init(&cIf_YC11MnOP, false);
  numBytes += cDelay_init(this, &cDelay_cbrGhbED, 10.0f);
  numBytes += cIf_init(&cIf_JZssd5F9, false);
  numBytes += cIf_init(&cIf_tbRq2Yir, false);
  numBytes += cDelay_init(this, &cDelay_uCuUXqpg, 10.0f);
  numBytes += cIf_init(&cIf_uTJdpVMb, false);
  numBytes += cIf_init(&cIf_wh8w6HlN, false);
  numBytes += cDelay_init(this, &cDelay_xu2wwxD5, 10.0f);
  numBytes += cIf_init(&cIf_RXHenqf9, false);
  numBytes += cIf_init(&cIf_wGEVmMbT, false);
  numBytes += cDelay_init(this, &cDelay_1xFYJelr, 10.0f);
  numBytes += cIf_init(&cIf_k5gSxk7Z, false);
  numBytes += cIf_init(&cIf_Tag13p41, false);
  numBytes += cDelay_init(this, &cDelay_cvUGMh7r, 10.0f);
  numBytes += cIf_init(&cIf_D8uYsz5R, false);
  numBytes += cIf_init(&cIf_lPdOPQPO, false);
  numBytes += cDelay_init(this, &cDelay_SlBAmC8o, 10.0f);
  numBytes += sVarf_init(&sVarf_z8kMulaZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6lmF587D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dj8JBq9i, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ppLw72a2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dVcBLyzG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e42Xc7Vu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FwKB29b3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_69eazwhA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_No85xWgj, 0.0f);
  numBytes += cSlice_init(&cSlice_Te2wSBeM, 1, -1);
  numBytes += cVar_init_f(&cVar_8NjuvYf4, 1.0f);
  numBytes += cSlice_init(&cSlice_Bf6pzDH6, 1, -1);
  numBytes += cVar_init_f(&cVar_RLLfYlu2, 0.0f);
  numBytes += cSlice_init(&cSlice_RcwEkOXm, 1, -1);
  numBytes += cVar_init_f(&cVar_p5Z3NStQ, 512.0f);
  numBytes += cSlice_init(&cSlice_UVfnKGIx, 1, -1);
  numBytes += cVar_init_f(&cVar_GDN57tMl, 1.0f);
  numBytes += cSlice_init(&cSlice_d5o7Jbri, 1, -1);
  numBytes += cVar_init_f(&cVar_sSWWn5wD, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Im76m92h, 20.0f);
  numBytes += cVar_init_f(&cVar_Z9MgKsEk, 0.0f);
  numBytes += cIf_init(&cIf_yPH8owPy, false);
  numBytes += cIf_init(&cIf_FfRro8ZL, false);
  numBytes += cBinop_init(&cBinop_S6TSI3t9, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_x0lApO6w, 1, -1);
  numBytes += cVar_init_f(&cVar_X1Gb7C1p, 0.0f);
  numBytes += sVarf_init(&sVarf_RPaHVCGC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RFHMGAVa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MenJlcB4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ccrDZwSY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TDF0yw69, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QyWbtUyd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rtmMlI3K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ov2vUpd0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sdcgtbQ1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xf9ed4rW, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FlBWNvIG, 0.0f);
  numBytes += cVar_init_f(&cVar_EpyIgzyu, 0.0f);
  numBytes += cVar_init_f(&cVar_E5FbYGVI, 0.0f);
  numBytes += sVarf_init(&sVarf_8WjuLJOs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6WxNejch, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b8rowDHu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UXMKkb6N, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KSvbZcpv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EDfGSRwX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cf85iq98, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GlNrK1BO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lwBamMYy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l3mZQs0V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EmFOTdUR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_53dYSyA0, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_8OdsCRrA);
  sEnv_free(&sEnv_oxk4RKer);
  sEnv_free(&sEnv_TgHdAcS9);
  sEnv_free(&sEnv_xECpFu9h);
  sEnv_free(&sEnv_TH3MPeU9);
  sEnv_free(&sEnv_gRDr9mRZ);
  sEnv_free(&sEnv_6hbp07Ll);
  sEnv_free(&sEnv_s06cSl1I);
  sEnv_free(&sEnv_9A6aXtWA);
  sEnv_free(&sEnv_Gi9Jylt3);
  sEnv_free(&sEnv_sPKu9mgO);
  sEnv_free(&sEnv_ubATTlpE);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XCMcSpJ1_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HOTMUMc8_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_heY7iPyM_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hvTGP8C6_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8KbvQSEV_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SPSVsmUw_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HBbC0R7p_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HWsD1rhS_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UvAqxm2t_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yC9OirOK_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Wxqj7Ii7_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SBO1dMRH_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h5X2g9Uk_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v8BPPn2y_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VOQxzy0O_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6Ftahr6P_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WUjbZFH7_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pUMO7fQg_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b0WYLfNn_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RQOWEQSM_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gGlGXYVO_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4LSgttPq_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_POzJSvAK_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1iCP1ZEg_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_epzOUEev_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HVeCv9on_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_egtGvsJj_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r7idC7W3_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_USYw6nPV_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_naTGkfxT_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UPIxNqHF_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kW1nJCHc_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iAOxQtby_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sl1p4AoA_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jzQpgH5N_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IBnKJRJX_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cjGoT0BC_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YZGVBl4x_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gybXrlge_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Lg9ipFnK_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vwq33LNP_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ie4CVbv1_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kotBGMIk_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qqXR0VGw_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j7BlqcpF_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hWD0BHml_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sSvvou17_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fpJAUlu6_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F7ctwigV_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wBWL47rm_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ph6SEXjF_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dp2LASle_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2p5VN6LX_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_clL3NmGi_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VpOocFHH_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_29iqfHLq_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bsQ6wNtT_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dxezpwfZ_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LDbKEa4z_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VtWR25EE_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gt3Vq36Y_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jlP8cUPj_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w1RKZsje_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JrZy6zSo_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yvG6sply_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ayjhjz9g_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AEbFepGH_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ytQL2yiy_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fjK0FJpF_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KoCGRNzx_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U3MInDzn_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jk0rvQSg_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RNn1EDOK_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wB8kp16t_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HjibjBdg_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nZmUCc3U_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1V5Urq4x_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cSklG3t5_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UfK0arfv_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HMIW50Tt_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DP6ysMyI_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_py99zrKG_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eDSCalQF_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZLoTblXc_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pi2tDx37_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r93Y1Obq_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HyhH1HIW_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FLUFw3c6_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CSHBHJHF_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VBoL81hq_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cdQR7lvR_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YrkN7vI2_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NMWnsYai_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_SkuXN42G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZJ2NWrJq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_uJsLa4rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iu1uKzNI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2gcvKABU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wWERAUO5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_zpOI3hT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HgYiiCKO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Xyw8bzAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RVlJJgdY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4GSgR6Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8sL8oa5t_sendMessage);
  cMsg_0N0kTBUn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8sL8oa5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4GSgR6Hj, 1, m, &cVar_4GSgR6Hj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MAbeLRlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_glx1Jg8o_sendMessage(_c, 0, m);
  cMsg_pB5ajQEq_sendMessage(_c, 0, m);
  cMsg_vsnTlIAx_sendMessage(_c, 0, m);
  cMsg_zoNRNyRx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Hjjj7Gkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xAnnlaSo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dOisNT3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hwgIqjna_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cSv0eSaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yx6W0TJO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_41T1P0MT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nQo5fOFp_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kLoPuvCT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x2O5SFp6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A27HdRE7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nK1rqr4E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xATTgOGW, 0, m, &cSlice_xATTgOGW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6LiLTmmH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xATTgOGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iifAO1sU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iifAO1sU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_vXswbp7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iifAO1sU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iifAO1sU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r7idC7W3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_s0DtSXmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HTrVTikn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_pnZuN4Pz, 0, m, &cIf_pnZuN4Pz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_pnZuN4Pz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_H8FEQwva_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BavTpePu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mpzLFmMr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_CM4whxC9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_4dlV5TAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pg8HLkb5, HV_BINOP_POW, 0, m, &cBinop_pg8HLkb5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pg8HLkb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bk7ESpmF, 0, m, &cIf_bk7ESpmF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bqj5bXxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_3jsFEjUo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MDn3kdA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BavTpePu, 0, m, &cIf_BavTpePu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5BPQCWSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5f2ioBxx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5f2ioBxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BavTpePu, 1, m, &cIf_BavTpePu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CM4whxC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_bqj5bXxK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mpzLFmMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_bk7ESpmF, 0, m, &cIf_bk7ESpmF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3jsFEjUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pg8HLkb5, HV_BINOP_POW, 1, m, &cBinop_pg8HLkb5_sendMessage);
  cMsg_4dlV5TAg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_bk7ESpmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bX4THJoN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_HTrVTikn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pnZuN4Pz, 1, m, &cIf_pnZuN4Pz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H8FEQwva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s2W8Nbw9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x6WQv59T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v4yVS1Vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5BPQCWSn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MDn3kdA5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LJkyeNIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bk7ESpmF, 1, m, &cIf_bk7ESpmF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fRplhASY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EzWXKZtP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EzWXKZtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_bX4THJoN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kbeDNKpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_v4yVS1Vx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x6WQv59T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LJkyeNIQ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_LJkyeNIQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s2W8Nbw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fRplhASY, HV_BINOP_EQ, 1, m, &cBinop_fRplhASY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LAlPKkvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LJkyeNIQ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_LJkyeNIQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wphm7wiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fRplhASY, HV_BINOP_EQ, 0, m, &cBinop_fRplhASY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wGvCHE2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kbeDNKpb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jzfWMajD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s0DtSXmq, 0, m, &cVar_s0DtSXmq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_6BbbTg2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wP48zUYo_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_YF7fZQPI, 0, m, &cIf_YF7fZQPI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_YF7fZQPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LnVhjQiX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6YSa8fqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kSust4W0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_4yIKkIsU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_Sbdi2H1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uPfjIP7x, HV_BINOP_POW, 0, m, &cBinop_uPfjIP7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uPfjIP7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hb0CtREM, 0, m, &cIf_Hb0CtREM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Sert0Qua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_KnTO0Lja_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pvslYbjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6YSa8fqh, 0, m, &cIf_6YSa8fqh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q1qqF6fF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2ZSFQYSa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2ZSFQYSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6YSa8fqh, 1, m, &cIf_6YSa8fqh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4yIKkIsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Sert0Qua_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kSust4W0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Hb0CtREM, 0, m, &cIf_Hb0CtREM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KnTO0Lja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uPfjIP7x, HV_BINOP_POW, 1, m, &cBinop_uPfjIP7x_sendMessage);
  cMsg_Sbdi2H1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Hb0CtREM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZxnzN2p6_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zzzTo2yB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_wP48zUYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YF7fZQPI, 1, m, &cIf_YF7fZQPI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LnVhjQiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kotCGuQH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gTgQfaG7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OFzwOgAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q1qqF6fF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pvslYbjc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PI602Cv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hb0CtREM, 1, m, &cIf_Hb0CtREM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8ydYRDGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UWjpWgx8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UWjpWgx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZxnzN2p6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zzzTo2yB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JNSRMU9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_OFzwOgAA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gTgQfaG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PI602Cv7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_PI602Cv7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kotCGuQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ydYRDGa, HV_BINOP_EQ, 1, m, &cBinop_8ydYRDGa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SMU23zjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ydYRDGa, HV_BINOP_EQ, 0, m, &cBinop_8ydYRDGa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gcYmiYqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JNSRMU9k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_M4bWbYui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6BbbTg2Q, 0, m, &cVar_6BbbTg2Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_adtN093M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PI602Cv7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_PI602Cv7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_S4P4lcf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W4NxqaVL_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_U3zFWP0W, 0, m, &cIf_U3zFWP0W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_U3zFWP0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5TmfHbvS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HvWY9sJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7uGS5hXe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_as9S68sA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_pXbK25w1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_c7P9gKZH, HV_BINOP_POW, 0, m, &cBinop_c7P9gKZH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c7P9gKZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ss5kAQ6S, 0, m, &cIf_ss5kAQ6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rpYT3oIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_NiMNdW6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E8AuBuOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HvWY9sJW, 0, m, &cIf_HvWY9sJW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TnPIf6mM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1HW18xyB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1HW18xyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HvWY9sJW, 1, m, &cIf_HvWY9sJW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_as9S68sA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_rpYT3oIY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7uGS5hXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ss5kAQ6S, 0, m, &cIf_ss5kAQ6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NiMNdW6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c7P9gKZH, HV_BINOP_POW, 1, m, &cBinop_c7P9gKZH_sendMessage);
  cMsg_pXbK25w1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_ss5kAQ6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nIm9IILr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_W4NxqaVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U3zFWP0W, 1, m, &cIf_U3zFWP0W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5TmfHbvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PUmxJsZq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q6QOaoh0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HvgMQhg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TnPIf6mM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E8AuBuOg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bOlgInDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ss5kAQ6S, 1, m, &cIf_ss5kAQ6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EcwF3NQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kdqs1Nu1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kdqs1Nu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_nIm9IILr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xLO0I8Qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_HvgMQhg3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q6QOaoh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOlgInDB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bOlgInDB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PUmxJsZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EcwF3NQe, HV_BINOP_EQ, 1, m, &cBinop_EcwF3NQe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I3zjcxW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EcwF3NQe, HV_BINOP_EQ, 0, m, &cBinop_EcwF3NQe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8AknOgni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xLO0I8Qq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_DfcBn9bL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S4P4lcf7, 0, m, &cVar_S4P4lcf7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UZwHvfx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOlgInDB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bOlgInDB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_XFAG4AY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SU7phEsK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sZ1HaNjI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ijFyqL49, 0, m, &cSlice_ijFyqL49_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9m3TU7gb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ijFyqL49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mZvGyibG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mZvGyibG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MjOS9zGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mZvGyibG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mZvGyibG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HVeCv9on_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9m3TU7gb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rU5MIj7O, 0, m, &cSlice_rU5MIj7O_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nK1rqr4E_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_rU5MIj7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fZ70AxwG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fZ70AxwG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7PJXTgPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fZ70AxwG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fZ70AxwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_naTGkfxT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6LiLTmmH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_e98Y68Ke, 0, m, &cSlice_e98Y68Ke_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UvVNZGwG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_e98Y68Ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NJrngZMM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NJrngZMM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jX0ERHxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NJrngZMM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NJrngZMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_egtGvsJj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UvVNZGwG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kWPQyVZ1, 0, m, &cSlice_kWPQyVZ1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kWPQyVZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6CTteSwn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6CTteSwn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yOAtbf1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6CTteSwn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6CTteSwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_USYw6nPV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_loaERfKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sej1KvDv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g753LYf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dZ7n3rfQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vctTOWvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gl52Z6OQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PUY4Qfpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_53bw1hnb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rxXDVzqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lpjwtbeN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WIr7Pm0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sipKMg9z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_sipKMg9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_55GRQzGz, HV_BINOP_DIVIDE, 1, m, &cBinop_55GRQzGz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QVnwbKAa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_2rIEA4oS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_J6GUdsc4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ouViavA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_2rIEA4oS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J6GUdsc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_55GRQzGz, HV_BINOP_DIVIDE, 0, m, &cBinop_55GRQzGz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QVnwbKAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ouViavA7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_55GRQzGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P6UI7xpS, HV_BINOP_MULTIPLY, 1, m, &cBinop_P6UI7xpS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P6UI7xpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QHCKRWlA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ykzfzD8E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_itvYkUvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4e8vveZz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_CNli2XZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pGdEUwlJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BuVzwg02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_yNlenTgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yNlenTgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P6UI7xpS, HV_BINOP_MULTIPLY, 0, m, &cBinop_P6UI7xpS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jQvT6mqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_XEfdJyMF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XEfdJyMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pK4MbAby_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5ETRQ4TR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_domoguBz, 1, m, &cVar_domoguBz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_domoguBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KrbJl1cR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pQVuNhSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yGrp55kt, HV_BINOP_MULTIPLY, 1, m, &cBinop_yGrp55kt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1DPSkuRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pQVuNhSH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z61vLivR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_G4l123fM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G4l123fM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4sE1sQfJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_4sE1sQfJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3nu6LzMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TG8SqWe9, HV_BINOP_MULTIPLY, 1, m, &cBinop_TG8SqWe9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F4nrdSte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3nu6LzMq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NfhtF3Wt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gad6ySIp, HV_BINOP_MULTIPLY, 1, m, &cBinop_gad6ySIp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W6kBMTFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NFXo5XUL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NFXo5XUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9tJn8k1, HV_BINOP_MULTIPLY, 1, m, &cBinop_L9tJn8k1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_rSaP5Oj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_65O9vJrE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_BuVzwg02_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6egR7T5N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_OvyC4f6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_jQvT6mqY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ykzfzD8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_CNli2XZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QHCKRWlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_itvYkUvR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_4e8vveZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iAOxQtby_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pGdEUwlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kW1nJCHc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_darPd35l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UPIxNqHF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pK4MbAby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kYC284Xl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kYC284Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5m5Wgqrz, HV_BINOP_MULTIPLY, 1, m, &cBinop_5m5Wgqrz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5m5Wgqrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_INwIa5sh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_INwIa5sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_darPd35l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KrbJl1cR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TRt5AJNl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TRt5AJNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q4MB6R6s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_htNwqy3L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aHDBcBM1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cTk66mCX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6v7cRhWi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Saf09iDa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yGrp55kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_loaERfKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4sE1sQfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g753LYf4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TG8SqWe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vctTOWvR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gad6ySIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PUY4Qfpr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_L9tJn8k1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rxXDVzqM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_HACeHoRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rSaP5Oj9, 0, m, &cVar_rSaP5Oj9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZSwzGNSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OvyC4f6y, 1, m, &cVar_OvyC4f6y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Saf09iDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yGrp55kt, HV_BINOP_MULTIPLY, 0, m, &cBinop_yGrp55kt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aHDBcBM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gad6ySIp, HV_BINOP_MULTIPLY, 0, m, &cBinop_gad6ySIp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6v7cRhWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4sE1sQfJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_4sE1sQfJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_htNwqy3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9tJn8k1, HV_BINOP_MULTIPLY, 0, m, &cBinop_L9tJn8k1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cTk66mCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TG8SqWe9, HV_BINOP_MULTIPLY, 0, m, &cBinop_TG8SqWe9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q4MB6R6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_6egR7T5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_domoguBz, 0, m, &cVar_domoguBz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_65O9vJrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OvyC4f6y, 0, m, &cVar_OvyC4f6y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4gUKsTrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3LTEDo4O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PsF0QgA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lfN5ZIzu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cVNpi5FV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZZqkUpdO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Vx7oD3Gu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sGntX5nh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EH55aeaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yOueXST7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_yOueXST7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DNw8EPtK, HV_BINOP_DIVIDE, 1, m, &cBinop_DNw8EPtK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9d4xBBLS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_INDjdUCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_tPXU8rAv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N0Ggxn3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_INDjdUCn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tPXU8rAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DNw8EPtK, HV_BINOP_DIVIDE, 0, m, &cBinop_DNw8EPtK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9d4xBBLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N0Ggxn3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_DNw8EPtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RmaKdLeh, HV_BINOP_MULTIPLY, 1, m, &cBinop_RmaKdLeh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RmaKdLeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6TBxXp4E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_alVymDjL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_o08M6Ech_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qh0ncBfR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_TvFDL03W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wqr9DXlO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sExn2luF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Frxnj0LH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Frxnj0LH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RmaKdLeh, HV_BINOP_MULTIPLY, 0, m, &cBinop_RmaKdLeh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oo5AwNiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_tnAoRy68_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tnAoRy68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V3mZsulu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_XzrSoyis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rDBmuGrJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_rDBmuGrJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_12OsfzPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aOAuIYeV, 1, m, &cVar_aOAuIYeV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_91GDms9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kCA3Z3VI, HV_BINOP_MULTIPLY, 1, m, &cBinop_kCA3Z3VI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KNo1ZS7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IH8EtDVT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IH8EtDVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MwnZVMy9, HV_BINOP_MULTIPLY, 1, m, &cBinop_MwnZVMy9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_aOAuIYeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wklv8Iwx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_afI0yXk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bx7C9n7H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_sExn2luF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BmPbFeYW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_RHC5YGr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oo5AwNiN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_alVymDjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TvFDL03W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6TBxXp4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_o08M6Ech_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_qh0ncBfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IBnKJRJX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wqr9DXlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jzQpgH5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5TH0faey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Sl1p4AoA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_V3mZsulu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Ou2WymPX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ou2WymPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VmQgOBYF, HV_BINOP_MULTIPLY, 1, m, &cBinop_VmQgOBYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VmQgOBYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6d6xu4iV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6d6xu4iV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5TH0faey_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wklv8Iwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iCCQWbef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iCCQWbef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BzgfXO9e_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZrB8NNq0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nm9rntaJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KY3icrbH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HC1SlKxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4gUKsTrk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rDBmuGrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PsF0QgA2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kCA3Z3VI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cVNpi5FV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MwnZVMy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vx7oD3Gu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_mJ4mo5rW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RHC5YGr0, 1, m, &cVar_RHC5YGr0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bImcDVmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_afI0yXk5, 0, m, &cVar_afI0yXk5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bx7C9n7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RHC5YGr0, 0, m, &cVar_RHC5YGr0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BmPbFeYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aOAuIYeV, 0, m, &cVar_aOAuIYeV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZrB8NNq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kCA3Z3VI, HV_BINOP_MULTIPLY, 0, m, &cBinop_kCA3Z3VI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KY3icrbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HC1SlKxu, HV_BINOP_MULTIPLY, 0, m, &cBinop_HC1SlKxu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BzgfXO9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MwnZVMy9, HV_BINOP_MULTIPLY, 0, m, &cBinop_MwnZVMy9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nm9rntaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rDBmuGrJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_rDBmuGrJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4bwODBjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3QAlvVxT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_alVmF8oZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RtHfbkXF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sOLVYIlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Pr9RHTzh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_X0VmZeNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_npUChMq9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VFntXgYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2vnoandb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kHLtLbiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VeICt3if_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_VeICt3if_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LSEjh1uE, HV_BINOP_DIVIDE, 1, m, &cBinop_LSEjh1uE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_43hxucjj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_g6QWs8tl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_619tbqi9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aOwBOExS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_g6QWs8tl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_619tbqi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LSEjh1uE, HV_BINOP_DIVIDE, 0, m, &cBinop_LSEjh1uE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_43hxucjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aOwBOExS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LSEjh1uE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OLEo28i3, HV_BINOP_MULTIPLY, 1, m, &cBinop_OLEo28i3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OLEo28i3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RGVlXa3N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TPIB7Py3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_oYUjOoTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uY9dFVb0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_C8in54Mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9xTiIROw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2G6uYSEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_sdOqpOF9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sdOqpOF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OLEo28i3, HV_BINOP_MULTIPLY, 0, m, &cBinop_OLEo28i3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yofDFJsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LFo7C0QR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LFo7C0QR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sy7alKqF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lSgE881Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j3i6VK5x, HV_BINOP_MULTIPLY, 1, m, &cBinop_j3i6VK5x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R0zFAA39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QvqzMdPt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QvqzMdPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lSgE881Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YcxKIVrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Lf0p5TzZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lf0p5TzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iQMR7jim, HV_BINOP_MULTIPLY, 1, m, &cBinop_iQMR7jim_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bcorqVTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G18zNitn, HV_BINOP_MULTIPLY, 1, m, &cBinop_G18zNitn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BGrvaOXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_n5nlpd0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n5nlpd0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bcorqVTQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ob25paRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_spyRH8pQ, 1, m, &cVar_spyRH8pQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hqy14bjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_raDD9ZQe, HV_BINOP_MULTIPLY, 1, m, &cBinop_raDD9ZQe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kUYsYsWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FnfsBNFu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FnfsBNFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wcfkEwvo, HV_BINOP_MULTIPLY, 1, m, &cBinop_wcfkEwvo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_spyRH8pQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rcXJoD9A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_JC1bABvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ah2urkon_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_2G6uYSEK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1arUrbfs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_19rYGSbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_yofDFJsx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RGVlXa3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_oYUjOoTz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TPIB7Py3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_C8in54Mi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_uY9dFVb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gybXrlge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9xTiIROw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YZGVBl4x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3kFqZvUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cjGoT0BC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Sy7alKqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fIfNVi81_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fIfNVi81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uUKtEod4, HV_BINOP_MULTIPLY, 1, m, &cBinop_uUKtEod4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uUKtEod4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4vXFg6Ou_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4vXFg6Ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3kFqZvUV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rcXJoD9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kf75yPjK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kf75yPjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oYV4tAHl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PhU8SvDC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6w8ftpQE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EfxspTrU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rpg2Spui_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FBcvZFhe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j3i6VK5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4bwODBjX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_iQMR7jim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_alVmF8oZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_G18zNitn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sOLVYIlz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_raDD9ZQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X0VmZeNV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wcfkEwvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VFntXgYC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3ZBfUHA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JC1bABvF, 0, m, &cVar_JC1bABvF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_09DHCyfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_19rYGSbo, 1, m, &cVar_19rYGSbo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FBcvZFhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j3i6VK5x, HV_BINOP_MULTIPLY, 0, m, &cBinop_j3i6VK5x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6w8ftpQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_raDD9ZQe, HV_BINOP_MULTIPLY, 0, m, &cBinop_raDD9ZQe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rpg2Spui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iQMR7jim, HV_BINOP_MULTIPLY, 0, m, &cBinop_iQMR7jim_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PhU8SvDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wcfkEwvo, HV_BINOP_MULTIPLY, 0, m, &cBinop_wcfkEwvo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EfxspTrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G18zNitn, HV_BINOP_MULTIPLY, 0, m, &cBinop_G18zNitn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oYV4tAHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_1arUrbfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_spyRH8pQ, 0, m, &cVar_spyRH8pQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ah2urkon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_19rYGSbo, 0, m, &cVar_19rYGSbo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3fnLtkFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XFAG4AY6, 1, m, &cIf_XFAG4AY6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6Otww7Gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_SU7phEsK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vKhaYzOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Otww7Gh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uSBQN22i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XFAG4AY6, 0, m, &cIf_XFAG4AY6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bX4THJoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4r4wX7nS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SU7phEsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lntt1gKQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nIm9IILr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_afMLwezW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zzzTo2yB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_uSBQN22i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZxnzN2p6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3fnLtkFo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vKhaYzOw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P8pRpaOV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2VJHCtpi, 0, m, &cSlice_2VJHCtpi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_brGOnFbN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_2VJHCtpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_isGR0X3T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_isGR0X3T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_FvyrLmTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_isGR0X3T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_isGR0X3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ie4CVbv1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_gzQ2LRNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xVeI1tEz_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dm1Bwonh, 0, m, &cIf_dm1Bwonh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_dm1Bwonh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7EIojc9r_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HiGqmY2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_TLkHqEMw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uI1SRQwH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_pjXzHJ3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UwraAuBL, HV_BINOP_POW, 0, m, &cBinop_UwraAuBL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UwraAuBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_93trXGI8, 0, m, &cIf_93trXGI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XhEaN3dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Tjovwmyb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DFKDSfWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_71sW7o3Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ovXOV9uq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HiGqmY2R, 0, m, &cIf_HiGqmY2R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_71sW7o3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HiGqmY2R, 1, m, &cIf_HiGqmY2R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uI1SRQwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_XhEaN3dJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TLkHqEMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_93trXGI8, 0, m, &cIf_93trXGI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Tjovwmyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UwraAuBL, HV_BINOP_POW, 1, m, &cBinop_UwraAuBL_sendMessage);
  cMsg_pjXzHJ3q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_93trXGI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1wP3Ikfb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_xVeI1tEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dm1Bwonh, 1, m, &cIf_dm1Bwonh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7EIojc9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RIjlYg9T_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fNxznUyN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eLAgg2Pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DFKDSfWS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ovXOV9uq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IVItAYld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_93trXGI8, 1, m, &cIf_93trXGI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_foYYzKNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1o3L2q6A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1o3L2q6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_1wP3Ikfb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RjDnVcHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_eLAgg2Pe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RIjlYg9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_foYYzKNw, HV_BINOP_EQ, 1, m, &cBinop_foYYzKNw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fNxznUyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVItAYld, HV_BINOP_GREATER_THAN, 1, m, &cBinop_IVItAYld_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lo9Bb9Tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_foYYzKNw, HV_BINOP_EQ, 0, m, &cBinop_foYYzKNw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_P8YTOPUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RjDnVcHW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pUFbIULZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gzQ2LRNY, 0, m, &cVar_gzQ2LRNY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TxUrvScu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVItAYld, HV_BINOP_GREATER_THAN, 0, m, &cBinop_IVItAYld_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_flLMe8XE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DtvViRo9_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VabdDMfz, 0, m, &cIf_VabdDMfz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_VabdDMfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_31KiD0Ps_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BcShZzz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_4gDF94jD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_q24v78p7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_LP0tCRUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mYGwEWl8, HV_BINOP_POW, 0, m, &cBinop_mYGwEWl8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mYGwEWl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wPa2Ee9Y, 0, m, &cIf_wPa2Ee9Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qPaTUPqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_jyNrMNnL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F8qOuKdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BcShZzz7, 0, m, &cIf_BcShZzz7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kEm9o3ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ku0ujfca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ku0ujfca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BcShZzz7, 1, m, &cIf_BcShZzz7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q24v78p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_qPaTUPqI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4gDF94jD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_wPa2Ee9Y, 0, m, &cIf_wPa2Ee9Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jyNrMNnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mYGwEWl8, HV_BINOP_POW, 1, m, &cBinop_mYGwEWl8_sendMessage);
  cMsg_LP0tCRUq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_wPa2Ee9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MpO94ssg_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Q3BlMH7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_DtvViRo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VabdDMfz, 1, m, &cIf_VabdDMfz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_31KiD0Ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FihEChKw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yE6lAyIP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bwDAUcHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kEm9o3ur_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F8qOuKdq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DNXim1NI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wPa2Ee9Y, 1, m, &cIf_wPa2Ee9Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QoazAXRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sx4prvWb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sx4prvWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MpO94ssg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Q3BlMH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DpgPA44b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_bwDAUcHj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yE6lAyIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DNXim1NI, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DNXim1NI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FihEChKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QoazAXRM, HV_BINOP_EQ, 1, m, &cBinop_QoazAXRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OEe6sRg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DNXim1NI, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DNXim1NI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NfLCrbMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QoazAXRM, HV_BINOP_EQ, 0, m, &cBinop_QoazAXRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xuYHjr9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DpgPA44b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Ih92ZzFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_flLMe8XE, 0, m, &cVar_flLMe8XE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Wjupj4pL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KtvsSbef_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kiA35Ncm, 0, m, &cIf_kiA35Ncm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_kiA35Ncm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_67RPm39L_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DlJck292_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_2Dw3ujv7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_e6c2KqoC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_VUfWPK06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OHq7w2lP, HV_BINOP_POW, 0, m, &cBinop_OHq7w2lP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OHq7w2lP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wkdfg6cc, 0, m, &cIf_Wkdfg6cc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JNgoWVEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ZNavwu4R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fnxrYv3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Z4nMUyFx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0dFGazN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DlJck292, 0, m, &cIf_DlJck292_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z4nMUyFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DlJck292, 1, m, &cIf_DlJck292_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e6c2KqoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_JNgoWVEH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2Dw3ujv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Wkdfg6cc, 0, m, &cIf_Wkdfg6cc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZNavwu4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OHq7w2lP, HV_BINOP_POW, 1, m, &cBinop_OHq7w2lP_sendMessage);
  cMsg_VUfWPK06_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Wkdfg6cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HEkCMXKa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_KtvsSbef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kiA35Ncm, 1, m, &cIf_kiA35Ncm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_67RPm39L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hQNHixYS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nkC2firN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pUGaCH8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fnxrYv3z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0dFGazN8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6Y03BWZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wkdfg6cc, 1, m, &cIf_Wkdfg6cc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tA9xpZYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_11TBryoy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_11TBryoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_HEkCMXKa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HDdUaN1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_pUGaCH8c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nkC2firN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Y03BWZ5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_6Y03BWZ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hQNHixYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tA9xpZYS, HV_BINOP_EQ, 1, m, &cBinop_tA9xpZYS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x9IJpIHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HDdUaN1Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_CEwuWPlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wjupj4pL, 0, m, &cVar_Wjupj4pL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QHTUrtHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Y03BWZ5, HV_BINOP_GREATER_THAN, 0, m, &cBinop_6Y03BWZ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_myyka4Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tA9xpZYS, HV_BINOP_EQ, 0, m, &cBinop_tA9xpZYS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_deDUVDjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q3n03MbO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nrrTwxDm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_COf6yhOy, 0, m, &cSlice_COf6yhOy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WIx0xza8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_COf6yhOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4eHJqufN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4eHJqufN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YDP0k7AN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4eHJqufN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4eHJqufN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Lg9ipFnK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WIx0xza8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NtESeyTN, 0, m, &cSlice_NtESeyTN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_P8pRpaOV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NtESeyTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JcxFYxyp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JcxFYxyp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_4CeHcXc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JcxFYxyp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JcxFYxyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qqXR0VGw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_brGOnFbN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kjyVkAVM, 0, m, &cSlice_kjyVkAVM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wXxN7jkq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kjyVkAVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DbL1dgmg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DbL1dgmg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_6b0EHiqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DbL1dgmg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DbL1dgmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Vwq33LNP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wXxN7jkq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_td2PB9xi, 0, m, &cSlice_td2PB9xi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_td2PB9xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Itzmngfx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Itzmngfx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_t1AnaW3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Itzmngfx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Itzmngfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kotBGMIk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MWwkVIph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9FRuhRsR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lpnBfB61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_raqXavFV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8Ii0Rfax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7quaHcdV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SnYzksdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M4rcebnw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5rQYelZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zkgrVsG6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GTMinQd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_APBHd0Of_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_APBHd0Of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhJLSn8U, HV_BINOP_DIVIDE, 1, m, &cBinop_KhJLSn8U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Umpp6mYc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_fzSZa6zS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lTYqLdSJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XcDQ9duU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_fzSZa6zS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lTYqLdSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhJLSn8U, HV_BINOP_DIVIDE, 0, m, &cBinop_KhJLSn8U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Umpp6mYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XcDQ9duU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_KhJLSn8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sH7skcpm, HV_BINOP_MULTIPLY, 1, m, &cBinop_sH7skcpm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sH7skcpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F6M3Wa8u_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dxYEcCMh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_FwzVZgRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FQl4bWkZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_8izd91c8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_acYaGADR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8ENnjsXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9QlsovIL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9QlsovIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sH7skcpm, HV_BINOP_MULTIPLY, 0, m, &cBinop_sH7skcpm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_amqS4OPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_gwL8fDrS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gwL8fDrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y8wL12xR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WuPSkxsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZbOSXhdm, 1, m, &cVar_ZbOSXhdm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ZbOSXhdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AkPddjNi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1Wx23pSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PfCV1v0S, HV_BINOP_MULTIPLY, 1, m, &cBinop_PfCV1v0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Q5Z0gaBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1Wx23pSl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_07cqoUXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZmbhEa6z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZmbhEa6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nVcGJ0ZH, HV_BINOP_MULTIPLY, 1, m, &cBinop_nVcGJ0ZH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7IYf4NPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iob2gDIv, HV_BINOP_MULTIPLY, 1, m, &cBinop_iob2gDIv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U3vlsy8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7IYf4NPM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UMllHzAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6SEDxjYm, HV_BINOP_MULTIPLY, 1, m, &cBinop_6SEDxjYm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eKkcgSTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ohb2FANp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ohb2FANp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o31MkgMQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_o31MkgMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_nXuPzEvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gysZtSza_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_8ENnjsXm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C6Ew3UXh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_VHOIqA7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_amqS4OPV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F6M3Wa8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FwzVZgRL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dxYEcCMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_8izd91c8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_FQl4bWkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sSvvou17_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_acYaGADR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hWD0BHml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mpFg1BlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_j7BlqcpF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y8wL12xR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_a8xo45zl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a8xo45zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_msvO6W7U, HV_BINOP_MULTIPLY, 1, m, &cBinop_msvO6W7U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_msvO6W7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6RZMZPcz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6RZMZPcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mpFg1BlJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AkPddjNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_34TBDcm3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_34TBDcm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Safqmkj4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DMVh6LVP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8dadWl0Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ANIHRXfF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_scrEmQX5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GSjb61D4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PfCV1v0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MWwkVIph_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_nVcGJ0ZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lpnBfB61_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_iob2gDIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Ii0Rfax_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_6SEDxjYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SnYzksdj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_o31MkgMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5rQYelZA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_RMOm2dBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VHOIqA7Y, 1, m, &cVar_VHOIqA7Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hQSAtYpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nXuPzEvr, 0, m, &cVar_nXuPzEvr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GSjb61D4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PfCV1v0S, HV_BINOP_MULTIPLY, 0, m, &cBinop_PfCV1v0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8dadWl0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6SEDxjYm, HV_BINOP_MULTIPLY, 0, m, &cBinop_6SEDxjYm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_scrEmQX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nVcGJ0ZH, HV_BINOP_MULTIPLY, 0, m, &cBinop_nVcGJ0ZH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DMVh6LVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o31MkgMQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_o31MkgMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ANIHRXfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iob2gDIv, HV_BINOP_MULTIPLY, 0, m, &cBinop_iob2gDIv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Safqmkj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_C6Ew3UXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZbOSXhdm, 0, m, &cVar_ZbOSXhdm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gysZtSza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VHOIqA7Y, 0, m, &cVar_VHOIqA7Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XsI2XYf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dRwmqQef, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rHcace1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_26wwKcyL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LQZK6F7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qaz4s4xL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pSFCmto0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TjraN0UB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gqp2iEQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SSipNLer_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_SSipNLer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j6Q3R9ia, HV_BINOP_DIVIDE, 1, m, &cBinop_j6Q3R9ia_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jay0Y2ld_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_iV7W5SKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RObBz2M4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NqEc6Xwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_iV7W5SKe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RObBz2M4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j6Q3R9ia, HV_BINOP_DIVIDE, 0, m, &cBinop_j6Q3R9ia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jay0Y2ld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NqEc6Xwy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_j6Q3R9ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LcoRoVR2, HV_BINOP_MULTIPLY, 1, m, &cBinop_LcoRoVR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LcoRoVR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LDeTt8pa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YmRoLPn1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_nbn7WTCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KFELdfq2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_y6k580JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L8vjSu6e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HklQDIa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_WpyPUP0J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WpyPUP0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LcoRoVR2, HV_BINOP_MULTIPLY, 0, m, &cBinop_LcoRoVR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9G1v1gWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_hZ8SWPFO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hZ8SWPFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L7JuYPQ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NYUQN9q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_79B47L3B, HV_BINOP_MULTIPLY, 1, m, &cBinop_79B47L3B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GYllp0k0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a3XsnOjg, 1, m, &cVar_a3XsnOjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zLtEb26R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQKBZMCN, HV_BINOP_MULTIPLY, 1, m, &cBinop_vQKBZMCN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6IashbXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nXqmq4CP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nXqmq4CP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oc6R38tc, HV_BINOP_MULTIPLY, 1, m, &cBinop_oc6R38tc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_a3XsnOjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UxjjHqa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_kUZAMChw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jgNGokV3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HklQDIa7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eY0dNXHj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_E0YFy6UL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9G1v1gWQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YmRoLPn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_y6k580JM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LDeTt8pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_nbn7WTCJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_KFELdfq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wBWL47rm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_L8vjSu6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F7ctwigV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WuNCIuje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fpJAUlu6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_L7JuYPQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FknPDiVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FknPDiVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qXgioyOo, HV_BINOP_MULTIPLY, 1, m, &cBinop_qXgioyOo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qXgioyOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fD5dwvPb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fD5dwvPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WuNCIuje_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UxjjHqa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_G7H2vWO8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G7H2vWO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WjcAQA0i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LghQpGYm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4DMPIYPY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bfzmm3fT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3LEAu5Bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XsI2XYf7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_79B47L3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rHcace1p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vQKBZMCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LQZK6F7T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_oc6R38tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pSFCmto0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_IhJ2ks5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E0YFy6UL, 1, m, &cVar_E0YFy6UL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3Yzq59jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kUZAMChw, 0, m, &cVar_kUZAMChw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jgNGokV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E0YFy6UL, 0, m, &cVar_E0YFy6UL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eY0dNXHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a3XsnOjg, 0, m, &cVar_a3XsnOjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4DMPIYPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_79B47L3B, HV_BINOP_MULTIPLY, 0, m, &cBinop_79B47L3B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LghQpGYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQKBZMCN, HV_BINOP_MULTIPLY, 0, m, &cBinop_vQKBZMCN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bfzmm3fT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3LEAu5Bb, HV_BINOP_MULTIPLY, 0, m, &cBinop_3LEAu5Bb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WjcAQA0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oc6R38tc, HV_BINOP_MULTIPLY, 0, m, &cBinop_oc6R38tc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YCgMudtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eUesPIQn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iYQB4jRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CqyyEhpi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WP4EKF5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O0zgOsnr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PuJI05YP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X0cqLvoj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rqqZ0Oqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qNVqZ0xs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5VFuYQhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_J1dJ9K0e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_J1dJ9K0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EpS4SjhC, HV_BINOP_DIVIDE, 1, m, &cBinop_EpS4SjhC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OcMoO0zY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_IU7qLMo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Yl0oQrR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hjpXE1Va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_IU7qLMo7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Yl0oQrR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EpS4SjhC, HV_BINOP_DIVIDE, 0, m, &cBinop_EpS4SjhC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OcMoO0zY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hjpXE1Va_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EpS4SjhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_770zwUGE, HV_BINOP_MULTIPLY, 1, m, &cBinop_770zwUGE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_770zwUGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_44YFibaZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wD3BUu5V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_WeBBf8Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pYo4Lo0W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_k4IsAVAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dUSQ62RJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wm1i6W3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_axmU5LfH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_axmU5LfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_770zwUGE, HV_BINOP_MULTIPLY, 0, m, &cBinop_770zwUGE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LzVQarEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Gfed9AlK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gfed9AlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_guntItCs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xVh05dCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2KYDFHA, HV_BINOP_MULTIPLY, 1, m, &cBinop_L2KYDFHA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PBZ7YbGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_k92IMqtc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k92IMqtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xVh05dCY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ADTSvlwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_o8ICvUho_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_o8ICvUho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BwEPke3z, HV_BINOP_MULTIPLY, 1, m, &cBinop_BwEPke3z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PQAshKnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v0KlHAKP, HV_BINOP_MULTIPLY, 1, m, &cBinop_v0KlHAKP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JuyZJ97A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_s8BELtpY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s8BELtpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PQAshKnF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MOj0SuUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bR93fS8q, 1, m, &cVar_bR93fS8q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6b5e1k4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bS41TH9K, HV_BINOP_MULTIPLY, 1, m, &cBinop_bS41TH9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bvrdrAhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_C4XBpaEu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C4XBpaEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z5ZWCgzs, HV_BINOP_MULTIPLY, 1, m, &cBinop_z5ZWCgzs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_bR93fS8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FTJvcOzO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_uC3qg3Ta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tYAC4Bbq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wm1i6W3T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EIikmzKr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_sm0mZmc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_LzVQarEF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_44YFibaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_WeBBf8Rx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wD3BUu5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_k4IsAVAs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_pYo4Lo0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2p5VN6LX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dUSQ62RJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Dp2LASle_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_l4jEvWQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ph6SEXjF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_guntItCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gqn3ceKb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gqn3ceKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ljHLgF4F, HV_BINOP_MULTIPLY, 1, m, &cBinop_ljHLgF4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ljHLgF4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nBNuv62j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nBNuv62j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_l4jEvWQk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FTJvcOzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bA4MzkRc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bA4MzkRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_19961vR5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_knUG9LIJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7i4WCiwk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iPePm4pf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5NIjs4nD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xQc359D5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L2KYDFHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YCgMudtA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BwEPke3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iYQB4jRo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_v0KlHAKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WP4EKF5a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_bS41TH9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PuJI05YP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_z5ZWCgzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rqqZ0Oqa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_hxv69dlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uC3qg3Ta, 0, m, &cVar_uC3qg3Ta_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FhEPhySV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sm0mZmc5, 1, m, &cVar_sm0mZmc5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xQc359D5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2KYDFHA, HV_BINOP_MULTIPLY, 0, m, &cBinop_L2KYDFHA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7i4WCiwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bS41TH9K, HV_BINOP_MULTIPLY, 0, m, &cBinop_bS41TH9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5NIjs4nD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BwEPke3z, HV_BINOP_MULTIPLY, 0, m, &cBinop_BwEPke3z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_knUG9LIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z5ZWCgzs, HV_BINOP_MULTIPLY, 0, m, &cBinop_z5ZWCgzs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iPePm4pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v0KlHAKP, HV_BINOP_MULTIPLY, 0, m, &cBinop_v0KlHAKP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_19961vR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_EIikmzKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bR93fS8q, 0, m, &cVar_bR93fS8q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tYAC4Bbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sm0mZmc5, 0, m, &cVar_sm0mZmc5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SYvT4kvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_deDUVDjr, 1, m, &cIf_deDUVDjr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P4NrT6G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Q3n03MbO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xVPxGYv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P4NrT6G0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_smon8tOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_deDUVDjr, 0, m, &cIf_deDUVDjr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1wP3Ikfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6vVca9Cr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Q3n03MbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_REElEn5X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HEkCMXKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uQ15MQKN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MpO94ssg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SYvT4kvN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xVPxGYv6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5Q3BlMH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_smon8tOn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_om0lpqK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P8LxCXas, HV_BINOP_DIVIDE, 0, m, &cBinop_P8LxCXas_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_AQVkZflm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T1pfZXq3, HV_BINOP_DIVIDE, 1, m, &cBinop_T1pfZXq3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P8LxCXas, HV_BINOP_DIVIDE, 1, m, &cBinop_P8LxCXas_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ZL5ibEZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FH6wKarX, HV_BINOP_DIVIDE, 0, m, &cBinop_FH6wKarX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_BkjHwmjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FH6wKarX, HV_BINOP_DIVIDE, 1, m, &cBinop_FH6wKarX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x2O5SFp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_om0lpqK3, 0, m, &cVar_om0lpqK3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kLoPuvCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AQVkZflm, 0, m, &cVar_AQVkZflm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A27HdRE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T1pfZXq3, HV_BINOP_DIVIDE, 0, m, &cBinop_T1pfZXq3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T1pfZXq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ZL5ibEZe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P8LxCXas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_BkjHwmjo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FH6wKarX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_4q1O26Ev_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_zAM8W2bI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_ZbHnGLsN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zTeMRaT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_v15SQeJo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4q1O26Ev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zTeMRaT9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v15SQeJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_zAM8W2bI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZbHnGLsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ar1qedyY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RSnYxweB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3eND2rf4, 0, m, &cSlice_3eND2rf4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3eND2rf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6T3PtCLq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6T3PtCLq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_W8z6vecT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6T3PtCLq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6T3PtCLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_clL3NmGi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ajKf7QPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jYwzDPzO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jYwzDPzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_m75TrZVR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m75TrZVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nhZp6XOs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nhZp6XOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ePpl4LkK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mNLFZhPr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mNLFZhPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y7ARuB8X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ePpl4LkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3yCEaZWh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3yCEaZWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uRSg2rWi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y7ARuB8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MB7HR1RB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MB7HR1RB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BlQ8hLB7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uRSg2rWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0UxOgVHV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BlQ8hLB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hkyNfm4T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0UxOgVHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nNObmQnJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hkyNfm4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mz8VXjYh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_faZ6EUdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GwetDzNz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_3ZUY5rtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LvIagUPh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LPbe5xJI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8gIiOQTL_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w3HFThNP_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OldT3hFy_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QktPzPeh_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bVq1WsQN_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9Qjp89Z3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_8gIiOQTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vt1DUkP7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_w3HFThNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vcQyguXC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_OldT3hFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7dICklBq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QktPzPeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K7g5aOqy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bVq1WsQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dnEQ3VuD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9Qjp89Z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iEmhsdHM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_rZPZkBYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vtV557cV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_nrXq1pId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r1DIcQqf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3FkdL1r5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_u9LaxVIP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_u9LaxVIP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xL1cimJa, 1, m, &cDelay_xL1cimJa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fLBY2T85_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xL1cimJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xL1cimJa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rZPZkBYe, 0, m, &cIf_rZPZkBYe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u9LaxVIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xL1cimJa, 0, m, &cDelay_xL1cimJa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fLBY2T85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xL1cimJa, 0, m, &cDelay_xL1cimJa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MxW767Di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hI5r13iq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_moPavtgn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GJV5VEik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ki9NoH0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6zOwiJFd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2ki9NoH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZPZkBYe, 1, m, &cIf_rZPZkBYe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6zOwiJFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3FkdL1r5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hI5r13iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nrXq1pId, 1, m, &cIf_nrXq1pId_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_moPavtgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nrXq1pId, 0, m, &cIf_nrXq1pId_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r1DIcQqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EatOt60Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vtV557cV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EatOt60Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qBqUbyvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zZvvjM81_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_joUq5Dg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rwC2kv3C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Xm857uae_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_F7YyOama_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_F7YyOama_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uiVZVRSd, 1, m, &cDelay_uiVZVRSd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z4W1UNpv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uiVZVRSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uiVZVRSd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qBqUbyvf, 0, m, &cIf_qBqUbyvf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_F7YyOama_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uiVZVRSd, 0, m, &cDelay_uiVZVRSd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z4W1UNpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uiVZVRSd, 0, m, &cDelay_uiVZVRSd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GdZodGI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_83BtCgi5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jZfJiU1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HWjnmdsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OWE8eb3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jIBd43Cr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jIBd43Cr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Xm857uae_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OWE8eb3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qBqUbyvf, 1, m, &cIf_qBqUbyvf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_83BtCgi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_joUq5Dg8, 1, m, &cIf_joUq5Dg8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4jZfJiU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_joUq5Dg8, 0, m, &cIf_joUq5Dg8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rwC2kv3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QWeQvLzO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zZvvjM81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QWeQvLzO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aCQNy187_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_c6nq2m6d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IiP5H2MN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uYkctBVh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BN0EwyOT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ts5niJ5Z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ts5niJ5Z_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IUJu461L, 1, m, &cDelay_IUJu461L_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pAAMUvzF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IUJu461L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IUJu461L, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aCQNy187, 0, m, &cIf_aCQNy187_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ts5niJ5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IUJu461L, 0, m, &cDelay_IUJu461L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pAAMUvzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IUJu461L, 0, m, &cDelay_IUJu461L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6F4S2wNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yUQ46skr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FkEiaB8F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uES7C00V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3BmdL0VT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hOAgO01Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hOAgO01Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BN0EwyOT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3BmdL0VT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aCQNy187, 1, m, &cIf_aCQNy187_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FkEiaB8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IiP5H2MN, 0, m, &cIf_IiP5H2MN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yUQ46skr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IiP5H2MN, 1, m, &cIf_IiP5H2MN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uYkctBVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4r1gdoJt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_c6nq2m6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4r1gdoJt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_w4upmWr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QxYTDB1v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VMBLhdTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z6Gcsuhd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VLRCAGy7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xnsH1xVV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xnsH1xVV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5d88VEFO, 1, m, &cDelay_5d88VEFO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PNQmx3nc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5d88VEFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5d88VEFO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_w4upmWr1, 0, m, &cIf_w4upmWr1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xnsH1xVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5d88VEFO, 0, m, &cDelay_5d88VEFO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PNQmx3nc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5d88VEFO, 0, m, &cDelay_5d88VEFO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pv3fHKA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FfjWW9Gm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ZFkRNLO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lb6DFyUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fzwAiUgg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I4EMnevU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I4EMnevU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VLRCAGy7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fzwAiUgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w4upmWr1, 1, m, &cIf_w4upmWr1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8ZFkRNLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VMBLhdTF, 0, m, &cIf_VMBLhdTF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FfjWW9Gm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VMBLhdTF, 1, m, &cIf_VMBLhdTF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z6Gcsuhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ya7UUR3T, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QxYTDB1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ya7UUR3T, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RXPVmfrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zI2AZH5G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BjWkBQKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qg5Gnc5N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dvbY7uaZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vvKCO2nZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vvKCO2nZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ghD3M5nq, 1, m, &cDelay_ghD3M5nq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x5XoFcFS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ghD3M5nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ghD3M5nq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RXPVmfrS, 0, m, &cIf_RXPVmfrS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vvKCO2nZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ghD3M5nq, 0, m, &cDelay_ghD3M5nq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x5XoFcFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ghD3M5nq, 0, m, &cDelay_ghD3M5nq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LaVaHFMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_95KGB0Fh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1Jgdyshk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yNOAagAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8fDwn6Nw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FECF9vDL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8fDwn6Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RXPVmfrS, 1, m, &cIf_RXPVmfrS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FECF9vDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dvbY7uaZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1Jgdyshk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BjWkBQKp, 0, m, &cIf_BjWkBQKp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_95KGB0Fh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BjWkBQKp, 1, m, &cIf_BjWkBQKp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qg5Gnc5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dPcUEwbX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zI2AZH5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dPcUEwbX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gH8xkWa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BEZXtVkP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xBd9cXju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aYZydj8F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_03OWWkZG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7HSvv0BI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7HSvv0BI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GJ0hf4gK, 1, m, &cDelay_GJ0hf4gK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G5YgQdkI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GJ0hf4gK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GJ0hf4gK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gH8xkWa4, 0, m, &cIf_gH8xkWa4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7HSvv0BI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GJ0hf4gK, 0, m, &cDelay_GJ0hf4gK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G5YgQdkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GJ0hf4gK, 0, m, &cDelay_GJ0hf4gK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PpngYSMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sur8U27e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y2P4U0qg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Uv7nVSUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J9IJpGyV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rmK8O1lh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J9IJpGyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gH8xkWa4, 1, m, &cIf_gH8xkWa4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rmK8O1lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_03OWWkZG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sur8U27e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xBd9cXju, 1, m, &cIf_xBd9cXju_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y2P4U0qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xBd9cXju, 0, m, &cIf_xBd9cXju_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aYZydj8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DCvegYgG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BEZXtVkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DCvegYgG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_urSupkEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AjcOImFk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_d4MZwD38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zARL6gLp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zY7v7Iqa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2BI46L9c_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2BI46L9c_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_f6CvEkvi, 1, m, &cDelay_f6CvEkvi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h80mXcei_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_f6CvEkvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f6CvEkvi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_urSupkEr, 0, m, &cIf_urSupkEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2BI46L9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_f6CvEkvi, 0, m, &cDelay_f6CvEkvi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h80mXcei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f6CvEkvi, 0, m, &cDelay_f6CvEkvi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AZeB0Nus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4pb1tZuE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2O42DsrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K09M7lIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XFGD7wjE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9IQwWC20_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XFGD7wjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_urSupkEr, 1, m, &cIf_urSupkEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9IQwWC20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zY7v7Iqa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4pb1tZuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d4MZwD38, 1, m, &cIf_d4MZwD38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2O42DsrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d4MZwD38, 0, m, &cIf_d4MZwD38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zARL6gLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QMwfSRga, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AjcOImFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QMwfSRga, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_m2kQ7kDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1t8Rzkfx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_llQsnpYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EGhGPCtq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9oawhY8x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KAs0nlQ6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KAs0nlQ6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sNEuETOi, 1, m, &cDelay_sNEuETOi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZIaGrj0k_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sNEuETOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sNEuETOi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_m2kQ7kDd, 0, m, &cIf_m2kQ7kDd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KAs0nlQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sNEuETOi, 0, m, &cDelay_sNEuETOi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZIaGrj0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sNEuETOi, 0, m, &cDelay_sNEuETOi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RJL3b0zH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b91VpFld_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6UfVG7Rz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1qYbK9Pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vxg4gjQS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6SFAgzER_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6SFAgzER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9oawhY8x_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Vxg4gjQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m2kQ7kDd, 1, m, &cIf_m2kQ7kDd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b91VpFld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_llQsnpYS, 1, m, &cIf_llQsnpYS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6UfVG7Rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_llQsnpYS, 0, m, &cIf_llQsnpYS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EGhGPCtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j9UaZDEl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1t8Rzkfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j9UaZDEl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zTkDCWhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qPiYJ6bc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_n0joCUc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_clgOxcFG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7woWW0w7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KcXzbNEJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KcXzbNEJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tMfXYhXj, 1, m, &cDelay_tMfXYhXj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CG1Aje7h_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tMfXYhXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tMfXYhXj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zTkDCWhg, 0, m, &cIf_zTkDCWhg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KcXzbNEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tMfXYhXj, 0, m, &cDelay_tMfXYhXj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CG1Aje7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tMfXYhXj, 0, m, &cDelay_tMfXYhXj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vmlyNT7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D0XlJM2o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oxBMzDiA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D08IcOOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ciryArAV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MTB7AoiU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MTB7AoiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7woWW0w7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ciryArAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zTkDCWhg, 1, m, &cIf_zTkDCWhg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oxBMzDiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n0joCUc6, 0, m, &cIf_n0joCUc6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D0XlJM2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n0joCUc6, 1, m, &cIf_n0joCUc6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_clgOxcFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8EvkVbqL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qPiYJ6bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8EvkVbqL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RjQVFPMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pZjw6oNe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1JPhumj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_40QLHlei_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9o1f1b2u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_evHpLg0t_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_evHpLg0t_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NAEiPiYB, 1, m, &cDelay_NAEiPiYB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ysDcY4uW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NAEiPiYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NAEiPiYB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RjQVFPMQ, 0, m, &cIf_RjQVFPMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_evHpLg0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NAEiPiYB, 0, m, &cDelay_NAEiPiYB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ysDcY4uW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NAEiPiYB, 0, m, &cDelay_NAEiPiYB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5mn7avwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RMC848ol_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JsdcE8OU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v09hPt5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lFbDw5kN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vJeJBYur_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lFbDw5kN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RjQVFPMQ, 1, m, &cIf_RjQVFPMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vJeJBYur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9o1f1b2u_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RMC848ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1JPhumj8, 1, m, &cIf_1JPhumj8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JsdcE8OU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1JPhumj8, 0, m, &cIf_1JPhumj8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_40QLHlei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WoERXYiG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pZjw6oNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WoERXYiG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zkFuNTwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Dz41h9o8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yw4unP2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H3zt8w87_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HlN7YSM0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_78vxizfV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_78vxizfV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kPFs8OsT, 1, m, &cDelay_kPFs8OsT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ukj0ci8a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kPFs8OsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kPFs8OsT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zkFuNTwG, 0, m, &cIf_zkFuNTwG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_78vxizfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kPFs8OsT, 0, m, &cDelay_kPFs8OsT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ukj0ci8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kPFs8OsT, 0, m, &cDelay_kPFs8OsT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zE5K29Ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JMAmZRT0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mSQUwJVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MSRqduSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jPpbXDgy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HknjJb9j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jPpbXDgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zkFuNTwG, 1, m, &cIf_zkFuNTwG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HknjJb9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HlN7YSM0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JMAmZRT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yw4unP2m, 1, m, &cIf_yw4unP2m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mSQUwJVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yw4unP2m, 0, m, &cIf_yw4unP2m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H3zt8w87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V8kzE1T5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Dz41h9o8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V8kzE1T5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4qRB0p9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_D1vd5oUZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lu7S16iF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OFirUjS2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FmxyYIkr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_e2XuGNMn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_e2XuGNMn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ma4Mo2fd, 1, m, &cDelay_Ma4Mo2fd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hZXttbZo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ma4Mo2fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ma4Mo2fd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4qRB0p9V, 0, m, &cIf_4qRB0p9V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e2XuGNMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ma4Mo2fd, 0, m, &cDelay_Ma4Mo2fd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hZXttbZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ma4Mo2fd, 0, m, &cDelay_Ma4Mo2fd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oXPrl3Ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QUeUixWz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z6bLaARX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oO4L8EwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ufdpjGIo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BqTDXoMM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BqTDXoMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FmxyYIkr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ufdpjGIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4qRB0p9V, 1, m, &cIf_4qRB0p9V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QUeUixWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lu7S16iF, 1, m, &cIf_lu7S16iF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z6bLaARX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lu7S16iF, 0, m, &cIf_lu7S16iF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OFirUjS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2HZSDI7Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_D1vd5oUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2HZSDI7Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vt1DUkP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_hLrL9gn7_sendMessage(_c, 0, m);
  cMsg_wrvrn80v_sendMessage(_c, 0, m);
  cMsg_5c1gXfpW_sendMessage(_c, 0, m);
  cMsg_b3gwR7SU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vcQyguXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_hLrL9gn7_sendMessage(_c, 0, m);
  cMsg_MM9IVgZf_sendMessage(_c, 0, m);
  cMsg_rMN7Wxqe_sendMessage(_c, 0, m);
  cMsg_JLNQChmV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7dICklBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_yNapuroc_sendMessage(_c, 0, m);
  cMsg_MM9IVgZf_sendMessage(_c, 0, m);
  cMsg_b3gwR7SU_sendMessage(_c, 0, m);
  cMsg_HcKo4nYf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_K7g5aOqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_yNapuroc_sendMessage(_c, 0, m);
  cMsg_dOpCRxA0_sendMessage(_c, 0, m);
  cMsg_5c1gXfpW_sendMessage(_c, 0, m);
  cMsg_pSTq0CCt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dnEQ3VuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_cbMrT2NB_sendMessage(_c, 0, m);
  cMsg_JLNQChmV_sendMessage(_c, 0, m);
  cMsg_PZBWmMxj_sendMessage(_c, 0, m);
  cMsg_5c1gXfpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iEmhsdHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_cbMrT2NB_sendMessage(_c, 0, m);
  cMsg_pSTq0CCt_sendMessage(_c, 0, m);
  cMsg_MM9IVgZf_sendMessage(_c, 0, m);
  cMsg_38rE4kLz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bpW0H79S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GJV5VEik_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MxW767Di_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Q0m2p0bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GJV5VEik_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MxW767Di_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OMr0Dp1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HWjnmdsF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GdZodGI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i47HcqCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HWjnmdsF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GdZodGI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_V6DTBdxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uES7C00V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6F4S2wNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JxjZ17DD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uES7C00V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6F4S2wNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hLrL9gn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_bpW0H79S_sendMessage(_c, 0, m);
  cMsg_i47HcqCP_sendMessage(_c, 0, m);
  cMsg_JxjZ17DD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yNapuroc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Q0m2p0bj_sendMessage(_c, 0, m);
  cMsg_OMr0Dp1x_sendMessage(_c, 0, m);
  cMsg_JxjZ17DD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cbMrT2NB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Q0m2p0bj_sendMessage(_c, 0, m);
  cMsg_i47HcqCP_sendMessage(_c, 0, m);
  cMsg_V6DTBdxT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lWhuy20r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Lb6DFyUI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pv3fHKA5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8wcw68Jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Lb6DFyUI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pv3fHKA5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bliTFVXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yNOAagAm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LaVaHFMg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4nJ8R8rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yNOAagAm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LaVaHFMg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xXktZy8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Uv7nVSUB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PpngYSMZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oqVC4CSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Uv7nVSUB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PpngYSMZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MM9IVgZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_8wcw68Jl_sendMessage(_c, 0, m);
  cMsg_4nJ8R8rf_sendMessage(_c, 0, m);
  cMsg_oqVC4CSz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wrvrn80v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_8wcw68Jl_sendMessage(_c, 0, m);
  cMsg_bliTFVXN_sendMessage(_c, 0, m);
  cMsg_xXktZy8q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dOpCRxA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_lWhuy20r_sendMessage(_c, 0, m);
  cMsg_4nJ8R8rf_sendMessage(_c, 0, m);
  cMsg_xXktZy8q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qkjlS9AB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v09hPt5c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5mn7avwN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mgqLdhGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v09hPt5c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5mn7avwN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AyNCuKDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MSRqduSI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zE5K29Ud_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r97lXOrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MSRqduSI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zE5K29Ud_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JrqJKr2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oO4L8EwI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oXPrl3Ay_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y6jhwKOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oO4L8EwI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oXPrl3Ay_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pSTq0CCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_qkjlS9AB_sendMessage(_c, 0, m);
  cMsg_r97lXOrO_sendMessage(_c, 0, m);
  cMsg_Y6jhwKOQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JLNQChmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_mgqLdhGz_sendMessage(_c, 0, m);
  cMsg_AyNCuKDr_sendMessage(_c, 0, m);
  cMsg_Y6jhwKOQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_b3gwR7SU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_mgqLdhGz_sendMessage(_c, 0, m);
  cMsg_r97lXOrO_sendMessage(_c, 0, m);
  cMsg_JrqJKr2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WWfcEiaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K09M7lIw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AZeB0Nus_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cznYxU0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K09M7lIw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AZeB0Nus_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VOTgAAHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1qYbK9Pp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RJL3b0zH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BB55A0Pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1qYbK9Pp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RJL3b0zH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uHUlYmff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_D08IcOOZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vmlyNT7R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I7SD0b1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_D08IcOOZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vmlyNT7R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5c1gXfpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_cznYxU0e_sendMessage(_c, 0, m);
  cMsg_BB55A0Pc_sendMessage(_c, 0, m);
  cMsg_I7SD0b1l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rMN7Wxqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_cznYxU0e_sendMessage(_c, 0, m);
  cMsg_VOTgAAHh_sendMessage(_c, 0, m);
  cMsg_uHUlYmff_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_38rE4kLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_WWfcEiaQ_sendMessage(_c, 0, m);
  cMsg_VOTgAAHh_sendMessage(_c, 0, m);
  cMsg_I7SD0b1l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PZBWmMxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_lWhuy20r_sendMessage(_c, 0, m);
  cMsg_bliTFVXN_sendMessage(_c, 0, m);
  cMsg_oqVC4CSz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HcKo4nYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_WWfcEiaQ_sendMessage(_c, 0, m);
  cMsg_BB55A0Pc_sendMessage(_c, 0, m);
  cMsg_uHUlYmff_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6ARbiM1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tm9VxIc2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_45ePv0aR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_szjMbTXU, 0, m, &cSlice_szjMbTXU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KgjnoTK4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_szjMbTXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_B6lk9RQr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_B6lk9RQr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_s1PGAgDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B6lk9RQr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_B6lk9RQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_29iqfHLq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zekA9TM9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yt1KEm5e, 0, m, &cSlice_yt1KEm5e_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CIE3Mnbv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_yt1KEm5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NW4TWdYR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NW4TWdYR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_F4e1gTeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NW4TWdYR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NW4TWdYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VtWR25EE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CIE3Mnbv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2T4Uzhhe, 0, m, &cSlice_2T4Uzhhe_sendMessage);
      break;
    }
    default: {
      cSwitchcase_45ePv0aR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_2T4Uzhhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gbGtoOrD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gbGtoOrD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_oPv3OGDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gbGtoOrD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gbGtoOrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VpOocFHH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KgjnoTK4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GFPEUSRv, 0, m, &cSlice_GFPEUSRv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Rb9waLGe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GFPEUSRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_s4Q6TSoB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_s4Q6TSoB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Lor68x1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s4Q6TSoB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_s4Q6TSoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LDbKEa4z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Rb9waLGe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_46NNMAJQ, 0, m, &cSlice_46NNMAJQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ocuk1Qvv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_46NNMAJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_87tnX2Vu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_87tnX2Vu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_fjwMo5Md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_87tnX2Vu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_87tnX2Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dxezpwfZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xr5O0eC4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vdpE2mZl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vdpE2mZl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7QEbly5M, 1, m, &cDelay_7QEbly5M_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YtScH93W_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7QEbly5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7QEbly5M, m);
  cMsg_xHTP6kjj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vdpE2mZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7QEbly5M, 0, m, &cDelay_7QEbly5M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YtScH93W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7QEbly5M, 0, m, &cDelay_7QEbly5M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_9oNyGt2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HvB7Squ3, HV_BINOP_SUBTRACT, 0, m, &cBinop_HvB7Squ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_od9GEpez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mvszqDmT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UcZ1ughr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mvszqDmT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_8OdsCRrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9oNyGt2L, 0, m, &cVar_9oNyGt2L_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_oxk4RKer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9pxcnBed_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fUvCOKE6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pveVKa7R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HvB7Squ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LGkfCo8W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LGkfCo8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_E1osUEbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E1osUEbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_zFa5uD2u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bHrR681U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pAKjsNkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H4fmoDCJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H4fmoDCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_asuF18Jl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pAKjsNkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_od9GEpez, 1, m, &cIf_od9GEpez_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PE0L7dTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UcZ1ughr, 1, m, &cIf_UcZ1ughr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_asuF18Jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_od9GEpez, 0, m, &cIf_od9GEpez_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zFa5uD2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UcZ1ughr, 0, m, &cIf_UcZ1ughr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fUvCOKE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HvB7Squ3, HV_BINOP_SUBTRACT, 1, m, &cBinop_HvB7Squ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9pxcnBed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_pveVKa7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9oNyGt2L, 0, m, &cVar_9oNyGt2L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mvszqDmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pJQ56YO0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ocuk1Qvv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5EJnJL20, 0, m, &cSlice_5EJnJL20_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5EJnJL20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UVhMrLOA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UVhMrLOA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Jw7t1KrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UVhMrLOA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UVhMrLOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bsQ6wNtT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GwetDzNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SA2ckAkw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LvIagUPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XyeDdSp8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_zVkkpgjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3ZUY5rtM, 0, m, &cVar_3ZUY5rtM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Tm9VxIc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JRzax4vN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_tIPfoWkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xr5O0eC4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1CTeJvCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SQN7vnVI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xHTP6kjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HK2gFNh1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SQN7vnVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HK2gFNh1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Kn4AyRBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_ZHKxoNkX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZHKxoNkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hz2JynFj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Hz2JynFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m8B9emDa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_UO5nSCrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IkMFuFVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0EbCbiso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f21fVW1A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3HmpxPaB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qGXi3ruU_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_efjR1PCG_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_03cQwXhc_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TcxHklHo_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vPiB33Rx_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H9PFkC4E_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_qGXi3ruU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YuFSqGbx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_efjR1PCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WUovRqF3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_03cQwXhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_717RMlWG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_TcxHklHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cRpApoA5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_vPiB33Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DsaUMeMq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_H9PFkC4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_avOyPkgx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_zCnltwqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RcLGa6kQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7qGGY6pB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sneb8CXm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_U7sboEuN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5urtzwMy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5urtzwMy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TtE5ooxF, 1, m, &cDelay_TtE5ooxF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_62JUMQuE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TtE5ooxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TtE5ooxF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zCnltwqn, 0, m, &cIf_zCnltwqn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5urtzwMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TtE5ooxF, 0, m, &cDelay_TtE5ooxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_62JUMQuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TtE5ooxF, 0, m, &cDelay_TtE5ooxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v3uhs3PQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZtjqK0KQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c4ntPzLN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SmKMTKSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_McLeukuq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ntXg5lV4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_McLeukuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zCnltwqn, 1, m, &cIf_zCnltwqn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ntXg5lV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_U7sboEuN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZtjqK0KQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7qGGY6pB, 1, m, &cIf_7qGGY6pB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c4ntPzLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7qGGY6pB, 0, m, &cIf_7qGGY6pB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sneb8CXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VVYOa60h, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RcLGa6kQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VVYOa60h, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Sqdoqvmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IMV6bHuL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zXymloa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5isHmy7r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fpP8Uife_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_C59egyMD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_C59egyMD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5TyKpITm, 1, m, &cDelay_5TyKpITm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5bo8plYk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5TyKpITm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5TyKpITm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Sqdoqvmf, 0, m, &cIf_Sqdoqvmf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C59egyMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5TyKpITm, 0, m, &cDelay_5TyKpITm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5bo8plYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5TyKpITm, 0, m, &cDelay_5TyKpITm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i0Vae9L5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8amFaFJ2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W9Yesuuq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A5mwajau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_50z4ZLaT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iwuq7brU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iwuq7brU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fpP8Uife_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_50z4ZLaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sqdoqvmf, 1, m, &cIf_Sqdoqvmf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8amFaFJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zXymloa8, 1, m, &cIf_zXymloa8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W9Yesuuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zXymloa8, 0, m, &cIf_zXymloa8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5isHmy7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jPPBcdLx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IMV6bHuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jPPBcdLx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gtCX2lBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HQ6WzzMY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GlLtXK4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OHMIML2s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e4J4c40z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pt62EbqZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pt62EbqZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pOVJOXCs, 1, m, &cDelay_pOVJOXCs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z2mkxTrb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_pOVJOXCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pOVJOXCs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gtCX2lBF, 0, m, &cIf_gtCX2lBF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pt62EbqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pOVJOXCs, 0, m, &cDelay_pOVJOXCs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z2mkxTrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pOVJOXCs, 0, m, &cDelay_pOVJOXCs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gAdHngNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lVahfEjr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B8sifugZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j9cimrVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ekQ46cF4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k9U3pCXH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k9U3pCXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_e4J4c40z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ekQ46cF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gtCX2lBF, 1, m, &cIf_gtCX2lBF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B8sifugZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GlLtXK4z, 0, m, &cIf_GlLtXK4z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lVahfEjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GlLtXK4z, 1, m, &cIf_GlLtXK4z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OHMIML2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J2LrEdIu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HQ6WzzMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J2LrEdIu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zp0fCLDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_F3djR0E9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YMWJSu4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kNTRDtwq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EEP9UcWT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DEsRKYG4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DEsRKYG4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_J473aMcz, 1, m, &cDelay_J473aMcz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G8JEXSu9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_J473aMcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_J473aMcz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zp0fCLDd, 0, m, &cIf_zp0fCLDd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DEsRKYG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_J473aMcz, 0, m, &cDelay_J473aMcz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G8JEXSu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_J473aMcz, 0, m, &cDelay_J473aMcz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_njLvCLQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vq3EBerA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Co9dVj85_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XSth9S01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RsVh1iOm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o9EwFVrH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o9EwFVrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EEP9UcWT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RsVh1iOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zp0fCLDd, 1, m, &cIf_zp0fCLDd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Co9dVj85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YMWJSu4A, 0, m, &cIf_YMWJSu4A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vq3EBerA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YMWJSu4A, 1, m, &cIf_YMWJSu4A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kNTRDtwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hmkvz4a8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_F3djR0E9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hmkvz4a8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_U1CGVWlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TVWeiNkB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SUNsmsdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RTc5Snfq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RFk9uL7t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PVdwBNQI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PVdwBNQI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_woTVaoDn, 1, m, &cDelay_woTVaoDn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l0QxrwiT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_woTVaoDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_woTVaoDn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_U1CGVWlp, 0, m, &cIf_U1CGVWlp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PVdwBNQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_woTVaoDn, 0, m, &cDelay_woTVaoDn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l0QxrwiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_woTVaoDn, 0, m, &cDelay_woTVaoDn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nF2U4yqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9GbWaCCo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C818UJfw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9dxtJeLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GHCVCgqu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T0WePKil_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T0WePKil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RFk9uL7t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GHCVCgqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U1CGVWlp, 1, m, &cIf_U1CGVWlp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C818UJfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SUNsmsdJ, 0, m, &cIf_SUNsmsdJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9GbWaCCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SUNsmsdJ, 1, m, &cIf_SUNsmsdJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RTc5Snfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f9mjabuR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TVWeiNkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f9mjabuR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jZAhw5AC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wf45cyql_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EeReahtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AjFmupsn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_W2JuXokF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eUWtnT8B_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eUWtnT8B_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oP6ZzBJ2, 1, m, &cDelay_oP6ZzBJ2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P9sFqlQC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oP6ZzBJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oP6ZzBJ2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jZAhw5AC, 0, m, &cIf_jZAhw5AC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eUWtnT8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oP6ZzBJ2, 0, m, &cDelay_oP6ZzBJ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_P9sFqlQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oP6ZzBJ2, 0, m, &cDelay_oP6ZzBJ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AXmgBv1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OvedawNl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xmEVZCAo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QPSMLvwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YOaZYrXL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sgqlgFuU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sgqlgFuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_W2JuXokF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YOaZYrXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jZAhw5AC, 1, m, &cIf_jZAhw5AC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xmEVZCAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EeReahtF, 0, m, &cIf_EeReahtF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OvedawNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EeReahtF, 1, m, &cIf_EeReahtF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AjFmupsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_moI6oDZz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wf45cyql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_moI6oDZz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nboBnz8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1rgwdiUv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_nhgpSxVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6av0bgXr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cGPpInPk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Nr58naWs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Nr58naWs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RH6gkcFj, 1, m, &cDelay_RH6gkcFj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HRnl0kLE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RH6gkcFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RH6gkcFj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nboBnz8K, 0, m, &cIf_nboBnz8K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Nr58naWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RH6gkcFj, 0, m, &cDelay_RH6gkcFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HRnl0kLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RH6gkcFj, 0, m, &cDelay_RH6gkcFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0vFWIzcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yv3XSYEI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MQr9xmgI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EkxhFagN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sgTYVRSi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XAGMLCiB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sgTYVRSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nboBnz8K, 1, m, &cIf_nboBnz8K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XAGMLCiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cGPpInPk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MQr9xmgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nhgpSxVq, 0, m, &cIf_nhgpSxVq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Yv3XSYEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nhgpSxVq, 1, m, &cIf_nhgpSxVq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6av0bgXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_seo1zEtK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1rgwdiUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_seo1zEtK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_i7kJz4MF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GaO6yjjy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rr453G9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZQd5Phqw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NXmIxsXJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iXHJrPjI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iXHJrPjI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IZQevzEx, 1, m, &cDelay_IZQevzEx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XORVB9Hm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IZQevzEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IZQevzEx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_i7kJz4MF, 0, m, &cIf_i7kJz4MF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iXHJrPjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZQevzEx, 0, m, &cDelay_IZQevzEx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XORVB9Hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZQevzEx, 0, m, &cDelay_IZQevzEx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BHVIJqFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_adHtgADj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WZaQoTVC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tstuY3Ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JGQBmIWy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uompJP02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JGQBmIWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i7kJz4MF, 1, m, &cIf_i7kJz4MF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uompJP02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NXmIxsXJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WZaQoTVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rr453G9Y, 0, m, &cIf_rr453G9Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_adHtgADj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rr453G9Y, 1, m, &cIf_rr453G9Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZQd5Phqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qmwD0tTA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GaO6yjjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qmwD0tTA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OlbVMSsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_285cgTKn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2gSALixr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b3MCYa4e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XSYVj0i6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mhQG4uhJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mhQG4uhJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MqqZ9zNi, 1, m, &cDelay_MqqZ9zNi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NIAuDAyq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MqqZ9zNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MqqZ9zNi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OlbVMSsI, 0, m, &cIf_OlbVMSsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mhQG4uhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MqqZ9zNi, 0, m, &cDelay_MqqZ9zNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NIAuDAyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MqqZ9zNi, 0, m, &cDelay_MqqZ9zNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Yy2KLvPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MJsDg770_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9qqczMUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ngPIAkgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8AqBEsti_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g0SI83bO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g0SI83bO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XSYVj0i6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8AqBEsti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OlbVMSsI, 1, m, &cIf_OlbVMSsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9qqczMUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2gSALixr, 0, m, &cIf_2gSALixr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MJsDg770_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2gSALixr, 1, m, &cIf_2gSALixr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b3MCYa4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BpyP2r8M, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_285cgTKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BpyP2r8M, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_WjQWQyAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k5ZAbVoa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KwfzzepX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rKGGfhRa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_J5R42f09_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0CxtdO1e_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0CxtdO1e_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BmbMqJrL, 1, m, &cDelay_BmbMqJrL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EBVXM3Ej_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BmbMqJrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BmbMqJrL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WjQWQyAa, 0, m, &cIf_WjQWQyAa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0CxtdO1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BmbMqJrL, 0, m, &cDelay_BmbMqJrL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EBVXM3Ej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BmbMqJrL, 0, m, &cDelay_BmbMqJrL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GJAquo2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FDMKkts3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SS4AzcQo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TsubG2oM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xARK4y6I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JRtqPTbw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JRtqPTbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_J5R42f09_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xARK4y6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WjQWQyAa, 1, m, &cIf_WjQWQyAa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SS4AzcQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KwfzzepX, 0, m, &cIf_KwfzzepX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FDMKkts3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KwfzzepX, 1, m, &cIf_KwfzzepX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rKGGfhRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WWnlyZY9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k5ZAbVoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WWnlyZY9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_69B7bNBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_t69Hg4xh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TMoUevPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KQeSGrgh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Kqegsjn8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DyuiwdYb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DyuiwdYb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MTUnsGSE, 1, m, &cDelay_MTUnsGSE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lc4V7TMD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MTUnsGSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MTUnsGSE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_69B7bNBq, 0, m, &cIf_69B7bNBq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DyuiwdYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MTUnsGSE, 0, m, &cDelay_MTUnsGSE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lc4V7TMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MTUnsGSE, 0, m, &cDelay_MTUnsGSE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_87w6fL8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JDtIxLcG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bvzAUguP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YZCqk43H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xcUm3wpI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aSZChPAi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xcUm3wpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_69B7bNBq, 1, m, &cIf_69B7bNBq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aSZChPAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Kqegsjn8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bvzAUguP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TMoUevPH, 0, m, &cIf_TMoUevPH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JDtIxLcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TMoUevPH, 1, m, &cIf_TMoUevPH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KQeSGrgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tiaIaBPv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t69Hg4xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tiaIaBPv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OdySkh0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cLubmljb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kyJelErj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zdGo0qm8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KpQ6ClM8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_m6bHZjN1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_m6bHZjN1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_P7lGCPUB, 1, m, &cDelay_P7lGCPUB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fJieDeu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_P7lGCPUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P7lGCPUB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OdySkh0w, 0, m, &cIf_OdySkh0w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m6bHZjN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_P7lGCPUB, 0, m, &cDelay_P7lGCPUB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8fJieDeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P7lGCPUB, 0, m, &cDelay_P7lGCPUB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ju3Z8l6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cw9hRGm4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G26dbJG3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MapMpVQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d5Ljnsjb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K20wF5X7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d5Ljnsjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OdySkh0w, 1, m, &cIf_OdySkh0w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K20wF5X7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KpQ6ClM8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Cw9hRGm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kyJelErj, 1, m, &cIf_kyJelErj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G26dbJG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kyJelErj, 0, m, &cIf_kyJelErj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zdGo0qm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WT3npUqH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cLubmljb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WT3npUqH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YuFSqGbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_GGWj87IM_sendMessage(_c, 0, m);
  cMsg_As8XDcuR_sendMessage(_c, 0, m);
  cMsg_XMIQKfai_sendMessage(_c, 0, m);
  cMsg_GrWIzNn3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WUovRqF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_GGWj87IM_sendMessage(_c, 0, m);
  cMsg_rJXCf6qR_sendMessage(_c, 0, m);
  cMsg_dXSHLAfa_sendMessage(_c, 0, m);
  cMsg_wVq0tv81_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_717RMlWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_6ippLFrs_sendMessage(_c, 0, m);
  cMsg_rJXCf6qR_sendMessage(_c, 0, m);
  cMsg_GrWIzNn3_sendMessage(_c, 0, m);
  cMsg_RYypMJtc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cRpApoA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_6ippLFrs_sendMessage(_c, 0, m);
  cMsg_0bQNExR0_sendMessage(_c, 0, m);
  cMsg_XMIQKfai_sendMessage(_c, 0, m);
  cMsg_8PBgVW7f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DsaUMeMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_CBXiiZCt_sendMessage(_c, 0, m);
  cMsg_wVq0tv81_sendMessage(_c, 0, m);
  cMsg_NGDy8brS_sendMessage(_c, 0, m);
  cMsg_XMIQKfai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_avOyPkgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_CBXiiZCt_sendMessage(_c, 0, m);
  cMsg_8PBgVW7f_sendMessage(_c, 0, m);
  cMsg_rJXCf6qR_sendMessage(_c, 0, m);
  cMsg_zdNlS537_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bPHIgXux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SmKMTKSd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_v3uhs3PQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SXtxVZ9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SmKMTKSd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_v3uhs3PQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5lRlua0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_A5mwajau_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i0Vae9L5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nytknWyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_A5mwajau_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i0Vae9L5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oi6oBJmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j9cimrVt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gAdHngNt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Etxb1BAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j9cimrVt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gAdHngNt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GGWj87IM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_bPHIgXux_sendMessage(_c, 0, m);
  cMsg_nytknWyQ_sendMessage(_c, 0, m);
  cMsg_Etxb1BAD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6ippLFrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_SXtxVZ9I_sendMessage(_c, 0, m);
  cMsg_5lRlua0c_sendMessage(_c, 0, m);
  cMsg_Etxb1BAD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CBXiiZCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_SXtxVZ9I_sendMessage(_c, 0, m);
  cMsg_nytknWyQ_sendMessage(_c, 0, m);
  cMsg_oi6oBJmc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PQhXkGvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XSth9S01_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_njLvCLQZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Cm8Q1nDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XSth9S01_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_njLvCLQZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ow1oIpuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9dxtJeLQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nF2U4yqz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9aTUDSbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9dxtJeLQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nF2U4yqz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pdiXRLn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QPSMLvwF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AXmgBv1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WEG2Hn9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QPSMLvwF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AXmgBv1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rJXCf6qR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Cm8Q1nDh_sendMessage(_c, 0, m);
  cMsg_9aTUDSbS_sendMessage(_c, 0, m);
  cMsg_WEG2Hn9T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_As8XDcuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Cm8Q1nDh_sendMessage(_c, 0, m);
  cMsg_ow1oIpuT_sendMessage(_c, 0, m);
  cMsg_pdiXRLn4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0bQNExR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_PQhXkGvd_sendMessage(_c, 0, m);
  cMsg_9aTUDSbS_sendMessage(_c, 0, m);
  cMsg_pdiXRLn4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JRgzl08i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TsubG2oM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GJAquo2a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IeqQzsru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TsubG2oM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GJAquo2a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pNbm5kuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YZCqk43H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_87w6fL8i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i5CsqZPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YZCqk43H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_87w6fL8i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CiuD8DWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MapMpVQi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ju3Z8l6Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EydiT9rH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MapMpVQi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ju3Z8l6Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8PBgVW7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_JRgzl08i_sendMessage(_c, 0, m);
  cMsg_i5CsqZPa_sendMessage(_c, 0, m);
  cMsg_EydiT9rH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wVq0tv81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_IeqQzsru_sendMessage(_c, 0, m);
  cMsg_pNbm5kuu_sendMessage(_c, 0, m);
  cMsg_EydiT9rH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GrWIzNn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_IeqQzsru_sendMessage(_c, 0, m);
  cMsg_i5CsqZPa_sendMessage(_c, 0, m);
  cMsg_CiuD8DWW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uZDmSndc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EkxhFagN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0vFWIzcU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gFAbtdQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EkxhFagN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0vFWIzcU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JyKjqHXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tstuY3Ai_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BHVIJqFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RQqwSecQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tstuY3Ai_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BHVIJqFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dN96A9i2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ngPIAkgm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yy2KLvPY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4tPbexbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ngPIAkgm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yy2KLvPY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XMIQKfai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_gFAbtdQE_sendMessage(_c, 0, m);
  cMsg_RQqwSecQ_sendMessage(_c, 0, m);
  cMsg_4tPbexbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dXSHLAfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_gFAbtdQE_sendMessage(_c, 0, m);
  cMsg_JyKjqHXX_sendMessage(_c, 0, m);
  cMsg_dN96A9i2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zdNlS537_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_uZDmSndc_sendMessage(_c, 0, m);
  cMsg_JyKjqHXX_sendMessage(_c, 0, m);
  cMsg_4tPbexbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NGDy8brS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_PQhXkGvd_sendMessage(_c, 0, m);
  cMsg_ow1oIpuT_sendMessage(_c, 0, m);
  cMsg_WEG2Hn9T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RYypMJtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_uZDmSndc_sendMessage(_c, 0, m);
  cMsg_RQqwSecQ_sendMessage(_c, 0, m);
  cMsg_dN96A9i2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_O1R7IVBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LB0A0j2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EJRI6XAU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Pb7bexez, 0, m, &cSlice_Pb7bexez_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BMRlP2i5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Pb7bexez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iSefpGwO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iSefpGwO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_iBNn5ckW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iSefpGwO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iSefpGwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jlP8cUPj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dIb9pIA2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mFvMQJ40, 0, m, &cSlice_mFvMQJ40_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WOXkRgYG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_mFvMQJ40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SJqx18Co_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SJqx18Co_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_NwxnDSmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SJqx18Co_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_SJqx18Co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ayjhjz9g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WOXkRgYG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_faT7fuze, 0, m, &cSlice_faT7fuze_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EJRI6XAU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_faT7fuze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8ZAuUxOZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8ZAuUxOZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_g8tNmKsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8ZAuUxOZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8ZAuUxOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Gt3Vq36Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BMRlP2i5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6UYS1LrN, 0, m, &cSlice_6UYS1LrN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_B67KEVk6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_6UYS1LrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SObdD89c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SObdD89c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9UOxWWwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SObdD89c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_SObdD89c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yvG6sply_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_B67KEVk6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gfoaeLXd, 0, m, &cSlice_gfoaeLXd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fzWg87Di_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gfoaeLXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jchPW2a5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jchPW2a5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yaeEgAZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jchPW2a5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jchPW2a5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JrZy6zSo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_p6fzlnNW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7sb8zyEf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7sb8zyEf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rfOgalhJ, 1, m, &cDelay_rfOgalhJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1HXZgjU5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rfOgalhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rfOgalhJ, m);
  cMsg_fRZUhy4O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7sb8zyEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rfOgalhJ, 0, m, &cDelay_rfOgalhJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1HXZgjU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rfOgalhJ, 0, m, &cDelay_rfOgalhJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_HE6nO6UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UujdfMmp, HV_BINOP_SUBTRACT, 0, m, &cBinop_UujdfMmp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_VEvNRyfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mds6nfkK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KJBlkulu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mds6nfkK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_TgHdAcS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HE6nO6UW, 0, m, &cVar_HE6nO6UW_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_xECpFu9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rNu9nLyk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2KjgA1xA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aoR7D2uY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UujdfMmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ObOm9Rd1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ObOm9Rd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Mq7BnLso_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mq7BnLso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_S5jscF8c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xrdoXAvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VWobYlCG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YTdVoaRW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VWobYlCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VEvNRyfy, 1, m, &cIf_VEvNRyfy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YTdVoaRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_df7cWRu3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mcs10iMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KJBlkulu, 1, m, &cIf_KJBlkulu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_df7cWRu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VEvNRyfy, 0, m, &cIf_VEvNRyfy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S5jscF8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KJBlkulu, 0, m, &cIf_KJBlkulu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rNu9nLyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_aoR7D2uY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HE6nO6UW, 0, m, &cVar_HE6nO6UW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2KjgA1xA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UujdfMmp, HV_BINOP_SUBTRACT, 1, m, &cBinop_UujdfMmp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mds6nfkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sUnt3fmJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fzWg87Di_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BD2EByby, 0, m, &cSlice_BD2EByby_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BD2EByby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qEzRAumn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qEzRAumn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_A2sS1xOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qEzRAumn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qEzRAumn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_w1RKZsje_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IkMFuFVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bCVl9EtW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f21fVW1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EXuIzKoZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_8RoJ6gK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0EbCbiso, 0, m, &cVar_0EbCbiso_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LB0A0j2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eIRCpUjN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AgVB9aut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_p6fzlnNW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ThkIMau9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w3xoOjGE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fRZUhy4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fqOE2GNO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_w3xoOjGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fqOE2GNO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_v6O0kzMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_eTnjcbKs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eTnjcbKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xermVicx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xermVicx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EvvUng9M, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_umAP1ILs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xAIlip3G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Zuv3wBvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_znDCxoPY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_An4hjZTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fROsmkKE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5k49lYlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3GjE7LFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cvRZM7dw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_infEbLxX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Iiby1YWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_p4mDxRfz_sendMessage);
  cMsg_rKqJtGxl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_p4mDxRfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iiby1YWS, 1, m, &cVar_Iiby1YWS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fxdlksZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7MzetPbe_sendMessage(_c, 0, m);
  cMsg_h7lvqwSr_sendMessage(_c, 0, m);
  cMsg_HvgVnbIq_sendMessage(_c, 0, m);
  cMsg_GKAeHh0x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_upwEHxJA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xsjDchXw, 0, m, &cSlice_xsjDchXw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xsjDchXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kpcaI3Lv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kpcaI3Lv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lPSpx9PB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kpcaI3Lv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_kpcaI3Lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AEbFepGH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cYqYOam2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2Gj3Ie8Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2Gj3Ie8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vhLvbwYf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vhLvbwYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_j6eXIkBP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j6eXIkBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HZDS1T1P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8AmG4r2l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8AmG4r2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dhc5MFS3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_HZDS1T1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_peOjgBdz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_peOjgBdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_m8NtTSJK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dhc5MFS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UsllMMLW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UsllMMLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AIPsOfZR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m8NtTSJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pLdTh9VT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_AIPsOfZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZKxiSnUD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pLdTh9VT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aC7DT6sk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZKxiSnUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rMz6RJNI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_rOfM6v9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ine4pwqu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_N2s2pr8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BqwyfoJz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rRlhatrq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IcA8Ay0s_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g6AIGGjg_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gETCvUlv_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BCJPGpCy_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XaMaMFKB_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P1CVCFSK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_IcA8Ay0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sbIZEi7X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_g6AIGGjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5THnwsyx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gETCvUlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i2AR5pbN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BCJPGpCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1PW9xIg4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XaMaMFKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p8xhizZ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_P1CVCFSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VaoPIbBJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_AEQ82mGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gpmebOqA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Q5uq7DpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sCJLSGpl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sISBCMaH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ijk1JnZk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ijk1JnZk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9082iQtt, 1, m, &cDelay_9082iQtt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q6tMAXIc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9082iQtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9082iQtt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AEQ82mGn, 0, m, &cIf_AEQ82mGn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ijk1JnZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9082iQtt, 0, m, &cDelay_9082iQtt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q6tMAXIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9082iQtt, 0, m, &cDelay_9082iQtt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4fQODDhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sFLcTZ41_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DIvApouQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hw8gU0Xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XxD73twi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TdSbNF0Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TdSbNF0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sISBCMaH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XxD73twi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AEQ82mGn, 1, m, &cIf_AEQ82mGn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DIvApouQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q5uq7DpR, 0, m, &cIf_Q5uq7DpR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sFLcTZ41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q5uq7DpR, 1, m, &cIf_Q5uq7DpR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sCJLSGpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e7Spewh2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gpmebOqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e7Spewh2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_XY9h36C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TiSlDaWd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hxWQB3ZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xHqdRZT1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8dfLmymF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rM9Lbqke_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rM9Lbqke_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0MgV46Z2, 1, m, &cDelay_0MgV46Z2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nDetkCmA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0MgV46Z2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0MgV46Z2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XY9h36C0, 0, m, &cIf_XY9h36C0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rM9Lbqke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0MgV46Z2, 0, m, &cDelay_0MgV46Z2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nDetkCmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0MgV46Z2, 0, m, &cDelay_0MgV46Z2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HYBFuJet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FXr1Tc6Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6PbIbNZE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z3NtQd9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NRTbu1cG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mKP60iea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mKP60iea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8dfLmymF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NRTbu1cG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XY9h36C0, 1, m, &cIf_XY9h36C0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6PbIbNZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hxWQB3ZC, 0, m, &cIf_hxWQB3ZC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FXr1Tc6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hxWQB3ZC, 1, m, &cIf_hxWQB3ZC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xHqdRZT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7sguzfOG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TiSlDaWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7sguzfOG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_g9Dedvue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oUC6gW58_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qjAzY1FE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hKrCwbIW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xUeS0wqh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VjlHI3Aj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VjlHI3Aj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wRADg0UY, 1, m, &cDelay_wRADg0UY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p7p2LqQQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wRADg0UY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wRADg0UY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_g9Dedvue, 0, m, &cIf_g9Dedvue_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VjlHI3Aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wRADg0UY, 0, m, &cDelay_wRADg0UY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p7p2LqQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wRADg0UY, 0, m, &cDelay_wRADg0UY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JUO9kJX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FY6e8Mh2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dKTs6c5c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aYw8N7GC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mc4lAJ7F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZPDSNDsi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZPDSNDsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xUeS0wqh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mc4lAJ7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g9Dedvue, 1, m, &cIf_g9Dedvue_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dKTs6c5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qjAzY1FE, 0, m, &cIf_qjAzY1FE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FY6e8Mh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qjAzY1FE, 1, m, &cIf_qjAzY1FE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hKrCwbIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZdQX6UkK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oUC6gW58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZdQX6UkK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3dgfP4Qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5PLipCyX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sTXeoL8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TWxEVhWE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_efO0oacL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_l0xjLych_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_l0xjLych_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Cqffm0lb, 1, m, &cDelay_Cqffm0lb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zwb0rS1a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Cqffm0lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cqffm0lb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3dgfP4Qq, 0, m, &cIf_3dgfP4Qq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l0xjLych_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cqffm0lb, 0, m, &cDelay_Cqffm0lb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zwb0rS1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cqffm0lb, 0, m, &cDelay_Cqffm0lb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pzpvcVcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V07tf5hk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nyuCswzE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X9y0d27F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zEXRAvh7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4KYK0Ona_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4KYK0Ona_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_efO0oacL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zEXRAvh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3dgfP4Qq, 1, m, &cIf_3dgfP4Qq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nyuCswzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sTXeoL8B, 0, m, &cIf_sTXeoL8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V07tf5hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sTXeoL8B, 1, m, &cIf_sTXeoL8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TWxEVhWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wOSRRnGQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5PLipCyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wOSRRnGQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oH1U9KOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sDEPD7KA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_t3EP04e8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HoPsFl4m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qTZSLlQi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2js7okwt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2js7okwt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_O8bupDjz, 1, m, &cDelay_O8bupDjz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ht6MHuII_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_O8bupDjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O8bupDjz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oH1U9KOz, 0, m, &cIf_oH1U9KOz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2js7okwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_O8bupDjz, 0, m, &cDelay_O8bupDjz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ht6MHuII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_O8bupDjz, 0, m, &cDelay_O8bupDjz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BYHNXiyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A461Gb9Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zsQdefSQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PQXS0B5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XKMfTqb6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FuQMiHcF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FuQMiHcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qTZSLlQi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XKMfTqb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oH1U9KOz, 1, m, &cIf_oH1U9KOz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zsQdefSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t3EP04e8, 0, m, &cIf_t3EP04e8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A461Gb9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t3EP04e8, 1, m, &cIf_t3EP04e8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HoPsFl4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kbKfvAp6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sDEPD7KA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kbKfvAp6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sKbU2Ao0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4EDow8RO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6xwx0NYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xqK4HtbR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Qxfs05ze_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IldO4qzC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IldO4qzC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wdkRrTBM, 1, m, &cDelay_wdkRrTBM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rlyHYcaU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wdkRrTBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wdkRrTBM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sKbU2Ao0, 0, m, &cIf_sKbU2Ao0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IldO4qzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wdkRrTBM, 0, m, &cDelay_wdkRrTBM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rlyHYcaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wdkRrTBM, 0, m, &cDelay_wdkRrTBM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BXT96fCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cnzi9ppP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F1lvXZjc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0TYKD7Jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iR9yY4gV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8V6yLC1P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8V6yLC1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Qxfs05ze_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iR9yY4gV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sKbU2Ao0, 1, m, &cIf_sKbU2Ao0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F1lvXZjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6xwx0NYw, 0, m, &cIf_6xwx0NYw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cnzi9ppP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6xwx0NYw, 1, m, &cIf_6xwx0NYw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xqK4HtbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KScbNcDK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4EDow8RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KScbNcDK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YrPAfTKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_D607lSFW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3Y66JFZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cNRUssEQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9jN3NlDl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oxZ0JTTC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oxZ0JTTC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wzPEvjgL, 1, m, &cDelay_wzPEvjgL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S8XsjaVH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wzPEvjgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wzPEvjgL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YrPAfTKc, 0, m, &cIf_YrPAfTKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oxZ0JTTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wzPEvjgL, 0, m, &cDelay_wzPEvjgL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S8XsjaVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wzPEvjgL, 0, m, &cDelay_wzPEvjgL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0F1qQbIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j9CvPbdQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jk44fqlM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EosCStmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kCQi6EeF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tIOqLsX0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tIOqLsX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9jN3NlDl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kCQi6EeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YrPAfTKc, 1, m, &cIf_YrPAfTKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jk44fqlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Y66JFZ3, 0, m, &cIf_3Y66JFZ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j9CvPbdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Y66JFZ3, 1, m, &cIf_3Y66JFZ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cNRUssEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QgOHtB8W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_D607lSFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QgOHtB8W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LDZzyc3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ulvm6aOo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4FKuDM62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_stW3tZ2I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oRH3atKO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lvtY4WoE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lvtY4WoE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_l3idUGzO, 1, m, &cDelay_l3idUGzO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Znqv05D_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_l3idUGzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_l3idUGzO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LDZzyc3W, 0, m, &cIf_LDZzyc3W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lvtY4WoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_l3idUGzO, 0, m, &cDelay_l3idUGzO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3Znqv05D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_l3idUGzO, 0, m, &cDelay_l3idUGzO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OMNDr4dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EG87VDQ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bvsOIo4J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Dckz9dSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y9lfkMrM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1rJTKTFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y9lfkMrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LDZzyc3W, 1, m, &cIf_LDZzyc3W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1rJTKTFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oRH3atKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bvsOIo4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4FKuDM62, 0, m, &cIf_4FKuDM62_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EG87VDQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4FKuDM62, 1, m, &cIf_4FKuDM62_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_stW3tZ2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lub09x2W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ulvm6aOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lub09x2W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bmbxXUsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lpwlncR1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LAtwhTOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mzgv3olV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9x4l6ZaK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UvrnGqFS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UvrnGqFS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ErhMvv75, 1, m, &cDelay_ErhMvv75_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kNEOv6tN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ErhMvv75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ErhMvv75, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bmbxXUsw, 0, m, &cIf_bmbxXUsw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UvrnGqFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ErhMvv75, 0, m, &cDelay_ErhMvv75_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kNEOv6tN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ErhMvv75, 0, m, &cDelay_ErhMvv75_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iKmlZYsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BPeZxJ4l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tU1G8knw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OI7tLgR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xO5fomdF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WjaVbT3G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xO5fomdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bmbxXUsw, 1, m, &cIf_bmbxXUsw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WjaVbT3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9x4l6ZaK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BPeZxJ4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LAtwhTOW, 1, m, &cIf_LAtwhTOW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tU1G8knw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LAtwhTOW, 0, m, &cIf_LAtwhTOW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mzgv3olV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M4qLKRWz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lpwlncR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M4qLKRWz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YLppH3aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SFh331HN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_e1wIRMuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BJJlACNj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hBZcs1ao_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_81fkRncL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_81fkRncL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fI5Q4QN5, 1, m, &cDelay_fI5Q4QN5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HGr871LE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fI5Q4QN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fI5Q4QN5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YLppH3aL, 0, m, &cIf_YLppH3aL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_81fkRncL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fI5Q4QN5, 0, m, &cDelay_fI5Q4QN5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HGr871LE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fI5Q4QN5, 0, m, &cDelay_fI5Q4QN5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FGIDsvQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lTjlsm6J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J69Alzlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xWWZugHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tk0X6x8z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i7hCwcS1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tk0X6x8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YLppH3aL, 1, m, &cIf_YLppH3aL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i7hCwcS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hBZcs1ao_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lTjlsm6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e1wIRMuy, 1, m, &cIf_e1wIRMuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J69Alzlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e1wIRMuy, 0, m, &cIf_e1wIRMuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BJJlACNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HjEufcug, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SFh331HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HjEufcug, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nlvq0xow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KIk7o8Zs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_OrISnqUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JWnnJrjA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n197tY1q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_e1lgvtwm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_e1lgvtwm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BAYm9xn7, 1, m, &cDelay_BAYm9xn7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A6xOUXnP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BAYm9xn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BAYm9xn7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nlvq0xow, 0, m, &cIf_nlvq0xow_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e1lgvtwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BAYm9xn7, 0, m, &cDelay_BAYm9xn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A6xOUXnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BAYm9xn7, 0, m, &cDelay_BAYm9xn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DOxA13eL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IF5Prn9L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KjMcy9Js_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mkHqiSyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Uw7YuHX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_16p3Ds6G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_16p3Ds6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_n197tY1q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7Uw7YuHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nlvq0xow, 1, m, &cIf_nlvq0xow_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KjMcy9Js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OrISnqUR, 0, m, &cIf_OrISnqUR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IF5Prn9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OrISnqUR, 1, m, &cIf_OrISnqUR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JWnnJrjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Wi290KZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KIk7o8Zs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Wi290KZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_k3gqYIte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DrNdG0TE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4G5Nt3iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6pHrJHU4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3dlULuyK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WUstYoJz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WUstYoJz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4dn0YQeG, 1, m, &cDelay_4dn0YQeG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lzanaGj3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4dn0YQeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4dn0YQeG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_k3gqYIte, 0, m, &cIf_k3gqYIte_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WUstYoJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4dn0YQeG, 0, m, &cDelay_4dn0YQeG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lzanaGj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4dn0YQeG, 0, m, &cDelay_4dn0YQeG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sjWuH8xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cyaGiuQZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_exhTBljA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jXags57R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BRXDdN8b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ENvQMPXL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BRXDdN8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k3gqYIte, 1, m, &cIf_k3gqYIte_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ENvQMPXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3dlULuyK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_exhTBljA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4G5Nt3iy, 0, m, &cIf_4G5Nt3iy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cyaGiuQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4G5Nt3iy, 1, m, &cIf_4G5Nt3iy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6pHrJHU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L5mr6iNo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DrNdG0TE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L5mr6iNo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sbIZEi7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_lu058dql_sendMessage(_c, 0, m);
  cMsg_s3161SS9_sendMessage(_c, 0, m);
  cMsg_4B3GPz1a_sendMessage(_c, 0, m);
  cMsg_N7Mu3A0m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5THnwsyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_lu058dql_sendMessage(_c, 0, m);
  cMsg_8intrUQk_sendMessage(_c, 0, m);
  cMsg_sCCesTgX_sendMessage(_c, 0, m);
  cMsg_VARvP3at_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_i2AR5pbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_4C4wF3yb_sendMessage(_c, 0, m);
  cMsg_8intrUQk_sendMessage(_c, 0, m);
  cMsg_N7Mu3A0m_sendMessage(_c, 0, m);
  cMsg_gwpO5sxN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1PW9xIg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_4C4wF3yb_sendMessage(_c, 0, m);
  cMsg_TlLO8qo8_sendMessage(_c, 0, m);
  cMsg_4B3GPz1a_sendMessage(_c, 0, m);
  cMsg_NBrIpzl2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p8xhizZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_JDgb7yys_sendMessage(_c, 0, m);
  cMsg_VARvP3at_sendMessage(_c, 0, m);
  cMsg_q6P8MB6w_sendMessage(_c, 0, m);
  cMsg_4B3GPz1a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VaoPIbBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_JDgb7yys_sendMessage(_c, 0, m);
  cMsg_NBrIpzl2_sendMessage(_c, 0, m);
  cMsg_8intrUQk_sendMessage(_c, 0, m);
  cMsg_w01OwQCi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JWz2kQWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hw8gU0Xi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4fQODDhS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jKd7nNKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hw8gU0Xi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4fQODDhS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m97AmSEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_z3NtQd9D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HYBFuJet_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_scQxRcIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_z3NtQd9D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HYBFuJet_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FZBe2eIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aYw8N7GC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JUO9kJX5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wMywJG90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aYw8N7GC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JUO9kJX5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lu058dql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_JWz2kQWa_sendMessage(_c, 0, m);
  cMsg_scQxRcIN_sendMessage(_c, 0, m);
  cMsg_wMywJG90_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4C4wF3yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_jKd7nNKB_sendMessage(_c, 0, m);
  cMsg_m97AmSEi_sendMessage(_c, 0, m);
  cMsg_wMywJG90_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JDgb7yys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_jKd7nNKB_sendMessage(_c, 0, m);
  cMsg_scQxRcIN_sendMessage(_c, 0, m);
  cMsg_FZBe2eIy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_N4GO488U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X9y0d27F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pzpvcVcI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bc79F6Gq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X9y0d27F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pzpvcVcI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Yn4CbKQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PQXS0B5p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BYHNXiyz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_101KvG0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PQXS0B5p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BYHNXiyz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_F3EKOFzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0TYKD7Jk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BXT96fCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Bb9XhQZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0TYKD7Jk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BXT96fCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8intrUQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_bc79F6Gq_sendMessage(_c, 0, m);
  cMsg_101KvG0z_sendMessage(_c, 0, m);
  cMsg_Bb9XhQZW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s3161SS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_bc79F6Gq_sendMessage(_c, 0, m);
  cMsg_Yn4CbKQX_sendMessage(_c, 0, m);
  cMsg_F3EKOFzu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TlLO8qo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_N4GO488U_sendMessage(_c, 0, m);
  cMsg_101KvG0z_sendMessage(_c, 0, m);
  cMsg_F3EKOFzu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PzmvYeSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xWWZugHm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FGIDsvQU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LrIlmh8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xWWZugHm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FGIDsvQU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7tQhyq5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mkHqiSyk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DOxA13eL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mDUT3Mj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mkHqiSyk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DOxA13eL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mTjPmM75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jXags57R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sjWuH8xi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EOPAXaTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jXags57R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sjWuH8xi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NBrIpzl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_PzmvYeSh_sendMessage(_c, 0, m);
  cMsg_mDUT3Mj5_sendMessage(_c, 0, m);
  cMsg_EOPAXaTZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VARvP3at_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_LrIlmh8K_sendMessage(_c, 0, m);
  cMsg_7tQhyq5G_sendMessage(_c, 0, m);
  cMsg_EOPAXaTZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_N7Mu3A0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_LrIlmh8K_sendMessage(_c, 0, m);
  cMsg_mDUT3Mj5_sendMessage(_c, 0, m);
  cMsg_mTjPmM75_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M57OT4fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EosCStmG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0F1qQbIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6FynNDV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EosCStmG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0F1qQbIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EVtJmg51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Dckz9dSd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OMNDr4dg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cHGtPSJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Dckz9dSd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OMNDr4dg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FbvkNi1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OI7tLgR0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iKmlZYsD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xKELCbX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OI7tLgR0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iKmlZYsD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4B3GPz1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_6FynNDV5_sendMessage(_c, 0, m);
  cMsg_cHGtPSJ5_sendMessage(_c, 0, m);
  cMsg_xKELCbX5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sCCesTgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_6FynNDV5_sendMessage(_c, 0, m);
  cMsg_EVtJmg51_sendMessage(_c, 0, m);
  cMsg_FbvkNi1i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_w01OwQCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_M57OT4fo_sendMessage(_c, 0, m);
  cMsg_EVtJmg51_sendMessage(_c, 0, m);
  cMsg_xKELCbX5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_q6P8MB6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_N4GO488U_sendMessage(_c, 0, m);
  cMsg_Yn4CbKQX_sendMessage(_c, 0, m);
  cMsg_Bb9XhQZW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gwpO5sxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_M57OT4fo_sendMessage(_c, 0, m);
  cMsg_cHGtPSJ5_sendMessage(_c, 0, m);
  cMsg_FbvkNi1i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_R4aWj4R5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nWt3QC46_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_B5BLXYxW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5KVMVSmf, 0, m, &cSlice_5KVMVSmf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_X0fYsihK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5KVMVSmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SdSqWgyw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SdSqWgyw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_o3BxUaNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SdSqWgyw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_SdSqWgyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fjK0FJpF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kHq3bTF6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SnpfxD2M, 0, m, &cSlice_SnpfxD2M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_y7xglb8G_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_SnpfxD2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fU20dMIZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fU20dMIZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sUtl7CNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fU20dMIZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fU20dMIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RNn1EDOK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_y7xglb8G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ADOb9MKK, 0, m, &cSlice_ADOb9MKK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_B5BLXYxW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ADOb9MKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5LMXpTMt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5LMXpTMt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Dh8Guek0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5LMXpTMt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5LMXpTMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ytQL2yiy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_X0fYsihK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_R8F0Po3E, 0, m, &cSlice_R8F0Po3E_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dRS34UvF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_R8F0Po3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_O96uoQOm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_O96uoQOm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_LoqW4EPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_O96uoQOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_O96uoQOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Jk0rvQSg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dRS34UvF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sE6N7cJ5, 0, m, &cSlice_sE6N7cJ5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VMYMPITw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sE6N7cJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xYFb4zTF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xYFb4zTF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_i9hEyMSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xYFb4zTF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xYFb4zTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U3MInDzn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BZ2WrjER_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EoknIynK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EoknIynK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_q9dON1FH, 1, m, &cDelay_q9dON1FH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_efD2odLc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_q9dON1FH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q9dON1FH, m);
  cMsg_hTRBe6zu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EoknIynK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_q9dON1FH, 0, m, &cDelay_q9dON1FH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_efD2odLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_q9dON1FH, 0, m, &cDelay_q9dON1FH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_CVVD1gDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0DooFNDo, HV_BINOP_SUBTRACT, 0, m, &cBinop_0DooFNDo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_0W3TtCXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7t3eCbbV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_i3vzggbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7t3eCbbV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_TH3MPeU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CVVD1gDo, 0, m, &cVar_CVVD1gDo_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_gRDr9mRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zgUC649m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CZA3yzb8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TN00Dx0Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0DooFNDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c17HH1Cu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_c17HH1Cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_j6wcQlou_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j6wcQlou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_49UDRt31_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dysl43NA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5o8apIsS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1IopsiRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1IopsiRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4JwWcpZo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_5o8apIsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0W3TtCXC, 1, m, &cIf_0W3TtCXC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IyhUov3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i3vzggbM, 1, m, &cIf_i3vzggbM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4JwWcpZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0W3TtCXC, 0, m, &cIf_0W3TtCXC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_49UDRt31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i3vzggbM, 0, m, &cIf_i3vzggbM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TN00Dx0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CVVD1gDo, 0, m, &cVar_CVVD1gDo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CZA3yzb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0DooFNDo, HV_BINOP_SUBTRACT, 1, m, &cBinop_0DooFNDo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zgUC649m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_7t3eCbbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gx8dbkoU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VMYMPITw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1PkPXkMA, 0, m, &cSlice_1PkPXkMA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1PkPXkMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eaU0rHqd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eaU0rHqd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PetLlyWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eaU0rHqd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eaU0rHqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KoCGRNzx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ine4pwqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r2YfIevf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BqwyfoJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iMgO4h1Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_53rcL26L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N2s2pr8f, 0, m, &cVar_N2s2pr8f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nWt3QC46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_79LUztVd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_THfT65mX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BZ2WrjER_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_F7WuBoqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cVK5dv0V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hTRBe6zu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fw9cbCSV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cVK5dv0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fw9cbCSV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QraX17SH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_wMEqPWRp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wMEqPWRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3uXmHnXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3uXmHnXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t8jeFpDX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_DcVn2d5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MOFvYSul_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8hkMbGJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jwboquZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RWu0Cxat_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TICVzEzN_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MDLfxvUf_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fCN4Byki_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C7LCEh0L_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkhUOV7q_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TQ5IpwjC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_TICVzEzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GLXtzXIv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_MDLfxvUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p41x2jMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fCN4Byki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6gv1ZcOP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_C7LCEh0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KLVab5oN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_kkhUOV7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fd8atxec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_TQ5IpwjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FdPF9byf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Gs03ZVh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L0NMNpzD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LeDjlmJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tr6H2BbY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6r8WVGZ0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DMoVjaGB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DMoVjaGB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AYUibBt5, 1, m, &cDelay_AYUibBt5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZGwtl2mK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AYUibBt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AYUibBt5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Gs03ZVh6, 0, m, &cIf_Gs03ZVh6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DMoVjaGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AYUibBt5, 0, m, &cDelay_AYUibBt5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZGwtl2mK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AYUibBt5, 0, m, &cDelay_AYUibBt5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5m9bMR37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DNg7x5ml_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ClQPE8hd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cQefDVdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nG28vu9l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8LkOCjJ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8LkOCjJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6r8WVGZ0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nG28vu9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gs03ZVh6, 1, m, &cIf_Gs03ZVh6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DNg7x5ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeDjlmJx, 1, m, &cIf_LeDjlmJx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ClQPE8hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeDjlmJx, 0, m, &cIf_LeDjlmJx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tr6H2BbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_06v0ov2y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_L0NMNpzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_06v0ov2y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_q8TihbSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cnWM7Zc5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_goDZZJKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cc5Zv346_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9s1pLuJh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SXlt5fSL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SXlt5fSL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GZf33aDM, 1, m, &cDelay_GZf33aDM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zYOYvx5l_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GZf33aDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GZf33aDM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_q8TihbSV, 0, m, &cIf_q8TihbSV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SXlt5fSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GZf33aDM, 0, m, &cDelay_GZf33aDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zYOYvx5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GZf33aDM, 0, m, &cDelay_GZf33aDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KVMyqpJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xngqkivj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DgvRN1br_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t3me3zei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RW1xRRdf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eznmxjYf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eznmxjYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9s1pLuJh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RW1xRRdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q8TihbSV, 1, m, &cIf_q8TihbSV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DgvRN1br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_goDZZJKi, 0, m, &cIf_goDZZJKi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xngqkivj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_goDZZJKi, 1, m, &cIf_goDZZJKi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cc5Zv346_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aTIrxYQX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cnWM7Zc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aTIrxYQX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_QV7MQsJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Jyyy9aQM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hRLlkKwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_f8QWsJ8C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Fw8IO5d5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lJH0hYeb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lJH0hYeb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gYfhUSM8, 1, m, &cDelay_gYfhUSM8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XUJvS2dV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gYfhUSM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gYfhUSM8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QV7MQsJq, 0, m, &cIf_QV7MQsJq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lJH0hYeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gYfhUSM8, 0, m, &cDelay_gYfhUSM8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XUJvS2dV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gYfhUSM8, 0, m, &cDelay_gYfhUSM8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kZCyhPBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_307HhC6c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hAabc2Ap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V4OG40c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QCfp1VpB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4yOvuBRB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QCfp1VpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QV7MQsJq, 1, m, &cIf_QV7MQsJq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4yOvuBRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Fw8IO5d5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_307HhC6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hRLlkKwJ, 1, m, &cIf_hRLlkKwJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hAabc2Ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hRLlkKwJ, 0, m, &cIf_hRLlkKwJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f8QWsJ8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lpzUfHtL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Jyyy9aQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lpzUfHtL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_b2rKToXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_evOLcgre_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JFyNgjIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TsKldpMF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_36ih24qD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cAY2Tiei_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cAY2Tiei_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Fh2HaYbK, 1, m, &cDelay_Fh2HaYbK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HW0MChiV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Fh2HaYbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Fh2HaYbK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_b2rKToXh, 0, m, &cIf_b2rKToXh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cAY2Tiei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fh2HaYbK, 0, m, &cDelay_Fh2HaYbK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HW0MChiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fh2HaYbK, 0, m, &cDelay_Fh2HaYbK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jXaQVgal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XqVcIakj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QODpDHXB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gQNjrExk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C7aZOlwE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ujm22wUp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C7aZOlwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b2rKToXh, 1, m, &cIf_b2rKToXh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ujm22wUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_36ih24qD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XqVcIakj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JFyNgjIf, 1, m, &cIf_JFyNgjIf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QODpDHXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JFyNgjIf, 0, m, &cIf_JFyNgjIf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TsKldpMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TNe89WGO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_evOLcgre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TNe89WGO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PsbIYKWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VFjSPP9O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SfRiob92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zsGhEhQS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NzapER2v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ePTs9WDt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ePTs9WDt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wZFSc2ia, 1, m, &cDelay_wZFSc2ia_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VbsJB2BZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wZFSc2ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wZFSc2ia, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PsbIYKWb, 0, m, &cIf_PsbIYKWb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ePTs9WDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wZFSc2ia, 0, m, &cDelay_wZFSc2ia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VbsJB2BZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wZFSc2ia, 0, m, &cDelay_wZFSc2ia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lExaG8CH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZI6P0HCh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JZxHvz4E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S4LnlgxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xyfd18Ja_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PVDMYCvn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PVDMYCvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NzapER2v_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xyfd18Ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PsbIYKWb, 1, m, &cIf_PsbIYKWb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZI6P0HCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SfRiob92, 1, m, &cIf_SfRiob92_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JZxHvz4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SfRiob92, 0, m, &cIf_SfRiob92_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zsGhEhQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YO57sY5g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VFjSPP9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YO57sY5g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Fz9iZt2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HOq0Mc4r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3gNr59uG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YcEwRz8P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_68lu0Hgk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8cRKGChH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8cRKGChH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0haWYZ33, 1, m, &cDelay_0haWYZ33_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V3LWtO67_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0haWYZ33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0haWYZ33, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Fz9iZt2E, 0, m, &cIf_Fz9iZt2E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8cRKGChH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0haWYZ33, 0, m, &cDelay_0haWYZ33_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V3LWtO67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0haWYZ33, 0, m, &cDelay_0haWYZ33_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U7GeTDiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kXhc6fyD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q9oAaTDI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PMKS0EYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nutoRJ8j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mKGXWnAl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mKGXWnAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_68lu0Hgk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nutoRJ8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fz9iZt2E, 1, m, &cIf_Fz9iZt2E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q9oAaTDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3gNr59uG, 0, m, &cIf_3gNr59uG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kXhc6fyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3gNr59uG, 1, m, &cIf_3gNr59uG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YcEwRz8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KZRLzRkT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HOq0Mc4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KZRLzRkT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cnrbjvXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eAzxKmbL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1BH4Ezgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i2pj9HK2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UJp2eWmW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xLzwG3Ob_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xLzwG3Ob_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0qvUFvq7, 1, m, &cDelay_0qvUFvq7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5WpCbbQS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0qvUFvq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0qvUFvq7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cnrbjvXM, 0, m, &cIf_cnrbjvXM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xLzwG3Ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0qvUFvq7, 0, m, &cDelay_0qvUFvq7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5WpCbbQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0qvUFvq7, 0, m, &cDelay_0qvUFvq7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2kIim2Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UwaDzIRo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D1fu2NDL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2iohHgWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HpSfaf29_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G4n6Q7mH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G4n6Q7mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UJp2eWmW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HpSfaf29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cnrbjvXM, 1, m, &cIf_cnrbjvXM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D1fu2NDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1BH4Ezgi, 0, m, &cIf_1BH4Ezgi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UwaDzIRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1BH4Ezgi, 1, m, &cIf_1BH4Ezgi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i2pj9HK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OfC7p1tY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eAzxKmbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OfC7p1tY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_emumqg22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FAuVt2EC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Bq7u471k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pRw6bcQY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_p3VhfhpV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3lwe3y6b_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3lwe3y6b_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sYLn6XTl, 1, m, &cDelay_sYLn6XTl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svrAaFWn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sYLn6XTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sYLn6XTl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_emumqg22, 0, m, &cIf_emumqg22_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3lwe3y6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sYLn6XTl, 0, m, &cDelay_sYLn6XTl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_svrAaFWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sYLn6XTl, 0, m, &cDelay_sYLn6XTl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ai4zl9n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rSIqudCX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UR4xhX4u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2RMiXlLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6KmFQ2yy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n52GNqCG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n52GNqCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_p3VhfhpV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6KmFQ2yy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_emumqg22, 1, m, &cIf_emumqg22_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UR4xhX4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bq7u471k, 0, m, &cIf_Bq7u471k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rSIqudCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bq7u471k, 1, m, &cIf_Bq7u471k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pRw6bcQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KEzHY0W9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FAuVt2EC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KEzHY0W9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9P4oGQza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_52CLrHr8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1SiX9hjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GrqA7U2b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8XkZnJDA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QYYJLUod_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QYYJLUod_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4rYPuzP7, 1, m, &cDelay_4rYPuzP7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_16AlDa5N_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4rYPuzP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4rYPuzP7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9P4oGQza, 0, m, &cIf_9P4oGQza_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QYYJLUod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4rYPuzP7, 0, m, &cDelay_4rYPuzP7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_16AlDa5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4rYPuzP7, 0, m, &cDelay_4rYPuzP7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6xKK4tle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4hd31o3l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eJ9fIFPJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ix1YdfSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5ofKi7rT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rxMBDzuB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rxMBDzuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8XkZnJDA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5ofKi7rT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9P4oGQza, 1, m, &cIf_9P4oGQza_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4hd31o3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1SiX9hjg, 1, m, &cIf_1SiX9hjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eJ9fIFPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1SiX9hjg, 0, m, &cIf_1SiX9hjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GrqA7U2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3yCyl5fj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_52CLrHr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3yCyl5fj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yntZjqAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zynaqnxr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Zz7b1Yrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0AbSsy40_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P7GcR9KR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_phDO17aq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_phDO17aq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2sYriDIu, 1, m, &cDelay_2sYriDIu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r17jujz4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2sYriDIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2sYriDIu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yntZjqAa, 0, m, &cIf_yntZjqAa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_phDO17aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2sYriDIu, 0, m, &cDelay_2sYriDIu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r17jujz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2sYriDIu, 0, m, &cDelay_2sYriDIu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YB8psM4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7gW4VeDd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_maQ5OyOd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VC42Eqcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kFAFQEgp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UJnfgrKy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UJnfgrKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_P7GcR9KR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kFAFQEgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yntZjqAa, 1, m, &cIf_yntZjqAa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_maQ5OyOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zz7b1Yrc, 0, m, &cIf_Zz7b1Yrc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7gW4VeDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zz7b1Yrc, 1, m, &cIf_Zz7b1Yrc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0AbSsy40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nTvlXFPr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zynaqnxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nTvlXFPr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_dN4Od6dW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yBPN1fZP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FZE15HHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RBdk5y4L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cYwJll6C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EgJ8yTVF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EgJ8yTVF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IxjM1C0E, 1, m, &cDelay_IxjM1C0E_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rtp1EKYF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IxjM1C0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IxjM1C0E, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dN4Od6dW, 0, m, &cIf_dN4Od6dW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EgJ8yTVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IxjM1C0E, 0, m, &cDelay_IxjM1C0E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rtp1EKYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IxjM1C0E, 0, m, &cDelay_IxjM1C0E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EGN6bulq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WfOwCnEv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qsH2Kmzp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l9qNykmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QsaY4it6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uhYMexpS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uhYMexpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cYwJll6C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QsaY4it6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dN4Od6dW, 1, m, &cIf_dN4Od6dW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qsH2Kmzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FZE15HHC, 0, m, &cIf_FZE15HHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WfOwCnEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FZE15HHC, 1, m, &cIf_FZE15HHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RBdk5y4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GQ2RnPk3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yBPN1fZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GQ2RnPk3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CG42HSUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9J7SDIsu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8umYTvb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ShIa2OXY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7kXDwv7u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zOeiHgE4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zOeiHgE4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4BaKOyFS, 1, m, &cDelay_4BaKOyFS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D9gGT3xg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4BaKOyFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4BaKOyFS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CG42HSUW, 0, m, &cIf_CG42HSUW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zOeiHgE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4BaKOyFS, 0, m, &cDelay_4BaKOyFS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D9gGT3xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4BaKOyFS, 0, m, &cDelay_4BaKOyFS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J1y62CT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1l4Jl9iI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3AYfL3It_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Q6XteVwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HGbmJEc7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uP17KX7d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uP17KX7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7kXDwv7u_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HGbmJEc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CG42HSUW, 1, m, &cIf_CG42HSUW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3AYfL3It_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8umYTvb3, 0, m, &cIf_8umYTvb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1l4Jl9iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8umYTvb3, 1, m, &cIf_8umYTvb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ShIa2OXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DrL1fQT8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9J7SDIsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DrL1fQT8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GLXtzXIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_7NaZs2ET_sendMessage(_c, 0, m);
  cMsg_NrktlQMn_sendMessage(_c, 0, m);
  cMsg_2IL3lmi2_sendMessage(_c, 0, m);
  cMsg_FhRz8gEN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p41x2jMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_7NaZs2ET_sendMessage(_c, 0, m);
  cMsg_9crKrtsT_sendMessage(_c, 0, m);
  cMsg_gL5r61kc_sendMessage(_c, 0, m);
  cMsg_kyRQ6LVF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6gv1ZcOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_9cCUHPER_sendMessage(_c, 0, m);
  cMsg_9crKrtsT_sendMessage(_c, 0, m);
  cMsg_FhRz8gEN_sendMessage(_c, 0, m);
  cMsg_2Nsgda7S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KLVab5oN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_9cCUHPER_sendMessage(_c, 0, m);
  cMsg_3WS7qq8F_sendMessage(_c, 0, m);
  cMsg_2IL3lmi2_sendMessage(_c, 0, m);
  cMsg_7JbNXkAu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fd8atxec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_SrgE42yT_sendMessage(_c, 0, m);
  cMsg_kyRQ6LVF_sendMessage(_c, 0, m);
  cMsg_bjc9BYGx_sendMessage(_c, 0, m);
  cMsg_2IL3lmi2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FdPF9byf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_SrgE42yT_sendMessage(_c, 0, m);
  cMsg_7JbNXkAu_sendMessage(_c, 0, m);
  cMsg_9crKrtsT_sendMessage(_c, 0, m);
  cMsg_7jDBEKyt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RN9Z0o96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cQefDVdZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5m9bMR37_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o51V0MCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cQefDVdZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5m9bMR37_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fAHPMx0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t3me3zei_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KVMyqpJc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sy6KWVoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t3me3zei_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KVMyqpJc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5Xf2K89o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V4OG40c6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kZCyhPBm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GowExVTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V4OG40c6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kZCyhPBm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7NaZs2ET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_RN9Z0o96_sendMessage(_c, 0, m);
  cMsg_sy6KWVoM_sendMessage(_c, 0, m);
  cMsg_GowExVTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9cCUHPER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_o51V0MCw_sendMessage(_c, 0, m);
  cMsg_fAHPMx0d_sendMessage(_c, 0, m);
  cMsg_GowExVTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SrgE42yT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_o51V0MCw_sendMessage(_c, 0, m);
  cMsg_sy6KWVoM_sendMessage(_c, 0, m);
  cMsg_5Xf2K89o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Sn02WIZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gQNjrExk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jXaQVgal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X7xwOgbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gQNjrExk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jXaQVgal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8Cekkdpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S4LnlgxU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lExaG8CH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qNFRShNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S4LnlgxU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lExaG8CH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VW0qgsak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PMKS0EYC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_U7GeTDiE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y5xNQZ9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PMKS0EYC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_U7GeTDiE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9crKrtsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_X7xwOgbf_sendMessage(_c, 0, m);
  cMsg_qNFRShNV_sendMessage(_c, 0, m);
  cMsg_Y5xNQZ9p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NrktlQMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_X7xwOgbf_sendMessage(_c, 0, m);
  cMsg_8Cekkdpz_sendMessage(_c, 0, m);
  cMsg_VW0qgsak_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3WS7qq8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Sn02WIZ6_sendMessage(_c, 0, m);
  cMsg_qNFRShNV_sendMessage(_c, 0, m);
  cMsg_VW0qgsak_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9RuaU1lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VC42Eqcn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YB8psM4W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_psLfk1jc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VC42Eqcn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YB8psM4W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_seYppuSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_l9qNykmn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EGN6bulq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_baiUU864_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_l9qNykmn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EGN6bulq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_F7GczINj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q6XteVwU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_J1y62CT0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IAvMXe02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q6XteVwU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_J1y62CT0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7JbNXkAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_9RuaU1lr_sendMessage(_c, 0, m);
  cMsg_baiUU864_sendMessage(_c, 0, m);
  cMsg_IAvMXe02_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kyRQ6LVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_psLfk1jc_sendMessage(_c, 0, m);
  cMsg_seYppuSW_sendMessage(_c, 0, m);
  cMsg_IAvMXe02_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FhRz8gEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_psLfk1jc_sendMessage(_c, 0, m);
  cMsg_baiUU864_sendMessage(_c, 0, m);
  cMsg_F7GczINj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NRL8R9hS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2iohHgWA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2kIim2Rs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HJYwCsEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2iohHgWA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2kIim2Rs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uCS2J43h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2RMiXlLo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ai4zl9n0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dppw6P3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2RMiXlLo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ai4zl9n0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jOItGMoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ix1YdfSW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6xKK4tle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r46Y4mNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ix1YdfSW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6xKK4tle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2IL3lmi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_HJYwCsEV_sendMessage(_c, 0, m);
  cMsg_Dppw6P3s_sendMessage(_c, 0, m);
  cMsg_r46Y4mNM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gL5r61kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_HJYwCsEV_sendMessage(_c, 0, m);
  cMsg_uCS2J43h_sendMessage(_c, 0, m);
  cMsg_jOItGMoj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7jDBEKyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_NRL8R9hS_sendMessage(_c, 0, m);
  cMsg_uCS2J43h_sendMessage(_c, 0, m);
  cMsg_r46Y4mNM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bjc9BYGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Sn02WIZ6_sendMessage(_c, 0, m);
  cMsg_8Cekkdpz_sendMessage(_c, 0, m);
  cMsg_Y5xNQZ9p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2Nsgda7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_NRL8R9hS_sendMessage(_c, 0, m);
  cMsg_Dppw6P3s_sendMessage(_c, 0, m);
  cMsg_jOItGMoj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_bLkseGDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PE46Qtxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NkU3J8n4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hXTz1ABP, 0, m, &cSlice_hXTz1ABP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Fik9qC92_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_hXTz1ABP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_li0H2yp1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_li0H2yp1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PDdGidzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_li0H2yp1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_li0H2yp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HjibjBdg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CqikwZhI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5LV7DwKu, 0, m, &cSlice_5LV7DwKu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kx8JDM3V_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5LV7DwKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kO860Hga_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kO860Hga_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MZZHCzlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kO860Hga_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_kO860Hga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UfK0arfv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kx8JDM3V_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_stTI8Zk3, 0, m, &cSlice_stTI8Zk3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NkU3J8n4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_stTI8Zk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1YGuTfgB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1YGuTfgB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_cS3lFCWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1YGuTfgB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_1YGuTfgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wB8kp16t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Fik9qC92_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DZcQTnxI, 0, m, &cSlice_DZcQTnxI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Wg7Vhldh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_DZcQTnxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XDKGaKfm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XDKGaKfm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_X11oOzSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XDKGaKfm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XDKGaKfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cSklG3t5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Wg7Vhldh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3JmQvSjg, 0, m, &cSlice_3JmQvSjg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MABW5dn0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3JmQvSjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_D8HI3t9r_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_D8HI3t9r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GM85VBZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D8HI3t9r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_D8HI3t9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1V5Urq4x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NLPpE1nw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5nFhPRWL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5nFhPRWL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JagwMNw9, 1, m, &cDelay_JagwMNw9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wUFOjsM1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JagwMNw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JagwMNw9, m);
  cMsg_0NYGgHot_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5nFhPRWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JagwMNw9, 0, m, &cDelay_JagwMNw9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wUFOjsM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JagwMNw9, 0, m, &cDelay_JagwMNw9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_RjQsoxzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KBSiokfF, HV_BINOP_SUBTRACT, 0, m, &cBinop_KBSiokfF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ocPoBjns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_02ekKrSR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eG0ON97L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_02ekKrSR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_6hbp07Ll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RjQsoxzy, 0, m, &cVar_RjQsoxzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_s06cSl1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Y1SHZka_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_johFtbVH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E1tYWzbq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KBSiokfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PFpO2z2I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PFpO2z2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mUVjPuyf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mUVjPuyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SIfkMHf2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gcpatnRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BqhZAzPn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PpMwCSMA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BqhZAzPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ocPoBjns, 1, m, &cIf_ocPoBjns_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PpMwCSMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KumW6tt2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_defB8Lot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eG0ON97L, 1, m, &cIf_eG0ON97L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KumW6tt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ocPoBjns, 0, m, &cIf_ocPoBjns_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SIfkMHf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eG0ON97L, 0, m, &cIf_eG0ON97L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Y1SHZka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_E1tYWzbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RjQsoxzy, 0, m, &cVar_RjQsoxzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_johFtbVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KBSiokfF, HV_BINOP_SUBTRACT, 1, m, &cBinop_KBSiokfF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_02ekKrSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ia7I8vH7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MABW5dn0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FSFOJBxZ, 0, m, &cSlice_FSFOJBxZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_FSFOJBxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Skj2tUz8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Skj2tUz8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Qt2vkRgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Skj2tUz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Skj2tUz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nZmUCc3U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MOFvYSul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Xxu8Vd2c, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jwboquZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qmGYOjlu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_W5UCY4aJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8hkMbGJs, 0, m, &cVar_8hkMbGJs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PE46Qtxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sjifc3bi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1A71QyG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H3ttCw5n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_s6iDBTfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NLPpE1nw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0NYGgHot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PUNHRokT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H3ttCw5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PUNHRokT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xZ4ICRDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_szToMdxm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_szToMdxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_92xrUYDI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_92xrUYDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PPHNkKqa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_EGC51EDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_12MgreLE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Z5WewmxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xBVUC3T3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_znjcRjVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mME9hJOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ELsEM9M6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ulCERoUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_smfHHkgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uGSgmtQq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_JLdQCMJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_511GinUh_sendMessage);
  cMsg_40mZowvt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_511GinUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JLdQCMJJ, 1, m, &cVar_JLdQCMJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SBRqU2So_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GiAPxvLp_sendMessage(_c, 0, m);
  cMsg_jx1KgI5H_sendMessage(_c, 0, m);
  cMsg_dFGYJZ6j_sendMessage(_c, 0, m);
  cMsg_4dPAS59t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dnLmhn9q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OCx7nA4n, 0, m, &cSlice_OCx7nA4n_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OCx7nA4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TEpLwEgb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TEpLwEgb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_1B2dBury_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TEpLwEgb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_TEpLwEgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HMIW50Tt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0hw18niq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZvqTG5MT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZvqTG5MT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_XVDRsoAy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XVDRsoAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fxbJGotU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fxbJGotU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bbg6HUPH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6OCtqoQ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bbg6HUPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qn0yZ60S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6OCtqoQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pWmvvg7p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_qn0yZ60S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4GyNjehE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pWmvvg7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uX5YfZf8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uX5YfZf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yDsLxq4C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4GyNjehE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aRcc6uCX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yDsLxq4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AOIL8kk2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aRcc6uCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hdxUK3Bt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AOIL8kk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wnyHJOKW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_w8gIL8FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_caHADCVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_sut06sUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O8CV7IDD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YBrxEYFv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X2ium0XE_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SKOau1Hj_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y50VWWz5_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JCNxFsUB_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NE2oXOZk_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8l3T2b2h_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_X2ium0XE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9fhgMrpE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SKOau1Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xGAgSe3Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Y50VWWz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WCJRpoW0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JCNxFsUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_49RD4paF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_NE2oXOZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R8zYEQhj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8l3T2b2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QgUqSF9A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_9tKQd3KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ASJFDrFU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xuQbgsSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jZcogxGQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HNNFYnW2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6fp6q971_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6fp6q971_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_V8AVhcz0, 1, m, &cDelay_V8AVhcz0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2t90UDec_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_V8AVhcz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V8AVhcz0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9tKQd3KG, 0, m, &cIf_9tKQd3KG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6fp6q971_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_V8AVhcz0, 0, m, &cDelay_V8AVhcz0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2t90UDec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_V8AVhcz0, 0, m, &cDelay_V8AVhcz0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fICOOLLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HrYNcKtl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4zYavbaE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fpaLkJTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xVzRmSyr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jUjfcY3u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xVzRmSyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9tKQd3KG, 1, m, &cIf_9tKQd3KG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jUjfcY3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HNNFYnW2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HrYNcKtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xuQbgsSr, 1, m, &cIf_xuQbgsSr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4zYavbaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xuQbgsSr, 0, m, &cIf_xuQbgsSr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jZcogxGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vIW2eJ5Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ASJFDrFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vIW2eJ5Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HQniJE11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s8fnUK2I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JT5YK775_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e0a3Pttk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Atv54t4K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5eOpXOC0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5eOpXOC0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XfNgmPtj, 1, m, &cDelay_XfNgmPtj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8hPpoq4R_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XfNgmPtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XfNgmPtj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HQniJE11, 0, m, &cIf_HQniJE11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5eOpXOC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XfNgmPtj, 0, m, &cDelay_XfNgmPtj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8hPpoq4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XfNgmPtj, 0, m, &cDelay_XfNgmPtj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9byfaQMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4gBd1zWy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gFG4MdqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lJcKiaK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j7ALKV09_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MmIPPamq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MmIPPamq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Atv54t4K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_j7ALKV09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HQniJE11, 1, m, &cIf_HQniJE11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4gBd1zWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JT5YK775, 1, m, &cIf_JT5YK775_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gFG4MdqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JT5YK775, 0, m, &cIf_JT5YK775_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e0a3Pttk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eigIZEcC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_s8fnUK2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eigIZEcC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pfHtmWxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PfiPb5Pm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oUjnr0of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ReqYtC7K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3BsCRqUi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IivSm8hA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IivSm8hA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RyssiktB, 1, m, &cDelay_RyssiktB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r3hmV72W_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RyssiktB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RyssiktB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pfHtmWxd, 0, m, &cIf_pfHtmWxd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IivSm8hA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RyssiktB, 0, m, &cDelay_RyssiktB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r3hmV72W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RyssiktB, 0, m, &cDelay_RyssiktB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nGHW9KnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vjBHvVLj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J74yreER_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DTPhalqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UT1Qr6Js_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wjl4HZbW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wjl4HZbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3BsCRqUi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UT1Qr6Js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pfHtmWxd, 1, m, &cIf_pfHtmWxd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J74yreER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oUjnr0of, 0, m, &cIf_oUjnr0of_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vjBHvVLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oUjnr0of, 1, m, &cIf_oUjnr0of_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ReqYtC7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ne6aPGeq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PfiPb5Pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ne6aPGeq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_hnyfnwaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VfiVObtP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2XC6qhC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bJYErOmo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_M05Vroik_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dAgUYzhD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dAgUYzhD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oZASpEX9, 1, m, &cDelay_oZASpEX9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PDY8tC6j_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oZASpEX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oZASpEX9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_hnyfnwaI, 0, m, &cIf_hnyfnwaI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dAgUYzhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oZASpEX9, 0, m, &cDelay_oZASpEX9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PDY8tC6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oZASpEX9, 0, m, &cDelay_oZASpEX9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aiwvQQn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HhgErfIi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yI8QoLTi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2xYHtdK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rBgADwkE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lDI805Fr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lDI805Fr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_M05Vroik_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rBgADwkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hnyfnwaI, 1, m, &cIf_hnyfnwaI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yI8QoLTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2XC6qhC8, 0, m, &cIf_2XC6qhC8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HhgErfIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2XC6qhC8, 1, m, &cIf_2XC6qhC8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bJYErOmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZwmsUNff, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VfiVObtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZwmsUNff, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oqjNYPB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EqTtfRyz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8SCpKquy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZPdAyUne_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P1xPuK7g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_it3H6bds_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_it3H6bds_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IVikXT7N, 1, m, &cDelay_IVikXT7N_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ktm0ipak_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IVikXT7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IVikXT7N, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oqjNYPB5, 0, m, &cIf_oqjNYPB5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_it3H6bds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IVikXT7N, 0, m, &cDelay_IVikXT7N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ktm0ipak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IVikXT7N, 0, m, &cDelay_IVikXT7N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vH587KPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_niGaVpNW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6m4g7Q86_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mMnrOOZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FATpDc1B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_59iefn8C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FATpDc1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oqjNYPB5, 1, m, &cIf_oqjNYPB5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_59iefn8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_P1xPuK7g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_niGaVpNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8SCpKquy, 1, m, &cIf_8SCpKquy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6m4g7Q86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8SCpKquy, 0, m, &cIf_8SCpKquy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZPdAyUne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PFoCM56L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EqTtfRyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PFoCM56L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ScXTvSbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KEIv7PrV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BYmAcvvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RWNMFmcG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ShAoXTTt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1bidUwmL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1bidUwmL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mCqZ7Px6, 1, m, &cDelay_mCqZ7Px6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUYHMYSx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mCqZ7Px6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mCqZ7Px6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ScXTvSbz, 0, m, &cIf_ScXTvSbz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1bidUwmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mCqZ7Px6, 0, m, &cDelay_mCqZ7Px6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eUYHMYSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mCqZ7Px6, 0, m, &cDelay_mCqZ7Px6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pcd88VVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YwT44qec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C2jyoz20_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v4NIJpNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Br94lEDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ew4uDuCM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ew4uDuCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ShAoXTTt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Br94lEDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ScXTvSbz, 1, m, &cIf_ScXTvSbz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YwT44qec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BYmAcvvb, 1, m, &cIf_BYmAcvvb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C2jyoz20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BYmAcvvb, 0, m, &cIf_BYmAcvvb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RWNMFmcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YUh0TIV9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KEIv7PrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YUh0TIV9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_rRbskevg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_U0lhleCL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qHJOiPwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0ZL5wWVq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NMfw3q8z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ekxni2zX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ekxni2zX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_g8GFWPaO, 1, m, &cDelay_g8GFWPaO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WoHlFwj2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_g8GFWPaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_g8GFWPaO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rRbskevg, 0, m, &cIf_rRbskevg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ekxni2zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_g8GFWPaO, 0, m, &cDelay_g8GFWPaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WoHlFwj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_g8GFWPaO, 0, m, &cDelay_g8GFWPaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZvaDhuim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LkoVhJZt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_anI9LSDr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7CITi4sC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xrQbrYfM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3pnjHBQs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3pnjHBQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NMfw3q8z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xrQbrYfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rRbskevg, 1, m, &cIf_rRbskevg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_anI9LSDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qHJOiPwR, 0, m, &cIf_qHJOiPwR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LkoVhJZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qHJOiPwR, 1, m, &cIf_qHJOiPwR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0ZL5wWVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ckwoFKe3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_U0lhleCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ckwoFKe3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SjtMX6ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_30G72sVL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oClkpwD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fFRJNyxA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JDU8zNo6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rNrCrQ4I_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rNrCrQ4I_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_00oanLG3, 1, m, &cDelay_00oanLG3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n8XzNTUV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_00oanLG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_00oanLG3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SjtMX6ie, 0, m, &cIf_SjtMX6ie_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rNrCrQ4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_00oanLG3, 0, m, &cDelay_00oanLG3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n8XzNTUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_00oanLG3, 0, m, &cDelay_00oanLG3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_za9zRp41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2thWY6hA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1fYM5gjv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eI3IqXx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EO8jv1nW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SwR9SqqO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SwR9SqqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JDU8zNo6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EO8jv1nW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SjtMX6ie, 1, m, &cIf_SjtMX6ie_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1fYM5gjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oClkpwD9, 0, m, &cIf_oClkpwD9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2thWY6hA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oClkpwD9, 1, m, &cIf_oClkpwD9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fFRJNyxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F075KHvp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_30G72sVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F075KHvp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_IHWxZJby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iPEdICuR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HAclVkRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_owemGzEN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Cw1uybp6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_N0jF6MRu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_N0jF6MRu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MtOpQlNO, 1, m, &cDelay_MtOpQlNO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8OLA20lh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MtOpQlNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MtOpQlNO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_IHWxZJby, 0, m, &cIf_IHWxZJby_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N0jF6MRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MtOpQlNO, 0, m, &cDelay_MtOpQlNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8OLA20lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MtOpQlNO, 0, m, &cDelay_MtOpQlNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QG3dRtWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2rxlt1mz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LLRsfZGJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VSbOrYBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AvKRLrwA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Nrb9CS95_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Nrb9CS95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Cw1uybp6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AvKRLrwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IHWxZJby, 1, m, &cIf_IHWxZJby_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LLRsfZGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HAclVkRL, 0, m, &cIf_HAclVkRL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2rxlt1mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HAclVkRL, 1, m, &cIf_HAclVkRL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_owemGzEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_whaKzzsP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iPEdICuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_whaKzzsP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_QIbFhJIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Fkb8RwsJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zOsJyx2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g5UU9sjc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VHbFWnDx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jzoIRUP4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jzoIRUP4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EVaU9APB, 1, m, &cDelay_EVaU9APB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wx9GEPzt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EVaU9APB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EVaU9APB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QIbFhJIL, 0, m, &cIf_QIbFhJIL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jzoIRUP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EVaU9APB, 0, m, &cDelay_EVaU9APB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wx9GEPzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EVaU9APB, 0, m, &cDelay_EVaU9APB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ChCkOhgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S48JhB22_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UV1S54L4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E0KM5dCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dg4gkEfv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aNjIJmp5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aNjIJmp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VHbFWnDx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Dg4gkEfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QIbFhJIL, 1, m, &cIf_QIbFhJIL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UV1S54L4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zOsJyx2w, 0, m, &cIf_zOsJyx2w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S48JhB22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zOsJyx2w, 1, m, &cIf_zOsJyx2w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g5UU9sjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eIOJyGLt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Fkb8RwsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eIOJyGLt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bKhpf6Jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4POl7Vda_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SLszZyGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_J1lXzK1L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zlvJsDUW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OcShg6NU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OcShg6NU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vJmYmDye, 1, m, &cDelay_vJmYmDye_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ry4fMiAL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vJmYmDye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vJmYmDye, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bKhpf6Jx, 0, m, &cIf_bKhpf6Jx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OcShg6NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vJmYmDye, 0, m, &cDelay_vJmYmDye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ry4fMiAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vJmYmDye, 0, m, &cDelay_vJmYmDye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s0hpxFhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R4DXkErJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FiKBV2O8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oczvGn43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W9llYYcn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UuKQd4m0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W9llYYcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bKhpf6Jx, 1, m, &cIf_bKhpf6Jx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UuKQd4m0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zlvJsDUW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FiKBV2O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SLszZyGS, 0, m, &cIf_SLszZyGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R4DXkErJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SLszZyGS, 1, m, &cIf_SLszZyGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J1lXzK1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mja35mP2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4POl7Vda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mja35mP2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5mX2ArI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vv2P3kyR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CNyPVCiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fN0NhwrM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2O1G7MAG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EqwfjEv7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EqwfjEv7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ULo6QypW, 1, m, &cDelay_ULo6QypW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lbHOt282_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ULo6QypW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ULo6QypW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5mX2ArI5, 0, m, &cIf_5mX2ArI5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EqwfjEv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ULo6QypW, 0, m, &cDelay_ULo6QypW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lbHOt282_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ULo6QypW, 0, m, &cDelay_ULo6QypW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j3o24poH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q1cD715S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bFOIBJaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KqH8nY3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oH0GF4zx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aDstMoiE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aDstMoiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2O1G7MAG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oH0GF4zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5mX2ArI5, 1, m, &cIf_5mX2ArI5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bFOIBJaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CNyPVCiw, 0, m, &cIf_CNyPVCiw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q1cD715S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CNyPVCiw, 1, m, &cIf_CNyPVCiw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fN0NhwrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tg35ulWt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vv2P3kyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tg35ulWt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9fhgMrpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Bcnu52sC_sendMessage(_c, 0, m);
  cMsg_iXrlSHtN_sendMessage(_c, 0, m);
  cMsg_l6CU1Zhm_sendMessage(_c, 0, m);
  cMsg_l5wZbf41_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xGAgSe3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Bcnu52sC_sendMessage(_c, 0, m);
  cMsg_aMt76Sdq_sendMessage(_c, 0, m);
  cMsg_Ud0p9Biw_sendMessage(_c, 0, m);
  cMsg_1e2HJ3dS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WCJRpoW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_7JF3cAFQ_sendMessage(_c, 0, m);
  cMsg_aMt76Sdq_sendMessage(_c, 0, m);
  cMsg_l5wZbf41_sendMessage(_c, 0, m);
  cMsg_OdeRu2WI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_49RD4paF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_7JF3cAFQ_sendMessage(_c, 0, m);
  cMsg_XskRRtND_sendMessage(_c, 0, m);
  cMsg_l6CU1Zhm_sendMessage(_c, 0, m);
  cMsg_JOUNVdcM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_R8zYEQhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_Evlp5pkW_sendMessage(_c, 0, m);
  cMsg_1e2HJ3dS_sendMessage(_c, 0, m);
  cMsg_JzFVAnp6_sendMessage(_c, 0, m);
  cMsg_l6CU1Zhm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QgUqSF9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_Evlp5pkW_sendMessage(_c, 0, m);
  cMsg_JOUNVdcM_sendMessage(_c, 0, m);
  cMsg_aMt76Sdq_sendMessage(_c, 0, m);
  cMsg_Ik7MRZOw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lvrD32TX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fpaLkJTC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fICOOLLt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0Ol6OTn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fpaLkJTC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fICOOLLt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_izrkeGSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lJcKiaK7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9byfaQMP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jfbrIr2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lJcKiaK7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9byfaQMP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TxBjyhwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DTPhalqj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nGHW9KnP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_61wunCdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DTPhalqj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nGHW9KnP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Bcnu52sC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_lvrD32TX_sendMessage(_c, 0, m);
  cMsg_jfbrIr2a_sendMessage(_c, 0, m);
  cMsg_61wunCdx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7JF3cAFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_0Ol6OTn8_sendMessage(_c, 0, m);
  cMsg_izrkeGSd_sendMessage(_c, 0, m);
  cMsg_61wunCdx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Evlp5pkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_0Ol6OTn8_sendMessage(_c, 0, m);
  cMsg_jfbrIr2a_sendMessage(_c, 0, m);
  cMsg_TxBjyhwv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7gjqIHVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2xYHtdK1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aiwvQQn6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ykeED3Gy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2xYHtdK1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aiwvQQn6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HvzLuWr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mMnrOOZW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vH587KPX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FR1ZOioX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mMnrOOZW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vH587KPX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fbOQhta7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v4NIJpNz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pcd88VVB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uBf7WGXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v4NIJpNz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pcd88VVB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aMt76Sdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ykeED3Gy_sendMessage(_c, 0, m);
  cMsg_FR1ZOioX_sendMessage(_c, 0, m);
  cMsg_uBf7WGXl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iXrlSHtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ykeED3Gy_sendMessage(_c, 0, m);
  cMsg_HvzLuWr1_sendMessage(_c, 0, m);
  cMsg_fbOQhta7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XskRRtND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_7gjqIHVT_sendMessage(_c, 0, m);
  cMsg_FR1ZOioX_sendMessage(_c, 0, m);
  cMsg_fbOQhta7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zouAJYr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E0KM5dCz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ChCkOhgZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2ukd14V1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E0KM5dCz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ChCkOhgZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BTxTxkGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oczvGn43_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_s0hpxFhe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tVehkUhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oczvGn43_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_s0hpxFhe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SKIoZfOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KqH8nY3W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_j3o24poH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T6FyZbqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KqH8nY3W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_j3o24poH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JOUNVdcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_zouAJYr5_sendMessage(_c, 0, m);
  cMsg_tVehkUhg_sendMessage(_c, 0, m);
  cMsg_T6FyZbqR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1e2HJ3dS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_2ukd14V1_sendMessage(_c, 0, m);
  cMsg_BTxTxkGK_sendMessage(_c, 0, m);
  cMsg_T6FyZbqR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l5wZbf41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_2ukd14V1_sendMessage(_c, 0, m);
  cMsg_tVehkUhg_sendMessage(_c, 0, m);
  cMsg_SKIoZfOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PTNmExQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7CITi4sC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZvaDhuim_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OO23s03C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7CITi4sC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZvaDhuim_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KMi8S62g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eI3IqXx2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_za9zRp41_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZMg3WvqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eI3IqXx2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_za9zRp41_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6mRPQQxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VSbOrYBX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QG3dRtWt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4Yklhtvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VSbOrYBX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QG3dRtWt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l6CU1Zhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_OO23s03C_sendMessage(_c, 0, m);
  cMsg_ZMg3WvqK_sendMessage(_c, 0, m);
  cMsg_4Yklhtvo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ud0p9Biw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_OO23s03C_sendMessage(_c, 0, m);
  cMsg_KMi8S62g_sendMessage(_c, 0, m);
  cMsg_6mRPQQxC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ik7MRZOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_PTNmExQg_sendMessage(_c, 0, m);
  cMsg_KMi8S62g_sendMessage(_c, 0, m);
  cMsg_4Yklhtvo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JzFVAnp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_7gjqIHVT_sendMessage(_c, 0, m);
  cMsg_HvzLuWr1_sendMessage(_c, 0, m);
  cMsg_uBf7WGXl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OdeRu2WI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_PTNmExQg_sendMessage(_c, 0, m);
  cMsg_ZMg3WvqK_sendMessage(_c, 0, m);
  cMsg_6mRPQQxC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4QNhStaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w4cIkn6a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ToMNc0c6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k6UZEAXK, 0, m, &cSlice_k6UZEAXK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bnAK4CHD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_k6UZEAXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qESjgt2f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qESjgt2f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qzP4bGat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qESjgt2f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qESjgt2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_py99zrKG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_B1liBwBE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_W3a4LvNm, 0, m, &cSlice_W3a4LvNm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XKT8FQer_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_W3a4LvNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rqJHQ9lA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rqJHQ9lA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SmbGZjaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rqJHQ9lA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rqJHQ9lA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r93Y1Obq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XKT8FQer_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_y60BcfGn, 0, m, &cSlice_y60BcfGn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ToMNc0c6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_y60BcfGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MglmyLh5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MglmyLh5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_rGavTHPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MglmyLh5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_MglmyLh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DP6ysMyI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bnAK4CHD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Q1iICSch, 0, m, &cSlice_Q1iICSch_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4V52uS0O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Q1iICSch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Jzz8A0Fg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Jzz8A0Fg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QbWn36HT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Jzz8A0Fg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Jzz8A0Fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Pi2tDx37_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4V52uS0O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3zICmhCh, 0, m, &cSlice_3zICmhCh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GKPmlq2w_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3zICmhCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BCU4T5Qd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BCU4T5Qd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_cZYTJsya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BCU4T5Qd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BCU4T5Qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZLoTblXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Heb6Jo3H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cPpbdY9u_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cPpbdY9u_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_M54dt0d9, 1, m, &cDelay_M54dt0d9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zNMEa2uK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_M54dt0d9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M54dt0d9, m);
  cMsg_txeZUvmq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cPpbdY9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_M54dt0d9, 0, m, &cDelay_M54dt0d9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zNMEa2uK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M54dt0d9, 0, m, &cDelay_M54dt0d9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ItYIhR0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_buAeymWO, HV_BINOP_SUBTRACT, 0, m, &cBinop_buAeymWO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_hSNk0LfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_92yKvkHT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pxDcAnNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_92yKvkHT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_9A6aXtWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ItYIhR0T, 0, m, &cVar_ItYIhR0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_Gi9Jylt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TVFk85jI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vFwFP5DX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aoD8vbrp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_buAeymWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b2UhqtNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_b2UhqtNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9LAu8NIA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9LAu8NIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lBhwppsz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LXSRSQGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z9Fl7nHV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NStXuGcL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NStXuGcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lE3zmRM9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_z9Fl7nHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hSNk0LfA, 1, m, &cIf_hSNk0LfA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v8Kb6P9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pxDcAnNn, 1, m, &cIf_pxDcAnNn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lE3zmRM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_hSNk0LfA, 0, m, &cIf_hSNk0LfA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lBhwppsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pxDcAnNn, 0, m, &cIf_pxDcAnNn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TVFk85jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_aoD8vbrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ItYIhR0T, 0, m, &cVar_ItYIhR0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vFwFP5DX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_buAeymWO, HV_BINOP_SUBTRACT, 1, m, &cBinop_buAeymWO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_92yKvkHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IyJGTvYs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GKPmlq2w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UWhvCNY3, 0, m, &cSlice_UWhvCNY3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_UWhvCNY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jDZ6oEeN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jDZ6oEeN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_y9Ic8F9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jDZ6oEeN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jDZ6oEeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eDSCalQF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_caHADCVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5TUnRzVB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_O8CV7IDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LC5DhuoK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_pMqheLc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sut06sUw, 0, m, &cVar_sut06sUw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w4cIkn6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7Rxsi0U6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HMhizrQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JhMtIuex_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZQRuBX5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Heb6Jo3H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_txeZUvmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XQ7uR8i7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JhMtIuex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XQ7uR8i7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CjC6U1wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_05ePvSWt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_05ePvSWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9jF5qHyK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9jF5qHyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DZriARlK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_lLDvfCuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nC6cKJBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_xIVEoOiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cp4ZeDeq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aTXiFaYa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xwiY0liz_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vyhReULT_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tv5CNtui_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_14k3hkgf_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Feh1PbG8_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zAZXrQG5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_xwiY0liz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_huTPuwsK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_vyhReULT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3UdUtMBf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_tv5CNtui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sGq60oTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_14k3hkgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VwR0RPvp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Feh1PbG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cDVxBgBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zAZXrQG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r2yzMKj6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_EGs2MKJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BhGI5JIt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_meuowHOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i7BUi3h7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2vTcXpeI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jK8YYFhA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jK8YYFhA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Vl5Ozy5a, 1, m, &cDelay_Vl5Ozy5a_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zhoQKvL6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Vl5Ozy5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Vl5Ozy5a, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EGs2MKJq, 0, m, &cIf_EGs2MKJq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jK8YYFhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vl5Ozy5a, 0, m, &cDelay_Vl5Ozy5a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zhoQKvL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vl5Ozy5a, 0, m, &cDelay_Vl5Ozy5a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QuL3AZY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sZl8sf3s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jy1mcMUw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LJysMdeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GzpfnlGk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k0kELZEs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GzpfnlGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EGs2MKJq, 1, m, &cIf_EGs2MKJq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k0kELZEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2vTcXpeI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Jy1mcMUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_meuowHOx, 0, m, &cIf_meuowHOx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sZl8sf3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_meuowHOx, 1, m, &cIf_meuowHOx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i7BUi3h7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3hLgWrox, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BhGI5JIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3hLgWrox, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qHaMXADt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LUfi0su1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9Lva9RF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aiR93wIE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VNZzufEt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mEJQS5aH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mEJQS5aH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_axqqacJr, 1, m, &cDelay_axqqacJr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Ub660ws_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_axqqacJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_axqqacJr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qHaMXADt, 0, m, &cIf_qHaMXADt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mEJQS5aH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_axqqacJr, 0, m, &cDelay_axqqacJr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8Ub660ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_axqqacJr, 0, m, &cDelay_axqqacJr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KjPXVQDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ORckveRh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cu6k239W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VTdJgXFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hKOFUXQc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HOhEpkV7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hKOFUXQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qHaMXADt, 1, m, &cIf_qHaMXADt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HOhEpkV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VNZzufEt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ORckveRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Lva9RF7, 1, m, &cIf_9Lva9RF7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cu6k239W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Lva9RF7, 0, m, &cIf_9Lva9RF7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aiR93wIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pAzKTcwn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LUfi0su1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pAzKTcwn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_avY7XTwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QgR4vbY5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YTGazUGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jgWqErDc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tOfGeHu8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qri97VQJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qri97VQJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tXCFi4wl, 1, m, &cDelay_tXCFi4wl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6iOFkRiG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tXCFi4wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tXCFi4wl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_avY7XTwE, 0, m, &cIf_avY7XTwE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qri97VQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tXCFi4wl, 0, m, &cDelay_tXCFi4wl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6iOFkRiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tXCFi4wl, 0, m, &cDelay_tXCFi4wl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HZ9fXMNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CMWz7ZVq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EPoZenBv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s7rW2GMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3RZ92D6o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv9zcFFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wv9zcFFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tOfGeHu8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3RZ92D6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_avY7XTwE, 1, m, &cIf_avY7XTwE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EPoZenBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YTGazUGY, 0, m, &cIf_YTGazUGY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CMWz7ZVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YTGazUGY, 1, m, &cIf_YTGazUGY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jgWqErDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dJlozWy7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QgR4vbY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dJlozWy7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8WpWV7sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Kz1KocIq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zxOBxmfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NnDmVIOZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HGRGGRGh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zVyBljgO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zVyBljgO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_y7la9T5L, 1, m, &cDelay_y7la9T5L_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hDmceBWb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_y7la9T5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y7la9T5L, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8WpWV7sO, 0, m, &cIf_8WpWV7sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zVyBljgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_y7la9T5L, 0, m, &cDelay_y7la9T5L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hDmceBWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y7la9T5L, 0, m, &cDelay_y7la9T5L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qmls83nE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BQbdqMoF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FBqdh9KT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v1ShKxQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vCDiVefJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Sut7HkfC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sut7HkfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HGRGGRGh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vCDiVefJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8WpWV7sO, 1, m, &cIf_8WpWV7sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FBqdh9KT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zxOBxmfh, 0, m, &cIf_zxOBxmfh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BQbdqMoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zxOBxmfh, 1, m, &cIf_zxOBxmfh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NnDmVIOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WVfGqVX0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Kz1KocIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WVfGqVX0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fK9mnZWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_etMzMDuo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hRfI5Qzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kpovMbcn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GiE9hfYd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fh9WnPAx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fh9WnPAx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eFv70F2N, 1, m, &cDelay_eFv70F2N_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xIOKTJtA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_eFv70F2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eFv70F2N, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fK9mnZWb, 0, m, &cIf_fK9mnZWb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fh9WnPAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eFv70F2N, 0, m, &cDelay_eFv70F2N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xIOKTJtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eFv70F2N, 0, m, &cDelay_eFv70F2N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vi9wlG0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wh8LYK38_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WVhvidC6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nk9F4qd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zkQDjaNM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GIuQyxoq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zkQDjaNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fK9mnZWb, 1, m, &cIf_fK9mnZWb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GIuQyxoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GiE9hfYd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WVhvidC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hRfI5Qzs, 0, m, &cIf_hRfI5Qzs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wh8LYK38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hRfI5Qzs, 1, m, &cIf_hRfI5Qzs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kpovMbcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qi29mgPh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_etMzMDuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qi29mgPh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lG0MlHE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9jY000fd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_peUIsEBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zhUrnDQ3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_anvoCruf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MZvsrpnQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MZvsrpnQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EEx3mr23, 1, m, &cDelay_EEx3mr23_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FD7CjVdD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EEx3mr23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EEx3mr23, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lG0MlHE3, 0, m, &cIf_lG0MlHE3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MZvsrpnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EEx3mr23, 0, m, &cDelay_EEx3mr23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FD7CjVdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EEx3mr23, 0, m, &cDelay_EEx3mr23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qBppBWL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BLW3UYTU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rf2vmvGv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZUv3EUCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eKo7IMku_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sKvutStT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eKo7IMku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lG0MlHE3, 1, m, &cIf_lG0MlHE3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sKvutStT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_anvoCruf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BLW3UYTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_peUIsEBB, 1, m, &cIf_peUIsEBB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rf2vmvGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_peUIsEBB, 0, m, &cIf_peUIsEBB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zhUrnDQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ngbSHQhy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9jY000fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ngbSHQhy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4ejsRWQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dUHiuZFk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YC11MnOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ko2sIZEF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0a0hupXP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TOC12GXN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TOC12GXN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cbrGhbED, 1, m, &cDelay_cbrGhbED_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wVFRYdyR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cbrGhbED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cbrGhbED, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4ejsRWQT, 0, m, &cIf_4ejsRWQT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TOC12GXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cbrGhbED, 0, m, &cDelay_cbrGhbED_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wVFRYdyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cbrGhbED, 0, m, &cDelay_cbrGhbED_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mluPt9De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pQOD2xLT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_35Tqh9zy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oWcoy2rI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_si0MMXEq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EqeM2fDG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_si0MMXEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4ejsRWQT, 1, m, &cIf_4ejsRWQT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EqeM2fDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0a0hupXP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pQOD2xLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YC11MnOP, 1, m, &cIf_YC11MnOP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_35Tqh9zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YC11MnOP, 0, m, &cIf_YC11MnOP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ko2sIZEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_epeDfFTl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dUHiuZFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_epeDfFTl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_JZssd5F9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WpYrOvFw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tbRq2Yir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o6srExnK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TSPwiYow_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IoNXsH7B_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IoNXsH7B_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uCuUXqpg, 1, m, &cDelay_uCuUXqpg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RqrgpBDh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uCuUXqpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uCuUXqpg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JZssd5F9, 0, m, &cIf_JZssd5F9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IoNXsH7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uCuUXqpg, 0, m, &cDelay_uCuUXqpg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RqrgpBDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uCuUXqpg, 0, m, &cDelay_uCuUXqpg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9eLMA3eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XuJo3uJi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hv66xxKn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LAIX0HlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eCSNVGfO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hD9BAmPN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hD9BAmPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TSPwiYow_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_eCSNVGfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JZssd5F9, 1, m, &cIf_JZssd5F9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XuJo3uJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tbRq2Yir, 1, m, &cIf_tbRq2Yir_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hv66xxKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tbRq2Yir, 0, m, &cIf_tbRq2Yir_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o6srExnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oK3ouDb7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WpYrOvFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oK3ouDb7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uTJdpVMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I1Z1enK9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wh8w6HlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z7dwCTU9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OytFE74j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Q5sITkGX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Q5sITkGX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xu2wwxD5, 1, m, &cDelay_xu2wwxD5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5USR4aUb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xu2wwxD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xu2wwxD5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uTJdpVMb, 0, m, &cIf_uTJdpVMb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Q5sITkGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xu2wwxD5, 0, m, &cDelay_xu2wwxD5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5USR4aUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xu2wwxD5, 0, m, &cDelay_xu2wwxD5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Obz99F8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wbk9amnP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RlMIOCia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k4UyditW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rxzv1qMl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LOUY5cZW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LOUY5cZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OytFE74j_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rxzv1qMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uTJdpVMb, 1, m, &cIf_uTJdpVMb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RlMIOCia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wh8w6HlN, 0, m, &cIf_wh8w6HlN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wbk9amnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wh8w6HlN, 1, m, &cIf_wh8w6HlN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z7dwCTU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RpULlIeq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_I1Z1enK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RpULlIeq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RXHenqf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jsD5xXW5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wGEVmMbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5ZXDw1Cn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8JUJhm4t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WfN0wufk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WfN0wufk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1xFYJelr, 1, m, &cDelay_1xFYJelr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7xuNHwWh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1xFYJelr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1xFYJelr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RXHenqf9, 0, m, &cIf_RXHenqf9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WfN0wufk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1xFYJelr, 0, m, &cDelay_1xFYJelr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7xuNHwWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1xFYJelr, 0, m, &cDelay_1xFYJelr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YIwMGaoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VQGO1qJt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UjvfFaBP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q9wdFE7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_arSZL0i8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9WeqMhB9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_arSZL0i8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RXHenqf9, 1, m, &cIf_RXHenqf9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9WeqMhB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8JUJhm4t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VQGO1qJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wGEVmMbT, 1, m, &cIf_wGEVmMbT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UjvfFaBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wGEVmMbT, 0, m, &cIf_wGEVmMbT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5ZXDw1Cn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EFU1BRDz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jsD5xXW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EFU1BRDz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_k5gSxk7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9wRoD8QM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Tag13p41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8iAM51ko_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BLTnrHmB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MnPEp8eR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MnPEp8eR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cvUGMh7r, 1, m, &cDelay_cvUGMh7r_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n421ovqt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cvUGMh7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cvUGMh7r, m);
  cIf_onMessage(_c, &Context(_c)->cIf_k5gSxk7Z, 0, m, &cIf_k5gSxk7Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MnPEp8eR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cvUGMh7r, 0, m, &cDelay_cvUGMh7r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n421ovqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cvUGMh7r, 0, m, &cDelay_cvUGMh7r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6ykDFHH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HMg1N8Tv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3luWxX1w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XxSDwtJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rOxSO33J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Oq0Fs2by_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rOxSO33J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k5gSxk7Z, 1, m, &cIf_k5gSxk7Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Oq0Fs2by_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BLTnrHmB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HMg1N8Tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tag13p41, 1, m, &cIf_Tag13p41_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3luWxX1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tag13p41, 0, m, &cIf_Tag13p41_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8iAM51ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iZheSgqy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9wRoD8QM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iZheSgqy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_D8uYsz5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_atdZsuhQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lPdOPQPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vRHKGlhC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_E171Uaz5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ryPqNmw1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ryPqNmw1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SlBAmC8o, 1, m, &cDelay_SlBAmC8o_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5HYTEt8S_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SlBAmC8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SlBAmC8o, m);
  cIf_onMessage(_c, &Context(_c)->cIf_D8uYsz5R, 0, m, &cIf_D8uYsz5R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ryPqNmw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SlBAmC8o, 0, m, &cDelay_SlBAmC8o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5HYTEt8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SlBAmC8o, 0, m, &cDelay_SlBAmC8o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3kW5Wt7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x3P92ly0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oFJlaaEY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g11zdalN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zijYD50A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fbJbNyzH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fbJbNyzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_E171Uaz5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zijYD50A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D8uYsz5R, 1, m, &cIf_D8uYsz5R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x3P92ly0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lPdOPQPO, 1, m, &cIf_lPdOPQPO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oFJlaaEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lPdOPQPO, 0, m, &cIf_lPdOPQPO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vRHKGlhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WiClOoou, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_atdZsuhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WiClOoou, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_huTPuwsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_aa93IvLk_sendMessage(_c, 0, m);
  cMsg_LY51GUDe_sendMessage(_c, 0, m);
  cMsg_0NuR1FeQ_sendMessage(_c, 0, m);
  cMsg_qg0URivI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3UdUtMBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_aa93IvLk_sendMessage(_c, 0, m);
  cMsg_UL9Bjtjw_sendMessage(_c, 0, m);
  cMsg_lgHxsmgR_sendMessage(_c, 0, m);
  cMsg_2Ft4VfCA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sGq60oTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_LriNI4Ch_sendMessage(_c, 0, m);
  cMsg_UL9Bjtjw_sendMessage(_c, 0, m);
  cMsg_qg0URivI_sendMessage(_c, 0, m);
  cMsg_VWoMNkwi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VwR0RPvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_LriNI4Ch_sendMessage(_c, 0, m);
  cMsg_OTiwm8Kc_sendMessage(_c, 0, m);
  cMsg_0NuR1FeQ_sendMessage(_c, 0, m);
  cMsg_yjKHBOMG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cDVxBgBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_7EBYqcKt_sendMessage(_c, 0, m);
  cMsg_2Ft4VfCA_sendMessage(_c, 0, m);
  cMsg_AbL7U6U5_sendMessage(_c, 0, m);
  cMsg_0NuR1FeQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_r2yzMKj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_7EBYqcKt_sendMessage(_c, 0, m);
  cMsg_yjKHBOMG_sendMessage(_c, 0, m);
  cMsg_UL9Bjtjw_sendMessage(_c, 0, m);
  cMsg_lCvKlnnN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VO1q0ZTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LJysMdeg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QuL3AZY3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EqYD8TQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LJysMdeg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QuL3AZY3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4Fzis8tI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VTdJgXFv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KjPXVQDc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y7diHnB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VTdJgXFv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KjPXVQDc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZxGHouA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s7rW2GMw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HZ9fXMNy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RzyGWUgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s7rW2GMw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HZ9fXMNy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aa93IvLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_VO1q0ZTR_sendMessage(_c, 0, m);
  cMsg_Y7diHnB8_sendMessage(_c, 0, m);
  cMsg_RzyGWUgq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LriNI4Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_EqYD8TQm_sendMessage(_c, 0, m);
  cMsg_4Fzis8tI_sendMessage(_c, 0, m);
  cMsg_RzyGWUgq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7EBYqcKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_EqYD8TQm_sendMessage(_c, 0, m);
  cMsg_Y7diHnB8_sendMessage(_c, 0, m);
  cMsg_ZxGHouA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FqhnAppm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v1ShKxQr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Qmls83nE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8EUk96mQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v1ShKxQr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Qmls83nE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QxVrWS9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nk9F4qd5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vi9wlG0Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DUj9x9C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nk9F4qd5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vi9wlG0Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vlqP0gaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZUv3EUCx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qBppBWL8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U8vLNpX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZUv3EUCx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qBppBWL8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UL9Bjtjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_8EUk96mQ_sendMessage(_c, 0, m);
  cMsg_DUj9x9C4_sendMessage(_c, 0, m);
  cMsg_U8vLNpX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LY51GUDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_8EUk96mQ_sendMessage(_c, 0, m);
  cMsg_QxVrWS9M_sendMessage(_c, 0, m);
  cMsg_vlqP0gaA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OTiwm8Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_FqhnAppm_sendMessage(_c, 0, m);
  cMsg_DUj9x9C4_sendMessage(_c, 0, m);
  cMsg_vlqP0gaA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oOK1Ct9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_q9wdFE7C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YIwMGaoF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4dyKpHyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_q9wdFE7C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YIwMGaoF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ymqbsxDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XxSDwtJ5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6ykDFHH2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WRM8hlrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XxSDwtJ5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6ykDFHH2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wh1xYjtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g11zdalN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3kW5Wt7u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U8ZsPL5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g11zdalN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3kW5Wt7u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yjKHBOMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_oOK1Ct9o_sendMessage(_c, 0, m);
  cMsg_WRM8hlrp_sendMessage(_c, 0, m);
  cMsg_U8ZsPL5v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2Ft4VfCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_4dyKpHyu_sendMessage(_c, 0, m);
  cMsg_ymqbsxDu_sendMessage(_c, 0, m);
  cMsg_U8ZsPL5v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qg0URivI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_4dyKpHyu_sendMessage(_c, 0, m);
  cMsg_WRM8hlrp_sendMessage(_c, 0, m);
  cMsg_Wh1xYjtx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CQ2IX9xI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oWcoy2rI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mluPt9De_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VzJZJokn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oWcoy2rI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mluPt9De_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tiWB98eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LAIX0HlM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9eLMA3eF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WxE5QBZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LAIX0HlM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9eLMA3eF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nSbiSkVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k4UyditW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Obz99F8S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VokqJJTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k4UyditW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Obz99F8S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0NuR1FeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_VzJZJokn_sendMessage(_c, 0, m);
  cMsg_WxE5QBZW_sendMessage(_c, 0, m);
  cMsg_VokqJJTD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lgHxsmgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_VzJZJokn_sendMessage(_c, 0, m);
  cMsg_tiWB98eg_sendMessage(_c, 0, m);
  cMsg_nSbiSkVd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lCvKlnnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_CQ2IX9xI_sendMessage(_c, 0, m);
  cMsg_tiWB98eg_sendMessage(_c, 0, m);
  cMsg_VokqJJTD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AbL7U6U5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_FqhnAppm_sendMessage(_c, 0, m);
  cMsg_QxVrWS9M_sendMessage(_c, 0, m);
  cMsg_U8vLNpX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VWoMNkwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_CQ2IX9xI_sendMessage(_c, 0, m);
  cMsg_WxE5QBZW_sendMessage(_c, 0, m);
  cMsg_nSbiSkVd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_No85xWgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2vtJVbSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1E0huSMw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Te2wSBeM, 0, m, &cSlice_Te2wSBeM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0wNxrUrQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Te2wSBeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dWPcX5cm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dWPcX5cm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_8NjuvYf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dWPcX5cm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dWPcX5cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FLUFw3c6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_a1K0ZCQW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Bf6pzDH6, 0, m, &cSlice_Bf6pzDH6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_D4wf57qN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Bf6pzDH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WFPMimRT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WFPMimRT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_RLLfYlu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WFPMimRT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WFPMimRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YrkN7vI2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_D4wf57qN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RcwEkOXm, 0, m, &cSlice_RcwEkOXm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1E0huSMw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_RcwEkOXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EPbfxwXV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EPbfxwXV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_p5Z3NStQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EPbfxwXV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EPbfxwXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HyhH1HIW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0wNxrUrQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UVfnKGIx, 0, m, &cSlice_UVfnKGIx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dZQPvdi5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_UVfnKGIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iVfGD8pq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iVfGD8pq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GDN57tMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iVfGD8pq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iVfGD8pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cdQR7lvR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dZQPvdi5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_d5o7Jbri, 0, m, &cSlice_d5o7Jbri_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uxfi05W4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_d5o7Jbri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n7791I63_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n7791I63_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sSWWn5wD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n7791I63_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_n7791I63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VBoL81hq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4dnQiAxc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mzqmnyZs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mzqmnyZs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Im76m92h, 1, m, &cDelay_Im76m92h_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SQEkEI5F_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Im76m92h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Im76m92h, m);
  cMsg_NSq0nW8O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mzqmnyZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Im76m92h, 0, m, &cDelay_Im76m92h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SQEkEI5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Im76m92h, 0, m, &cDelay_Im76m92h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Z9MgKsEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S6TSI3t9, HV_BINOP_SUBTRACT, 0, m, &cBinop_S6TSI3t9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_yPH8owPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ykXVoiuY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FfRro8ZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ykXVoiuY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_sPKu9mgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z9MgKsEk, 0, m, &cVar_Z9MgKsEk_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ubATTlpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jpl3ghsp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IYMOAIGs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s5XmV5wU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S6TSI3t9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cFnRQScN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cFnRQScN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fFMFfC8u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fFMFfC8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_o9ulty2p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oFyKzNNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_meFr6SvQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xTMMhigH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xTMMhigH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VwPp9Zv9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_meFr6SvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yPH8owPy, 1, m, &cIf_yPH8owPy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fJcYrupN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FfRro8ZL, 1, m, &cIf_FfRro8ZL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VwPp9Zv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_yPH8owPy, 0, m, &cIf_yPH8owPy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_o9ulty2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FfRro8ZL, 0, m, &cIf_FfRro8ZL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IYMOAIGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S6TSI3t9, HV_BINOP_SUBTRACT, 1, m, &cBinop_S6TSI3t9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jpl3ghsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_s5XmV5wU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z9MgKsEk, 0, m, &cVar_Z9MgKsEk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ykXVoiuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ooHmc5n6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uxfi05W4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x0lApO6w, 0, m, &cSlice_x0lApO6w_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_x0lApO6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FkQWzlnu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FkQWzlnu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_X1Gb7C1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FkQWzlnu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FkQWzlnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CSHBHJHF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nC6cKJBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JCRjLcqj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cp4ZeDeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_95mY20Hw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_DRGPYFb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xIVEoOiY, 0, m, &cVar_xIVEoOiY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2vtJVbSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TJ9q0kzw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CxthIuE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4dnQiAxc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qecBNMyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hgLpeunw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NSq0nW8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fYxkiR48, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hgLpeunw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fYxkiR48, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ErhDibAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_RLwOUiMY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RLwOUiMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aTjRmjkp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aTjRmjkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9I1zi2Zk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_FlBWNvIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2KYdQfiB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_EpyIgzyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F8lbPu7a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_E5FbYGVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5jgjDWNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZJ2NWrJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RSnYxweB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zekA9TM9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dIb9pIA2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HgYiiCKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RSnYxweB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zekA9TM9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dIb9pIA2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_z4GOtasK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uJsLa4rX, 0, m, &cVar_uJsLa4rX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wWERAUO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RSnYxweB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zekA9TM9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dIb9pIA2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RVlJJgdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RSnYxweB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zekA9TM9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dIb9pIA2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0N0kTBUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RSnYxweB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zekA9TM9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dIb9pIA2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_glx1Jg8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_zpOI3hT6, 0, m, &cVar_zpOI3hT6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pB5ajQEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_2gcvKABU, 0, m, &cVar_2gcvKABU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Xyw8bzAI, 0, m, &cVar_Xyw8bzAI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4GSgR6Hj, 0, m, &cVar_4GSgR6Hj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vsnTlIAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_z4GOtasK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xAnnlaSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sZ1HaNjI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_nrrTwxDm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hwgIqjna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sZ1HaNjI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_nrrTwxDm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yx6W0TJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sZ1HaNjI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_nrrTwxDm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nQo5fOFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sZ1HaNjI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_nrrTwxDm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ar1qedyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sZ1HaNjI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_nrrTwxDm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fFr8LMai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_41T1P0MT, 0, m, &cVar_41T1P0MT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VPmfXUvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Hjjj7Gkl, 0, m, &cVar_Hjjj7Gkl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dOisNT3F, 0, m, &cVar_dOisNT3F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cSv0eSaA, 0, m, &cVar_cSv0eSaA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iu1uKzNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RSnYxweB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zekA9TM9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dIb9pIA2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xAIlip3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_upwEHxJA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_kHq3bTF6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CqikwZhI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3GjE7LFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_upwEHxJA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_kHq3bTF6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CqikwZhI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_S5BSaOdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zuv3wBvS, 0, m, &cVar_Zuv3wBvS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fROsmkKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_upwEHxJA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_kHq3bTF6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CqikwZhI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_infEbLxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_upwEHxJA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_kHq3bTF6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CqikwZhI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rKqJtGxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_upwEHxJA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_kHq3bTF6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CqikwZhI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7MzetPbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_5k49lYlX, 0, m, &cVar_5k49lYlX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h7lvqwSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_An4hjZTa, 0, m, &cVar_An4hjZTa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cvRZM7dw, 0, m, &cVar_cvRZM7dw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Iiby1YWS, 0, m, &cVar_Iiby1YWS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HvgVnbIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_S5BSaOdI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_znDCxoPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_upwEHxJA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_kHq3bTF6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CqikwZhI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_12MgreLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_dnLmhn9q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_B1liBwBE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_a1K0ZCQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ulCERoUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_dnLmhn9q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_B1liBwBE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_a1K0ZCQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_nqTK9dPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z5WewmxS, 0, m, &cVar_Z5WewmxS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mME9hJOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_dnLmhn9q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_B1liBwBE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_a1K0ZCQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uGSgmtQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_dnLmhn9q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_B1liBwBE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_a1K0ZCQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_40mZowvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_dnLmhn9q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_B1liBwBE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_a1K0ZCQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GiAPxvLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ELsEM9M6, 0, m, &cVar_ELsEM9M6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jx1KgI5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_znjcRjVy, 0, m, &cVar_znjcRjVy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_smfHHkgW, 0, m, &cVar_smfHHkgW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JLdQCMJJ, 0, m, &cVar_JLdQCMJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dFGYJZ6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nqTK9dPn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xBVUC3T3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_dnLmhn9q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_B1liBwBE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_a1K0ZCQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zoNRNyRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_FlBWNvIG, 0, m, &cVar_FlBWNvIG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2KYdQfiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RSnYxweB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zekA9TM9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dIb9pIA2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GKAeHh0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_EpyIgzyu, 0, m, &cVar_EpyIgzyu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_F8lbPu7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_upwEHxJA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_kHq3bTF6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CqikwZhI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4dPAS59t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_E5FbYGVI, 0, m, &cVar_E5FbYGVI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5jgjDWNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_dnLmhn9q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_B1liBwBE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_a1K0ZCQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_NMWnsYai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WIr7Pm0e_sendMessage(_c, 0, m);
  cMsg_EH55aeaU_sendMessage(_c, 0, m);
  cMsg_kHLtLbiI_sendMessage(_c, 0, m);
  cMsg_GTMinQd1_sendMessage(_c, 0, m);
  cMsg_gqp2iEQT_sendMessage(_c, 0, m);
  cMsg_5VFuYQhF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rSaP5Oj9, 0, m, &cVar_rSaP5Oj9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_afI0yXk5, 0, m, &cVar_afI0yXk5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JC1bABvF, 0, m, &cVar_JC1bABvF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nXuPzEvr, 0, m, &cVar_nXuPzEvr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kUZAMChw, 0, m, &cVar_kUZAMChw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uC3qg3Ta, 0, m, &cVar_uC3qg3Ta_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vXswbp7G, 0, m, &cVar_vXswbp7G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s0DtSXmq, 0, m, &cVar_s0DtSXmq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6BbbTg2Q, 0, m, &cVar_6BbbTg2Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S4P4lcf7, 0, m, &cVar_S4P4lcf7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MjOS9zGe, 0, m, &cVar_MjOS9zGe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7PJXTgPc, 0, m, &cVar_7PJXTgPc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jX0ERHxB, 0, m, &cVar_jX0ERHxB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yOAtbf1e, 0, m, &cVar_yOAtbf1e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FvyrLmTE, 0, m, &cVar_FvyrLmTE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gzQ2LRNY, 0, m, &cVar_gzQ2LRNY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_flLMe8XE, 0, m, &cVar_flLMe8XE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wjupj4pL, 0, m, &cVar_Wjupj4pL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YDP0k7AN, 0, m, &cVar_YDP0k7AN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4CeHcXc0, 0, m, &cVar_4CeHcXc0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6b0EHiqE, 0, m, &cVar_6b0EHiqE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_t1AnaW3Q, 0, m, &cVar_t1AnaW3Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s1PGAgDC, 0, m, &cVar_s1PGAgDC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F4e1gTeM, 0, m, &cVar_F4e1gTeM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oPv3OGDS, 0, m, &cVar_oPv3OGDS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Lor68x1Q, 0, m, &cVar_Lor68x1Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fjwMo5Md, 0, m, &cVar_fjwMo5Md_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jw7t1KrR, 0, m, &cVar_Jw7t1KrR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iBNn5ckW, 0, m, &cVar_iBNn5ckW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NwxnDSmH, 0, m, &cVar_NwxnDSmH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_g8tNmKsh, 0, m, &cVar_g8tNmKsh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9UOxWWwP, 0, m, &cVar_9UOxWWwP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yaeEgAZP, 0, m, &cVar_yaeEgAZP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_A2sS1xOo, 0, m, &cVar_A2sS1xOo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o3BxUaNk, 0, m, &cVar_o3BxUaNk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sUtl7CNh, 0, m, &cVar_sUtl7CNh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Dh8Guek0, 0, m, &cVar_Dh8Guek0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LoqW4EPY, 0, m, &cVar_LoqW4EPY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i9hEyMSL, 0, m, &cVar_i9hEyMSL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PetLlyWF, 0, m, &cVar_PetLlyWF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PDdGidzx, 0, m, &cVar_PDdGidzx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MZZHCzlw, 0, m, &cVar_MZZHCzlw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cS3lFCWw, 0, m, &cVar_cS3lFCWw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X11oOzSZ, 0, m, &cVar_X11oOzSZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GM85VBZq, 0, m, &cVar_GM85VBZq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Qt2vkRgU, 0, m, &cVar_Qt2vkRgU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qzP4bGat, 0, m, &cVar_qzP4bGat_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SmbGZjaf, 0, m, &cVar_SmbGZjaf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rGavTHPC, 0, m, &cVar_rGavTHPC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QbWn36HT, 0, m, &cVar_QbWn36HT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cZYTJsya, 0, m, &cVar_cZYTJsya_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y9Ic8F9C, 0, m, &cVar_y9Ic8F9C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8NjuvYf4, 0, m, &cVar_8NjuvYf4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RLLfYlu2, 0, m, &cVar_RLLfYlu2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_p5Z3NStQ, 0, m, &cVar_p5Z3NStQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GDN57tMl, 0, m, &cVar_GDN57tMl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sSWWn5wD, 0, m, &cVar_sSWWn5wD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X1Gb7C1p, 0, m, &cVar_X1Gb7C1p_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W8z6vecT, 0, m, &cVar_W8z6vecT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lPSpx9PB, 0, m, &cVar_lPSpx9PB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1B2dBury, 0, m, &cVar_1B2dBury_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAbeLRlT_sendMessage);
  cMsg_VPmfXUvT_sendMessage(_c, 0, m);
  cMsg_fFr8LMai_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fxdlksZB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SBRqU2So_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XCMcSpJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hjjj7Gkl, 0, m, &cVar_Hjjj7Gkl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WUjbZFH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dOisNT3F, 0, m, &cVar_dOisNT3F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UvAqxm2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cSv0eSaA, 0, m, &cVar_cSv0eSaA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_r7idC7W3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_afI0yXk5, 0, m, &cVar_afI0yXk5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_USYw6nPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mJ4mo5rW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bImcDVmm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HVeCv9on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jzfWMajD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wphm7wiV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LAlPKkvY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wGvCHE2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_egtGvsJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DfcBn9bL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I3zjcxW6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UZwHvfx7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8AknOgni_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_naTGkfxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M4bWbYui_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SMU23zjT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_adtN093M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gcYmiYqF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_iAOxQtby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5m5Wgqrz, HV_BINOP_MULTIPLY, 0, m, &cBinop_5m5Wgqrz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kW1nJCHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1DPSkuRM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_z61vLivR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_F4nrdSte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_NfhtF3Wt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UPIxNqHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5ETRQ4TR_sendMessage);
  cMsg_W6kBMTFG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_IBnKJRJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VmQgOBYF, HV_BINOP_MULTIPLY, 0, m, &cBinop_VmQgOBYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jzQpgH5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_91GDms9t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Sl1p4AoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HC1SlKxu, HV_BINOP_MULTIPLY, 1, m, &cBinop_HC1SlKxu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XzrSoyis_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_12OsfzPI_sendMessage);
  cMsg_KNo1ZS7a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_gybXrlge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uUKtEod4, HV_BINOP_MULTIPLY, 0, m, &cBinop_uUKtEod4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YZGVBl4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R0zFAA39_sendMessage(_c, 0, m);
  cMsg_YcxKIVrg_sendMessage(_c, 0, m);
  cMsg_BGrvaOXI_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_hqy14bjN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cjGoT0BC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ob25paRh_sendMessage);
  cMsg_kUYsYsWw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ie4CVbv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kUZAMChw, 0, m, &cVar_kUZAMChw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kotBGMIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IhJ2ks5t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Yzq59jl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Lg9ipFnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pUFbIULZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lo9Bb9Tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TxUrvScu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P8YTOPUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Vwq33LNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CEwuWPlr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_myyka4Po_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QHTUrtHe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x9IJpIHU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qqXR0VGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ih92ZzFQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NfLCrbMG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OEe6sRg3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xuYHjr9l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sSvvou17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_msvO6W7U, HV_BINOP_MULTIPLY, 0, m, &cBinop_msvO6W7U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hWD0BHml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Q5Z0gaBB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_07cqoUXX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_U3vlsy8R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_UMllHzAX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_j7BlqcpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WuPSkxsI_sendMessage);
  cMsg_eKkcgSTS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_wBWL47rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qXgioyOo, HV_BINOP_MULTIPLY, 0, m, &cBinop_qXgioyOo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_F7ctwigV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zLtEb26R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fpJAUlu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3LEAu5Bb, HV_BINOP_MULTIPLY, 1, m, &cBinop_3LEAu5Bb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NYUQN9q8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GYllp0k0_sendMessage);
  cMsg_6IashbXq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_2p5VN6LX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ljHLgF4F, HV_BINOP_MULTIPLY, 0, m, &cBinop_ljHLgF4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Dp2LASle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PBZ7YbGJ_sendMessage(_c, 0, m);
  cMsg_ADTSvlwp_sendMessage(_c, 0, m);
  cMsg_JuyZJ97A_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_6b5e1k4h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ph6SEXjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MOj0SuUh_sendMessage);
  cMsg_bvrdrAhU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_RQOWEQSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_41T1P0MT, 0, m, &cVar_41T1P0MT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HWsD1rhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SkuXN42G, 0, m, &cVar_SkuXN42G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HOTMUMc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zpOI3hT6, 0, m, &cVar_zpOI3hT6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_heY7iPyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2gcvKABU, 0, m, &cVar_2gcvKABU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HBbC0R7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Xyw8bzAI, 0, m, &cVar_Xyw8bzAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8KbvQSEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4GSgR6Hj, 0, m, &cVar_4GSgR6Hj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SPSVsmUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_z4GOtasK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_clL3NmGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ajKf7QPI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_29iqfHLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_faZ6EUdk, 0, m, &cVar_faZ6EUdk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LDbKEa4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6ARbiM1H, 0, m, &cVar_6ARbiM1H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VpOocFHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_zVkkpgjM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VtWR25EE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LPbe5xJI_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1CTeJvCB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tIPfoWkh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dxezpwfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bHrR681U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PE0L7dTw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bsQ6wNtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kn4AyRBL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_jlP8cUPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UO5nSCrF, 0, m, &cVar_UO5nSCrF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yvG6sply_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O1R7IVBh, 0, m, &cVar_O1R7IVBh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Gt3Vq36Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_8RoJ6gK1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Ayjhjz9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3HmpxPaB_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ThkIMau9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AgVB9aut_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JrZy6zSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xrdoXAvM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mcs10iMb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_w1RKZsje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v6O0kzMp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_AEbFepGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cYqYOam2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fjK0FJpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rOfM6v9x, 0, m, &cVar_rOfM6v9x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Jk0rvQSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R4aWj4R5, 0, m, &cVar_R4aWj4R5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ytQL2yiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_53rcL26L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RNn1EDOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rRlhatrq_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F7WuBoqc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_THfT65mX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_U3MInDzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dysl43NA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IyhUov3J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KoCGRNzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QraX17SH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_HjibjBdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DcVn2d5N, 0, m, &cVar_DcVn2d5N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cSklG3t5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bLkseGDH, 0, m, &cVar_bLkseGDH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_wB8kp16t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_W5UCY4aJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UfK0arfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RWu0Cxat_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1A71QyG3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s6iDBTfR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1V5Urq4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gcpatnRy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_defB8Lot_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nZmUCc3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xZ4ICRDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_epzOUEev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_umAP1ILs, 0, m, &cVar_umAP1ILs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pUMO7fQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5k49lYlX, 0, m, &cVar_5k49lYlX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_b0WYLfNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_An4hjZTa, 0, m, &cVar_An4hjZTa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1iCP1ZEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cvRZM7dw, 0, m, &cVar_cvRZM7dw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4LSgttPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iiby1YWS, 0, m, &cVar_Iiby1YWS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_POzJSvAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_S5BSaOdI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HMIW50Tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0hw18niq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_py99zrKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w8gIL8FX, 0, m, &cVar_w8gIL8FX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Pi2tDx37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4QNhStaO, 0, m, &cVar_4QNhStaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DP6ysMyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_pMqheLc9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_r93Y1Obq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YBrxEYFv_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HMhizrQB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZQRuBX5J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZLoTblXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LXSRSQGJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v8Kb6P9J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eDSCalQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CjC6U1wi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_FLUFw3c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lLDvfCuW, 0, m, &cVar_lLDvfCuW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cdQR7lvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_No85xWgj, 0, m, &cVar_No85xWgj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HyhH1HIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_DRGPYFb5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YrkN7vI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aTXiFaYa_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qecBNMyE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CxthIuE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VBoL81hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oFyKzNNC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fJcYrupN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CSHBHJHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ErhDibAF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_6Ftahr6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EGC51EDO, 0, m, &cVar_EGC51EDO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yC9OirOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ELsEM9M6, 0, m, &cVar_ELsEM9M6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Wxqj7Ii7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_znjcRjVy, 0, m, &cVar_znjcRjVy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VOQxzy0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_smfHHkgW, 0, m, &cVar_smfHHkgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_h5X2g9Uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JLdQCMJJ, 0, m, &cVar_JLdQCMJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_v8BPPn2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nqTK9dPn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hvTGP8C6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FlBWNvIG, 0, m, &cVar_FlBWNvIG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gGlGXYVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EpyIgzyu, 0, m, &cVar_EpyIgzyu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SBO1dMRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E5FbYGVI, 0, m, &cVar_E5FbYGVI_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_sej1KvDv, VOf(Bf0));
    __hv_line_f(&sLine_dZ7n3rfQ, VOf(Bf1));
    __hv_line_f(&sLine_gl52Z6OQ, VOf(Bf2));
    __hv_line_f(&sLine_53bw1hnb, VOf(Bf3));
    __hv_line_f(&sLine_lpjwtbeN, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_ikrhn9Ym, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_4r4wX7nS, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_3LTEDo4O, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_lfN5ZIzu, VOf(Bf1));
    __hv_line_f(&sLine_ZZqkUpdO, VOf(Bf0));
    __hv_line_f(&sLine_sGntX5nh, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_qoYTJRhm, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Lntt1gKQ, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_3QAlvVxT, VOf(Bf5));
    __hv_line_f(&sLine_RtHfbkXF, VOf(Bf1));
    __hv_line_f(&sLine_Pr9RHTzh, VOf(Bf2));
    __hv_line_f(&sLine_npUChMq9, VOf(Bf4));
    __hv_line_f(&sLine_2vnoandb, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_ngWZE9jG, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_afMLwezW, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_9FRuhRsR, VOf(Bf6));
    __hv_line_f(&sLine_raqXavFV, VOf(Bf2));
    __hv_line_f(&sLine_7quaHcdV, VOf(Bf1));
    __hv_line_f(&sLine_M4rcebnw, VOf(Bf5));
    __hv_line_f(&sLine_zkgrVsG6, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_2s4LClbv, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_6vVca9Cr, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_dRwmqQef, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_26wwKcyL, VOf(Bf2));
    __hv_line_f(&sLine_qaz4s4xL, VOf(Bf6));
    __hv_line_f(&sLine_TjraN0UB, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_HwIjPgBM, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_REElEn5X, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_eUesPIQn, VOf(Bf8));
    __hv_line_f(&sLine_CqyyEhpi, VOf(Bf2));
    __hv_line_f(&sLine_O0zgOsnr, VOf(Bf1));
    __hv_line_f(&sLine_X0cqLvoj, VOf(Bf7));
    __hv_line_f(&sLine_qNVqZ0xs, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_b5bzU8L6, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_uQ15MQKN, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_8WjuLJOs, VIf(Bf0));
    __hv_varwrite_f(&sVarf_6WxNejch, VIf(Bf6));
    __hv_varwrite_f(&sVarf_b8rowDHu, VIf(Bf4));
    __hv_varwrite_f(&sVarf_UXMKkb6N, VIf(Bf7));
    __hv_varread_f(&sVarf_EmFOTdUR, VOf(Bf7));
    __hv_varread_f(&sVarf_53dYSyA0, VOf(Bf4));
    __hv_varread_f(&sVarf_ZZl5dmbC, VOf(Bf6));
    __hv_varread_f(&sVarf_WSjIvhTN, VOf(Bf0));
    __hv_varread_f(&sVarf_X844x2ZN, VOf(Bf9));
    __hv_varread_f(&sVarf_DG1clAzq, VOf(Bf1));
    __hv_line_f(&sLine_mz8VXjYh, VOf(Bf2));
    __hv_line_f(&sLine_nNObmQnJ, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_ZZl5dmbC, VIf(Bf7));
    __hv_varwrite_f(&sVarf_X844x2ZN, VIf(Bf4));
    __hv_varread_f(&sVarf_ExdiaC29, VOf(Bf2));
    __hv_varread_f(&sVarf_dx4aErxA, VOf(Bf9));
    __hv_varread_f(&sVarf_2CkmCKc6, VOf(Bf1));
    __hv_varread_f(&sVarf_XvX0DP4T, VOf(Bf6));
    __hv_varread_f(&sVarf_XknWIf2A, VOf(Bf10));
    __hv_varread_f(&sVarf_y57SgT2f, VOf(Bf11));
    __hv_varread_f(&sVarf_8JCjcEg0, VOf(Bf12));
    __hv_varwrite_f(&sVarf_OeThDu7x, VIf(Bf7));
    __hv_varread_f(&sVarf_LOndclkB, VOf(Bf13));
    __hv_line_f(&sLine_WoERXYiG, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_95TtqOFu, VOf(Bf15));
    __hv_line_f(&sLine_V8kzE1T5, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_IMBMYOIg, VOf(Bf14));
    __hv_line_f(&sLine_2HZSDI7Z, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_XvX0DP4T, VIf(Bf17));
    __hv_varread_f(&sVarf_OeThDu7x, VOf(Bf17));
    __hv_line_f(&sLine_EatOt60Z, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_ya7UUR3T, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_QMwfSRga, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_XknWIf2A, VIf(Bf16));
    __hv_line_f(&sLine_QWeQvLzO, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_dPcUEwbX, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_j9UaZDEl, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_y57SgT2f, VIf(Bf16));
    __hv_line_f(&sLine_4r1gdoJt, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_DCvegYgG, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_8EvkVbqL, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_8JCjcEg0, VIf(Bf16));
    __hv_varwrite_f(&sVarf_LOndclkB, VIf(Bf2));
    __hv_varwrite_f(&sVarf_95TtqOFu, VIf(Bf9));
    __hv_varwrite_f(&sVarf_IMBMYOIg, VIf(Bf1));
    sEnv_process(this, &sEnv_8OdsCRrA, VIf(Bf6), &sEnv_8OdsCRrA_sendMessage);
    sEnv_process(this, &sEnv_oxk4RKer, VIf(Bf7), &sEnv_oxk4RKer_sendMessage);
    __hv_line_f(&sLine_pJQ56YO0, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_HK2gFNh1, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_m8B9emDa, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_OZM9WAwd, VOf(Bf6));
    __hv_line_f(&sLine_XyeDdSp8, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_ExdiaC29, VIf(Bf9));
    __hv_varwrite_f(&sVarf_OZM9WAwd, VIf(Bf10));
    __hv_varwrite_f(&sVarf_hVBRXm4G, VIf(Bf11));
    __hv_varwrite_f(&sVarf_0kIcHBaa, VIf(Bf12));
    __hv_varread_f(&sVarf_0kIcHBaa, VOf(Bf12));
    __hv_line_f(&sLine_JRzax4vN, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_2CkmCKc6, VIf(Bf10));
    __hv_varread_f(&sVarf_hVBRXm4G, VOf(Bf10));
    __hv_line_f(&sLine_SA2ckAkw, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_dx4aErxA, VIf(Bf10));
    __hv_varwrite_f(&sVarf_WSjIvhTN, VIf(Bf7));
    __hv_varread_f(&sVarf_lqdcecXa, VOf(Bf7));
    __hv_varread_f(&sVarf_aBJrg6Oc, VOf(Bf10));
    __hv_varread_f(&sVarf_9di6zYGx, VOf(Bf9));
    __hv_varread_f(&sVarf_qzxQEqsb, VOf(Bf11));
    __hv_varread_f(&sVarf_yBlBBiOQ, VOf(Bf6));
    __hv_varread_f(&sVarf_B5XRbvMj, VOf(Bf12));
    __hv_varread_f(&sVarf_pA0lRah3, VOf(Bf1));
    __hv_varwrite_f(&sVarf_ShpDAYKz, VIf(Bf4));
    __hv_varread_f(&sVarf_u14jmybK, VOf(Bf2));
    __hv_line_f(&sLine_WWnlyZY9, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_88CCVbw4, VOf(Bf17));
    __hv_line_f(&sLine_tiaIaBPv, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_S0lqDWzV, VOf(Bf16));
    __hv_line_f(&sLine_WT3npUqH, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_qzxQEqsb, VIf(Bf15));
    __hv_varread_f(&sVarf_ShpDAYKz, VOf(Bf15));
    __hv_line_f(&sLine_VVYOa60h, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_hmkvz4a8, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_seo1zEtK, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_yBlBBiOQ, VIf(Bf13));
    __hv_line_f(&sLine_jPPBcdLx, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_f9mjabuR, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_qmwD0tTA, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_B5XRbvMj, VIf(Bf13));
    __hv_line_f(&sLine_J2LrEdIu, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_moI6oDZz, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_BpyP2r8M, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_pA0lRah3, VIf(Bf13));
    __hv_varwrite_f(&sVarf_u14jmybK, VIf(Bf7));
    __hv_varwrite_f(&sVarf_88CCVbw4, VIf(Bf10));
    __hv_varwrite_f(&sVarf_S0lqDWzV, VIf(Bf9));
    sEnv_process(this, &sEnv_TgHdAcS9, VIf(Bf11), &sEnv_TgHdAcS9_sendMessage);
    sEnv_process(this, &sEnv_xECpFu9h, VIf(Bf4), &sEnv_xECpFu9h_sendMessage);
    __hv_line_f(&sLine_sUnt3fmJ, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_fqOE2GNO, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_EvvUng9M, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_qCoLmusq, VOf(Bf11));
    __hv_line_f(&sLine_EXuIzKoZ, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_lqdcecXa, VIf(Bf10));
    __hv_varwrite_f(&sVarf_qCoLmusq, VIf(Bf6));
    __hv_varwrite_f(&sVarf_bR6c2Di2, VIf(Bf12));
    __hv_varwrite_f(&sVarf_TqvJawLR, VIf(Bf1));
    __hv_varread_f(&sVarf_TqvJawLR, VOf(Bf1));
    __hv_line_f(&sLine_eIRCpUjN, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_9di6zYGx, VIf(Bf6));
    __hv_varread_f(&sVarf_bR6c2Di2, VOf(Bf6));
    __hv_line_f(&sLine_bCVl9EtW, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_aBJrg6Oc, VIf(Bf6));
    __hv_varwrite_f(&sVarf_DG1clAzq, VIf(Bf4));
    __hv_varwrite_f(&sVarf_KSvbZcpv, VIf(Bf0));
    __hv_varread_f(&sVarf_8WjuLJOs, VOf(Bf0));
    __hv_varread_f(&sVarf_6WxNejch, VOf(Bf4));
    __hv_varread_f(&sVarf_gWkqP9St, VOf(Bf6));
    __hv_varread_f(&sVarf_i9sM1SQc, VOf(Bf10));
    __hv_varread_f(&sVarf_jeeuclHE, VOf(Bf12));
    __hv_varread_f(&sVarf_derGQKYi, VOf(Bf11));
    __hv_line_f(&sLine_rMz6RJNI, VOf(Bf1));
    __hv_line_f(&sLine_aC7DT6sk, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_gWkqP9St, VIf(Bf0));
    __hv_varwrite_f(&sVarf_jeeuclHE, VIf(Bf4));
    __hv_varread_f(&sVarf_wiclSSgC, VOf(Bf1));
    __hv_varread_f(&sVarf_IdaBpeE6, VOf(Bf12));
    __hv_varread_f(&sVarf_MRlNTXxU, VOf(Bf11));
    __hv_varread_f(&sVarf_dGVOgJc7, VOf(Bf6));
    __hv_varread_f(&sVarf_ZosQzkjf, VOf(Bf7));
    __hv_varread_f(&sVarf_6WDpbRwq, VOf(Bf13));
    __hv_varread_f(&sVarf_fGNPXAgy, VOf(Bf15));
    __hv_varwrite_f(&sVarf_4SG93k7D, VIf(Bf0));
    __hv_varread_f(&sVarf_3wCQGagt, VOf(Bf2));
    __hv_line_f(&sLine_HjEufcug, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_8mUt6gky, VOf(Bf18));
    __hv_line_f(&sLine_0Wi290KZ, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_prcUgFkP, VOf(Bf17));
    __hv_line_f(&sLine_L5mr6iNo, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_dGVOgJc7, VIf(Bf14));
    __hv_varread_f(&sVarf_4SG93k7D, VOf(Bf14));
    __hv_line_f(&sLine_e7Spewh2, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_wOSRRnGQ, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_QgOHtB8W, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_ZosQzkjf, VIf(Bf16));
    __hv_line_f(&sLine_7sguzfOG, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_kbKfvAp6, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_Lub09x2W, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_6WDpbRwq, VIf(Bf16));
    __hv_line_f(&sLine_ZdQX6UkK, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_KScbNcDK, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_M4qLKRWz, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_fGNPXAgy, VIf(Bf16));
    __hv_varwrite_f(&sVarf_3wCQGagt, VIf(Bf1));
    __hv_varwrite_f(&sVarf_8mUt6gky, VIf(Bf12));
    __hv_varwrite_f(&sVarf_prcUgFkP, VIf(Bf11));
    sEnv_process(this, &sEnv_TH3MPeU9, VIf(Bf6), &sEnv_TH3MPeU9_sendMessage);
    sEnv_process(this, &sEnv_gRDr9mRZ, VIf(Bf0), &sEnv_gRDr9mRZ_sendMessage);
    __hv_line_f(&sLine_Gx8dbkoU, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Fw9cbCSV, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_t8jeFpDX, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_jXRomTnn, VOf(Bf6));
    __hv_line_f(&sLine_iMgO4h1Q, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_wiclSSgC, VIf(Bf12));
    __hv_varwrite_f(&sVarf_jXRomTnn, VIf(Bf7));
    __hv_varwrite_f(&sVarf_sxRrVfkm, VIf(Bf13));
    __hv_varwrite_f(&sVarf_F0bs1PCs, VIf(Bf15));
    __hv_varread_f(&sVarf_F0bs1PCs, VOf(Bf15));
    __hv_line_f(&sLine_79LUztVd, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_MRlNTXxU, VIf(Bf7));
    __hv_varread_f(&sVarf_sxRrVfkm, VOf(Bf7));
    __hv_line_f(&sLine_r2YfIevf, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_IdaBpeE6, VIf(Bf7));
    __hv_varwrite_f(&sVarf_i9sM1SQc, VIf(Bf0));
    __hv_varread_f(&sVarf_zZjXv2uG, VOf(Bf0));
    __hv_varread_f(&sVarf_37WMNZrg, VOf(Bf7));
    __hv_varread_f(&sVarf_25zR7owl, VOf(Bf12));
    __hv_varread_f(&sVarf_n5tyFLhA, VOf(Bf13));
    __hv_varread_f(&sVarf_V3aHakud, VOf(Bf6));
    __hv_varread_f(&sVarf_J2vTYnF3, VOf(Bf15));
    __hv_varread_f(&sVarf_JAPXPLVV, VOf(Bf11));
    __hv_varwrite_f(&sVarf_BetPxAwB, VIf(Bf4));
    __hv_varread_f(&sVarf_7hjksRKV, VOf(Bf1));
    __hv_line_f(&sLine_nTvlXFPr, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_RKwgPg38, VOf(Bf14));
    __hv_line_f(&sLine_GQ2RnPk3, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_sLctzEdm, VOf(Bf16));
    __hv_line_f(&sLine_DrL1fQT8, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_n5tyFLhA, VIf(Bf18));
    __hv_varread_f(&sVarf_BetPxAwB, VOf(Bf18));
    __hv_line_f(&sLine_06v0ov2y, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_TNe89WGO, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_OfC7p1tY, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_V3aHakud, VIf(Bf2));
    __hv_line_f(&sLine_aTIrxYQX, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_YO57sY5g, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_KEzHY0W9, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_J2vTYnF3, VIf(Bf2));
    __hv_line_f(&sLine_lpzUfHtL, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_KZRLzRkT, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_3yCyl5fj, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_JAPXPLVV, VIf(Bf2));
    __hv_varwrite_f(&sVarf_7hjksRKV, VIf(Bf0));
    __hv_varwrite_f(&sVarf_RKwgPg38, VIf(Bf7));
    __hv_varwrite_f(&sVarf_sLctzEdm, VIf(Bf12));
    sEnv_process(this, &sEnv_6hbp07Ll, VIf(Bf13), &sEnv_6hbp07Ll_sendMessage);
    sEnv_process(this, &sEnv_s06cSl1I, VIf(Bf4), &sEnv_s06cSl1I_sendMessage);
    __hv_line_f(&sLine_Ia7I8vH7, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_PUNHRokT, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_PPHNkKqa, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_z5GeY2SP, VOf(Bf13));
    __hv_line_f(&sLine_qmGYOjlu, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_zZjXv2uG, VIf(Bf7));
    __hv_varwrite_f(&sVarf_z5GeY2SP, VIf(Bf6));
    __hv_varwrite_f(&sVarf_h8iJTmdX, VIf(Bf15));
    __hv_varwrite_f(&sVarf_LbIhn1e2, VIf(Bf11));
    __hv_varread_f(&sVarf_LbIhn1e2, VOf(Bf11));
    __hv_line_f(&sLine_Sjifc3bi, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_25zR7owl, VIf(Bf6));
    __hv_varread_f(&sVarf_h8iJTmdX, VOf(Bf6));
    __hv_line_f(&sLine_Xxu8Vd2c, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_37WMNZrg, VIf(Bf6));
    __hv_varwrite_f(&sVarf_derGQKYi, VIf(Bf4));
    __hv_varwrite_f(&sVarf_EDfGSRwX, VIf(Bf10));
    __hv_varread_f(&sVarf_b8rowDHu, VOf(Bf10));
    __hv_varread_f(&sVarf_UXMKkb6N, VOf(Bf4));
    __hv_varread_f(&sVarf_rtmMlI3K, VOf(Bf6));
    __hv_varread_f(&sVarf_sdcgtbQ1, VOf(Bf7));
    __hv_varread_f(&sVarf_Ov2vUpd0, VOf(Bf15));
    __hv_varread_f(&sVarf_xf9ed4rW, VOf(Bf13));
    __hv_line_f(&sLine_wnyHJOKW, VOf(Bf11));
    __hv_line_f(&sLine_hdxUK3Bt, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_rtmMlI3K, VIf(Bf10));
    __hv_varwrite_f(&sVarf_Ov2vUpd0, VIf(Bf4));
    __hv_varread_f(&sVarf_0xi5CqHY, VOf(Bf11));
    __hv_varread_f(&sVarf_lu1Mfbj6, VOf(Bf15));
    __hv_varread_f(&sVarf_ATTUWutT, VOf(Bf13));
    __hv_varread_f(&sVarf_FS7z3Svg, VOf(Bf6));
    __hv_varread_f(&sVarf_EI5p9koQ, VOf(Bf0));
    __hv_varread_f(&sVarf_hVkn6xBE, VOf(Bf2));
    __hv_varread_f(&sVarf_jxDhnbSF, VOf(Bf18));
    __hv_varwrite_f(&sVarf_4IoYfFzJ, VIf(Bf10));
    __hv_varread_f(&sVarf_NDbIMnZ0, VOf(Bf1));
    __hv_line_f(&sLine_eIOJyGLt, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_1FUPBahw, VOf(Bf19));
    __hv_line_f(&sLine_Mja35mP2, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_rq5NfA5X, VOf(Bf14));
    __hv_line_f(&sLine_tg35ulWt, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_FS7z3Svg, VIf(Bf17));
    __hv_varread_f(&sVarf_4IoYfFzJ, VOf(Bf17));
    __hv_line_f(&sLine_vIW2eJ5Y, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_ZwmsUNff, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_ckwoFKe3, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_EI5p9koQ, VIf(Bf16));
    __hv_line_f(&sLine_eigIZEcC, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_PFoCM56L, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_F075KHvp, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_hVkn6xBE, VIf(Bf16));
    __hv_line_f(&sLine_ne6aPGeq, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_YUh0TIV9, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_whaKzzsP, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_jxDhnbSF, VIf(Bf16));
    __hv_varwrite_f(&sVarf_NDbIMnZ0, VIf(Bf11));
    __hv_varwrite_f(&sVarf_1FUPBahw, VIf(Bf15));
    __hv_varwrite_f(&sVarf_rq5NfA5X, VIf(Bf13));
    sEnv_process(this, &sEnv_9A6aXtWA, VIf(Bf6), &sEnv_9A6aXtWA_sendMessage);
    sEnv_process(this, &sEnv_Gi9Jylt3, VIf(Bf10), &sEnv_Gi9Jylt3_sendMessage);
    __hv_line_f(&sLine_IyJGTvYs, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_XQ7uR8i7, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_DZriARlK, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_5BYYlVNZ, VOf(Bf6));
    __hv_line_f(&sLine_LC5DhuoK, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_0xi5CqHY, VIf(Bf15));
    __hv_varwrite_f(&sVarf_5BYYlVNZ, VIf(Bf0));
    __hv_varwrite_f(&sVarf_2WNNUoVQ, VIf(Bf2));
    __hv_varwrite_f(&sVarf_m06ewGta, VIf(Bf18));
    __hv_varread_f(&sVarf_m06ewGta, VOf(Bf18));
    __hv_line_f(&sLine_7Rxsi0U6, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_ATTUWutT, VIf(Bf0));
    __hv_varread_f(&sVarf_2WNNUoVQ, VOf(Bf0));
    __hv_line_f(&sLine_5TUnRzVB, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_lu1Mfbj6, VIf(Bf0));
    __hv_varwrite_f(&sVarf_sdcgtbQ1, VIf(Bf10));
    __hv_varread_f(&sVarf_RPaHVCGC, VOf(Bf10));
    __hv_varread_f(&sVarf_QyWbtUyd, VOf(Bf0));
    __hv_varread_f(&sVarf_TDF0yw69, VOf(Bf15));
    __hv_varread_f(&sVarf_6lmF587D, VOf(Bf2));
    __hv_varread_f(&sVarf_dj8JBq9i, VOf(Bf6));
    __hv_varread_f(&sVarf_ppLw72a2, VOf(Bf18));
    __hv_varread_f(&sVarf_dVcBLyzG, VOf(Bf13));
    __hv_varwrite_f(&sVarf_z8kMulaZ, VIf(Bf4));
    __hv_varread_f(&sVarf_e42Xc7Vu, VOf(Bf11));
    __hv_line_f(&sLine_EFU1BRDz, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_FwKB29b3, VOf(Bf17));
    __hv_line_f(&sLine_iZheSgqy, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_69eazwhA, VOf(Bf16));
    __hv_line_f(&sLine_WiClOoou, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_6lmF587D, VIf(Bf19));
    __hv_varread_f(&sVarf_z8kMulaZ, VOf(Bf19));
    __hv_line_f(&sLine_3hLgWrox, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_WVfGqVX0, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_epeDfFTl, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_dj8JBq9i, VIf(Bf1));
    __hv_line_f(&sLine_pAzKTcwn, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_qi29mgPh, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_oK3ouDb7, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_ppLw72a2, VIf(Bf1));
    __hv_line_f(&sLine_dJlozWy7, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_ngbSHQhy, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_RpULlIeq, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_dVcBLyzG, VIf(Bf1));
    __hv_varwrite_f(&sVarf_e42Xc7Vu, VIf(Bf10));
    __hv_varwrite_f(&sVarf_FwKB29b3, VIf(Bf0));
    __hv_varwrite_f(&sVarf_69eazwhA, VIf(Bf15));
    sEnv_process(this, &sEnv_sPKu9mgO, VIf(Bf2), &sEnv_sPKu9mgO_sendMessage);
    sEnv_process(this, &sEnv_ubATTlpE, VIf(Bf4), &sEnv_ubATTlpE_sendMessage);
    __hv_line_f(&sLine_ooHmc5n6, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_fYxkiR48, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_9I1zi2Zk, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_RFHMGAVa, VOf(Bf2));
    __hv_line_f(&sLine_95mY20Hw, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_RPaHVCGC, VIf(Bf0));
    __hv_varwrite_f(&sVarf_RFHMGAVa, VIf(Bf6));
    __hv_varwrite_f(&sVarf_MenJlcB4, VIf(Bf18));
    __hv_varwrite_f(&sVarf_ccrDZwSY, VIf(Bf13));
    __hv_varread_f(&sVarf_ccrDZwSY, VOf(Bf13));
    __hv_line_f(&sLine_TJ9q0kzw, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_TDF0yw69, VIf(Bf6));
    __hv_varread_f(&sVarf_MenJlcB4, VOf(Bf6));
    __hv_line_f(&sLine_JCRjLcqj, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_QyWbtUyd, VIf(Bf6));
    __hv_varwrite_f(&sVarf_xf9ed4rW, VIf(Bf4));
    __hv_varwrite_f(&sVarf_cf85iq98, VIf(Bf7));
    __hv_varwrite_f(&sVarf_GlNrK1BO, VIf(Bf8));
    __hv_varwrite_f(&sVarf_lwBamMYy, VIf(Bf9));
    __hv_varwrite_f(&sVarf_l3mZQs0V, VIf(Bf12));
    __hv_varwrite_f(&sVarf_EmFOTdUR, VIf(Bf3));
    __hv_varwrite_f(&sVarf_53dYSyA0, VIf(Bf5));
    __hv_varread_f(&sVarf_GlNrK1BO, VOf(Bf5));
    __hv_varread_f(&sVarf_lwBamMYy, VOf(Bf3));
    __hv_varread_f(&sVarf_l3mZQs0V, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_KSvbZcpv, VOf(Bf12));
    __hv_varread_f(&sVarf_EDfGSRwX, VOf(Bf5));
    __hv_varread_f(&sVarf_cf85iq98, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
